@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2015 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -39,9 +44,7 @@
 #include <sbml/Compartment.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -120,8 +123,6 @@ Compartment::Compartment(SBMLNamespaces * sbmlns) :
 }
 
 /** @cond doxygenLibsbmlInternal */
-
-
 /** @endcond */
                           
 /*
@@ -138,11 +139,6 @@ Compartment::~Compartment ()
 Compartment::Compartment(const Compartment& orig) :
    SBase             ( orig                    )
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
   {
     mSpatialDimensions       = orig.mSpatialDimensions;
     mSpatialDimensionsDouble = orig.mSpatialDimensionsDouble;
@@ -167,11 +163,7 @@ Compartment::Compartment(const Compartment& orig) :
  */
 Compartment& Compartment::operator=(const Compartment& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->SBase::operator =(rhs);
     mSpatialDimensions= rhs.mSpatialDimensions  ;
@@ -195,18 +187,13 @@ Compartment& Compartment::operator=(const Compartment& rhs)
 
 
 
-/*
- * Accepts the given SBMLVisitor.
- *
- * @return the result of calling <code>v.visit()</code>, which indicates
- * whether or not the Visitor would like to visit the Model's next
- * Compartment (if available).
- */
+/** @cond doxygenLibsbmlInternal */
 bool
 Compartment::accept (SBMLVisitor& v) const
 {
   return v.visit(*this);
 }
+/** @endcond */
 
 
 /*
@@ -237,6 +224,10 @@ Compartment::initDefaults ()
   setSpatialDimensions(dims);
   setConstant(1);
 
+  // not explicilty set
+  mExplicitlySetSpatialDimensions = false;
+  mExplicitlySetConstant = false;
+
   if (getLevel() > 2)
   {
     setUnits("litre");
@@ -488,11 +479,7 @@ Compartment::setId (const std::string& sid)
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
   }
 */
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(sid)))
+  if (!(SyntaxChecker::isValidInternalSId(sid)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -513,11 +500,7 @@ Compartment::setName (const std::string& name)
   /* if this is setting an L2 name the type is string
    * whereas if it is setting an L1 name its type is SId
    */
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (getLevel() == 1)
+  if (getLevel() == 1)
   {
     if (!(SyntaxChecker::isValidInternalSId(name)))
     {
@@ -543,11 +526,7 @@ Compartment::setName (const std::string& name)
 int
 Compartment::setCompartmentType (const std::string& sid)
 {
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if ( (getLevel() < 2)
+  if ( (getLevel() < 2)
     || (getLevel() == 2 && getVersion() == 1))
   {
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
@@ -665,11 +644,7 @@ Compartment::setVolume (double value)
 int
 Compartment::setUnits (const std::string& sid)
 {
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalUnitSId(sid)))
+  if (!(SyntaxChecker::isValidInternalUnitSId(sid)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -687,11 +662,7 @@ Compartment::setUnits (const std::string& sid)
 int
 Compartment::setOutside (const std::string& sid)
 {
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(sid)))
+  if (!(SyntaxChecker::isValidInternalSId(sid)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -770,6 +741,31 @@ Compartment::unsetName ()
 }
 
 
+int
+Compartment::unsetConstant ()
+{
+  if ( getLevel() == 1 )
+  {
+    mConstant = false;
+    return LIBSBML_UNEXPECTED_ATTRIBUTE;
+  }
+  else if (getLevel() == 2)
+  {
+    // reset default
+    mConstant = true;
+    mIsSetConstant = true;
+    mExplicitlySetConstant = false;
+    return LIBSBML_UNEXPECTED_ATTRIBUTE;
+  }
+  else
+  {
+    mIsSetConstant = false;
+    mExplicitlySetConstant = false;
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+}
+
+
 /*
  * Unsets the compartmentType of this Compartment.
  */
@@ -1116,7 +1112,8 @@ Compartment::readL1Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("name", level, version, "<compartment>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
   //
   // volume  { use="optional" default="1" }  (L1v1, L1v2)
@@ -1133,7 +1130,7 @@ Compartment::readL1Attributes (const XMLAttributes& attributes)
   }
   if (!SyntaxChecker::isValidInternalUnitSId(mUnits))
   {
-    logError(InvalidUnitIdSyntax);
+    logError(InvalidUnitIdSyntax, getLevel(), getVersion(), "The units attribute '" + mUnits + "' does not conform to the syntax.");
   }
 
   //
@@ -1164,7 +1161,8 @@ Compartment::readL2Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("id", level, version, "<compartment>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
   //
   // size    { use="optional" }              (L2v1 ->)
@@ -1181,7 +1179,7 @@ Compartment::readL2Attributes (const XMLAttributes& attributes)
   }
   if (!SyntaxChecker::isValidInternalUnitSId(mUnits))
   {
-    logError(InvalidUnitIdSyntax);
+    logError(InvalidUnitIdSyntax, getLevel(), getVersion(), "The units attribute '" + mUnits + "' does not conform to the syntax.");
   }
 
   //
@@ -1255,8 +1253,13 @@ Compartment::readL3Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("id", level, version, "<compartment>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
+  string elplusid = "<compartment>";
+  if (!mId.empty()) {
+    elplusid += " with the id '" + mId + "'";
+  }
   //
   // size    { use="optional" }              (L2v1 ->)
   //
@@ -1272,7 +1275,9 @@ Compartment::readL3Attributes (const XMLAttributes& attributes)
   }
   if (!SyntaxChecker::isValidInternalUnitSId(mUnits))
   {
-    logError(InvalidUnitIdSyntax);
+    logError(InvalidUnitIdSyntax, level, version, "The " + elplusid + 
+      " has a substanceUnits with a value of '" + mUnits 
+      + "' which does not conform .");
   }
 
 
@@ -1301,7 +1306,8 @@ Compartment::readL3Attributes (const XMLAttributes& attributes)
   if (!mIsSetConstant)
   {
     logError(AllowedAttributesOnCompartment, level, version, 
-      "The required attribute 'constant' is missing.");
+      "The required attribute 'constant' is missing from the "
+      + elplusid + ".");
   }
 }
 /** @endcond */
@@ -1526,11 +1532,6 @@ ListOfCompartments::get (const std::string& sid) const
 {
   vector<SBase*>::const_iterator result;
 
-  if (&(sid) == NULL)
-  {
-    return NULL;
-  }
-  else
   {
     result = find_if( mItems.begin(), mItems.end(), IdEq<Compartment>(sid) );
     return (result == mItems.end()) ? NULL : 
@@ -1554,15 +1555,12 @@ ListOfCompartments::remove (const std::string& sid)
   SBase* item = NULL;
   vector<SBase*>::iterator result;
 
-  if (&(sid) != NULL)
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEq<Compartment>(sid) );
+  result = find_if( mItems.begin(), mItems.end(), IdEq<Compartment>(sid) );
 
-    if (result != mItems.end())
-    {
-      item = *result;
-      mItems.erase(result);
-    }
+  if (result != mItems.end())
+  {
+    item = *result;
+    mItems.erase(result);
   }
 
   return static_cast <Compartment*> (item);
@@ -1620,9 +1618,7 @@ ListOfCompartments::createObject (XMLInputStream& stream)
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
-
-
+/** @cond doxygenIgnored */
 LIBSBML_EXTERN
 Compartment_t *
 Compartment_create (unsigned int level, unsigned int version)
@@ -1989,6 +1985,17 @@ Compartment_unsetCompartmentType (Compartment_t *c)
 }
 
 
+LIBSBML_EXTERN
+int
+Compartment_unsetConstant (Compartment_t *c)
+{
+  if (c != NULL)
+    return c->unsetConstant();
+  else
+    return LIBSBML_INVALID_OBJECT;
+}
+
+
 LIBSBML_EXTERN
 int
 Compartment_unsetSize (Compartment_t *c)
@@ -2085,7 +2092,6 @@ ListOfCompartments_removeById (ListOf_t *lo, const char *sid)
   else
     return NULL;
 }
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
