@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2015 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -38,9 +43,7 @@
 #include <sbml/CompartmentType.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -81,19 +84,11 @@ CompartmentType::~CompartmentType ()
 /*
  * Copy constructor. Creates a copy of this CompartmentType.
  */
-CompartmentType::CompartmentType(const CompartmentType& orig) :
-   SBase             ( orig                    )
+CompartmentType::CompartmentType(const CompartmentType& orig)
+  : SBase             ( orig                    )
+  , mId               (orig.mId)
+  , mName             (orig.mName)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mId               = orig.mId;
-    mName             = orig.mName;
-  }
-
 }
 
 
@@ -102,11 +97,7 @@ CompartmentType::CompartmentType(const CompartmentType& orig) :
  */
 CompartmentType& CompartmentType::operator=(const CompartmentType& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->SBase::operator =(rhs);
     mId = rhs.mId;
@@ -117,18 +108,13 @@ CompartmentType& CompartmentType::operator=(const CompartmentType& rhs)
 }
 
 
-/*
- * Accepts the given SBMLVisitor.
- *
- * @return the result of calling <code>v.visit()</code>, which indicates
- * whether or not the Visitor would like to visit the Model's next
- * CompartmentType (if available).
- */
+/** @cond doxygenLibsbmlInternal */
 bool
 CompartmentType::accept (SBMLVisitor& v) const
 {
   return v.visit(*this);
 }
+/** @endcond */
 
 
 /*
@@ -199,11 +185,7 @@ CompartmentType::setId (const std::string& sid)
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
   }
 */
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(sid)))
+  if (!(SyntaxChecker::isValidInternalSId(sid)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -224,11 +206,7 @@ CompartmentType::setName (const std::string& name)
   /* if this is setting an L2 name the type is string
    * whereas if it is setting an L1 name its type is SId
    */
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (getLevel() == 1)
+  if (getLevel() == 1)
   {
     if (!(SyntaxChecker::isValidInternalSId(name)))
     {
@@ -335,7 +313,6 @@ CompartmentType::hasRequiredAttributes() const
 
 
 /** @cond doxygenLibsbmlInternal */
-
 /**
  * Subclasses should override this method to get the list of
  * expected attributes.
@@ -413,7 +390,8 @@ CompartmentType::readL2Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("id", level, version, "<compartmentType>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
   //
   // name: string  { use="optional" }  (L2v2 ->)
@@ -560,16 +538,9 @@ ListOfCompartmentTypes::get (const std::string& sid) const
 {
   vector<SBase*>::const_iterator result;
 
-  if (&(sid) == NULL)
-  {
-    return NULL;
-  }
-  else
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqCT(sid) );
-    return (result == mItems.end()) ? NULL : 
-                      static_cast <CompartmentType*> (*result);
-  }
+  result = find_if( mItems.begin(), mItems.end(), IdEqCT(sid) );
+  return (result == mItems.end()) ? NULL : 
+                    static_cast <CompartmentType*> (*result);  
 }
 
 
@@ -588,15 +559,12 @@ ListOfCompartmentTypes::remove (const std::string& sid)
   SBase* item = NULL;
   vector<SBase*>::iterator result;
 
-  if (&(sid) != NULL)
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqCT(sid) );
+  result = find_if( mItems.begin(), mItems.end(), IdEqCT(sid) );
 
-    if (result != mItems.end())
-    {
-      item = *result;
-      mItems.erase(result);
-    }
+  if (result != mItems.end())
+  {
+    item = *result;
+    mItems.erase(result);
   }
 
   return static_cast <CompartmentType*> (item);
@@ -654,29 +622,7 @@ ListOfCompartmentTypes::createObject (XMLInputStream& stream)
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
-
-
-/**
- * Creates a new CompartmentType_t structure using the given SBML @p level
- * and @p version values.
- *
- * @param level an unsigned int, the SBML Level to assign to this
- * CompartmentType
- *
- * @param version an unsigned int, the SBML Version to assign to this
- * CompartmentType
- *
- * @return a pointer to the newly created CompartmentType_t structure.
- *
- * @note Once a CompartmentType has been added to an SBMLDocument, the @p
- * level and @p version for the document @em override those used to create
- * the CompartmentType.  Despite this, the ability to supply the values at
- * creation time is an important aid to creating valid SBML.  Knowledge of
- * the intended SBML Level and Version  determine whether it is valid to
- * assign a particular value to an attribute, or whether it is valid to add
- * an object to an existing SBMLDocument.
- */
+/** @cond doxygenIgnored */
 LIBSBML_EXTERN
 CompartmentType_t *
 CompartmentType_create (unsigned int level, unsigned int version)
@@ -693,23 +639,6 @@ CompartmentType_create (unsigned int level, unsigned int version)
 }
 
 
-/**
- * Creates a new CompartmentType_t structure using the given
- * SBMLNamespaces_t structure.
- *
- * @param sbmlns SBMLNamespaces, a pointer to an SBMLNamespaces structure
- * to assign to this CompartmentType
- *
- * @return a pointer to the newly created CompartmentType_t structure.
- *
- * @note Once a CompartmentType has been added to an SBMLDocument, the
- * @p sbmlns namespaces for the document @em override those used to create
- * the CompartmentType.  Despite this, the ability to supply the values at 
- * creation time is an important aid to creating valid SBML.  Knowledge of the 
- * intended SBML Level and Version determine whether it is valid to assign a 
- * particular value to an attribute, or whether it is valid to add an object 
- * to an existing SBMLDocument.
- */
 LIBSBML_EXTERN
 CompartmentType_t *
 CompartmentType_createWithNS (SBMLNamespaces_t* sbmlns)
@@ -726,11 +655,6 @@ CompartmentType_createWithNS (SBMLNamespaces_t* sbmlns)
 }
 
 
-/**
- * Frees the given CompartmentType_t structure.
- *
- * @param ct the CompartmentType_t structure to be freed.
- */
 LIBSBML_EXTERN
 void
 CompartmentType_free (CompartmentType_t *ct)
@@ -740,13 +664,6 @@ CompartmentType_free (CompartmentType_t *ct)
 }
 
 
-/**
- * Creates a deep copy of the given CompartmentType_t structure
- * 
- * @param ct the CompartmentType_t structure to be copied
- * 
- * @return a (deep) copy of this CompartmentType_t structure.
- */
 LIBSBML_EXTERN
 CompartmentType_t *
 CompartmentType_clone (const CompartmentType_t *ct)
@@ -762,15 +679,6 @@ CompartmentType_clone (const CompartmentType_t *ct)
 }
 
 
-/**
- * Returns a list of XMLNamespaces_t associated with this CompartmentType_t
- * structure.
- *
- * @param ct the CompartmentType_t structure
- * 
- * @return pointer to the XMLNamespaces_t structure associated with 
- * this SBML object
- */
 LIBSBML_EXTERN
 const XMLNamespaces_t *
 CompartmentType_getNamespaces(CompartmentType_t *ct)
@@ -785,13 +693,6 @@ CompartmentType_getNamespaces(CompartmentType_t *ct)
   }
 }
 
-/**
- * Takes a CompartmentType_t structure and returns its identifier.
- *
- * @param ct the CompartmentType_t structure whose identifier is sought
- * 
- * @return the identifier of this CompartmentType_t, as a pointer to a string.
- */
 LIBSBML_EXTERN
 const char *
 CompartmentType_getId (const CompartmentType_t *ct)
@@ -800,13 +701,6 @@ CompartmentType_getId (const CompartmentType_t *ct)
 }
 
 
-/**
- * Takes a CompartmentType_t structure and returns its name.
- *
- * @param ct the CompartmentType_t whose name is sought.
- *
- * @return the name of this CompartmentType_t, as a pointer to a string.
- */
 LIBSBML_EXTERN
 const char *
 CompartmentType_getName (const CompartmentType_t *ct)
@@ -815,15 +709,6 @@ CompartmentType_getName (const CompartmentType_t *ct)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * CompartmentType_t structure's identifier is set.
- *
- * @param ct the CompartmentType_t structure to query
- * 
- * @return @c non-zero (true) if the "id" field of the given
- * CompartmentType is set, zero (false) otherwise.
- */
 LIBSBML_EXTERN
 int
 CompartmentType_isSetId (const CompartmentType_t *ct)
@@ -832,15 +717,6 @@ CompartmentType_isSetId (const CompartmentType_t *ct)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * CompartmentType_t structure's name is set.
- *
- * @param ct the CompartmentType_t structure to query
- * 
- * @return @c non-zero (true) if the "name" field of the given
- * CompartmentType is set, zero (false) otherwise.
- */
 LIBSBML_EXTERN
 int
 CompartmentType_isSetName (const CompartmentType_t *ct)
@@ -849,24 +725,6 @@ CompartmentType_isSetName (const CompartmentType_t *ct)
 }
 
 
-/**
- * Assigns the identifier of a CompartmentType_t structure.
- *
- * This makes a copy of the string passed as the argument @p sid.
- *
- * @param ct the CompartmentType_t structure to set.
- * @param sid the string to use as the identifier.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with an id of NULL is equivalent to
- * unsetting the "id" attribute.
- */
 LIBSBML_EXTERN
 int
 CompartmentType_setId (CompartmentType_t *ct, const char *sid)
@@ -878,24 +736,6 @@ CompartmentType_setId (CompartmentType_t *ct, const char *sid)
 }
 
 
-/**
- * Assign the name of a CompartmentType_t structure.
- *
- * This makes a copy of the string passed as the argument @p name.
- *
- * @param ct the CompartmentType_t structure to set.
- * @param name the string to use as the name.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with the name set to NULL is equivalent to
- * unsetting the "name" attribute.
- */
 LIBSBML_EXTERN
 int
 CompartmentType_setName (CompartmentType_t *ct, const char *name)
@@ -907,18 +747,6 @@ CompartmentType_setName (CompartmentType_t *ct, const char *name)
 }
 
 
-/**
- * Unsets the name of a CompartmentType.
- * 
- * @param ct the CompartmentType_t structure whose name is to be unset.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_OPERATION_FAILED
- */
 LIBSBML_EXTERN
 int
 CompartmentType_unsetName (CompartmentType_t *ct)
@@ -930,10 +758,6 @@ CompartmentType_unsetName (CompartmentType_t *ct)
 }
 
 
-/**
- * @return item in this ListOfCompartmentType with the given @p id or @c NULL if no such
- * item exists.
- */
 LIBSBML_EXTERN
 CompartmentType_t *
 ListOfCompartmentTypes_getById (ListOf_t *lo, const char *sid)
@@ -946,11 +770,6 @@ ListOfCompartmentTypes_getById (ListOf_t *lo, const char *sid)
 }
 
 
-/**
- * Removes item in this ListOf items with the given @p id or @c NULL if no such
- * item exists.  The caller owns the returned item and is responsible for
- * deleting it.
- */
 LIBSBML_EXTERN
 CompartmentType_t *
 ListOfCompartmentTypes_removeById (ListOf_t *lo, const char *sid)
@@ -961,7 +780,6 @@ ListOfCompartmentTypes_removeById (ListOf_t *lo, const char *sid)
   else
     return NULL;
 }
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
