@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2015 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -44,9 +49,7 @@
 #include <signal.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -89,23 +92,16 @@ EventAssignment::~EventAssignment ()
  * Copy constructor. Creates a copy of this EventAssignment.
  */
 EventAssignment::EventAssignment (const EventAssignment& orig) :
-   SBase   ( orig )
-  , mMath  ( NULL    )
+   SBase      ( orig )
+  , mVariable ( orig.mVariable )
+  , mMath     ( NULL    )
 {
-  if (&orig == NULL)
+  if (orig.mMath != NULL) 
   {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mVariable  = orig.mVariable;
-
-    if (orig.mMath != NULL) 
-    {
-      mMath = orig.mMath->deepCopy();
-      mMath->setParentSBMLObject(this);
-    }
+    mMath = orig.mMath->deepCopy();
+    mMath->setParentSBMLObject(this);
   }
+  
 }
 
 
@@ -114,11 +110,7 @@ EventAssignment::EventAssignment (const EventAssignment& orig) :
  */
 EventAssignment& EventAssignment::operator=(const EventAssignment& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->SBase::operator =(rhs);
     this->mVariable = rhs.mVariable;
@@ -139,18 +131,13 @@ EventAssignment& EventAssignment::operator=(const EventAssignment& rhs)
 }
 
 
-/*
- * Accepts the given SBMLVisitor.
- *
- * @return the result of calling <code>v.visit()</code>, which indicates
- * whether or not the Visitor would like to visit the Event's next
- * EventAssignment (if available).
- */
+/** @cond doxygenLibsbmlInternal */
 bool
 EventAssignment::accept (SBMLVisitor& v) const
 {
   return v.visit(*this);
 }
+/** @endcond */
 
 
 /*
@@ -211,11 +198,7 @@ EventAssignment::isSetMath () const
 int
 EventAssignment::setVariable (const std::string& sid)
 {
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(sid)))
+  if (!(SyntaxChecker::isValidInternalSId(sid)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -227,6 +210,22 @@ EventAssignment::setVariable (const std::string& sid)
 }
 
 
+int
+EventAssignment::unsetVariable ()
+{
+  mVariable.erase();
+
+  if (mVariable.empty())
+  {
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+  else
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }
+}
+
+
 /*
  * Sets the math of this EventAssignment to a copy of the given ASTNode.
  */
@@ -682,7 +681,7 @@ EventAssignment::readL2Attributes (const XMLAttributes& attributes)
   }
   if (!SyntaxChecker::isValidInternalSId(mVariable)) 
     logError(InvalidIdSyntax, getLevel(), getVersion(), 
-    "The syntax of the attribute variable='" + mVariable + "' does not conform.");
+    "The syntax of the attribute variable='" + mVariable + "' does not conform to the syntax.");
 
 
   //
@@ -720,7 +719,8 @@ EventAssignment::readL3Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("variable", level, version, "<eventAssignment>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mVariable)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mVariable)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mVariable + "' does not conform to the syntax.");
 }
 /** @endcond */
 
@@ -863,16 +863,9 @@ ListOfEventAssignments::get (const std::string& sid) const
 {
   vector<SBase*>::const_iterator result;
 
-  if (&(sid) == NULL)
-  {
-    return NULL;
-  }
-  else
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqEA(sid) );
-    return (result == mItems.end()) ? NULL : 
-                      static_cast <EventAssignment*> (*result);
-  }
+  result = find_if( mItems.begin(), mItems.end(), IdEqEA(sid) );
+  return (result == mItems.end()) ? NULL : 
+                    static_cast <EventAssignment*> (*result);
 }
 
 
@@ -891,15 +884,12 @@ ListOfEventAssignments::remove (const std::string& sid)
   SBase* item = NULL;
   vector<SBase*>::iterator result;
 
-  if (&(sid) != NULL)
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqEA(sid) );
+  result = find_if( mItems.begin(), mItems.end(), IdEqEA(sid) );
 
-    if (result != mItems.end())
-    {
-      item = *result;
-      mItems.erase(result);
-    }
+  if (result != mItems.end())
+  {
+    item = *result;
+    mItems.erase(result);
   }
 
   return static_cast <EventAssignment*> (item);
@@ -972,29 +962,7 @@ ListOfEventAssignments::createObject (XMLInputStream& stream)
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
-
-
-/**
- * Creates a new EventAssignment_t structure using the given SBML @p level
- * and @p version values.
- *
- * @param level an unsigned int, the SBML Level to assign to this
- * EventAssignment
- *
- * @param version an unsigned int, the SBML Version to assign to this
- * EventAssignment
- *
- * @return a pointer to the newly created EventAssignment_t structure.
- *
- * @note Once a EventAssignment has been added to an SBMLDocument, the @p
- * level and @p version for the document @em override those used to create
- * the EventAssignment.  Despite this, the ability to supply the values at
- * creation time is an important aid to creating valid SBML.  Knowledge of
- * the intended SBML Level and Version  determine whether it is valid to
- * assign a particular value to an attribute, or whether it is valid to add
- * an object to an existing SBMLDocument.
- */
+/** @cond doxygenIgnored */
 LIBSBML_EXTERN
 EventAssignment_t *
 EventAssignment_create (unsigned int level, unsigned int version)
@@ -1011,23 +979,6 @@ EventAssignment_create (unsigned int level, unsigned int version)
 }
 
 
-/**
- * Creates a new EventAssignment_t structure using the given
- * SBMLNamespaces_t structure.
- *
- * @param sbmlns SBMLNamespaces, a pointer to an SBMLNamespaces structure
- * to assign to this EventAssignment
- *
- * @return a pointer to the newly created EventAssignment_t structure.
- *
- * @note Once a EventAssignment has been added to an SBMLDocument, the
- * @p sbmlns namespaces for the document @em override those used to create
- * the EventAssignment.  Despite this, the ability to supply the values at 
- * creation time is an important aid to creating valid SBML.  Knowledge of the 
- * intended SBML Level and Version determine whether it is valid to assign a 
- * particular value to an attribute, or whether it is valid to add an object to 
- * an existing SBMLDocument.
- */
 LIBSBML_EXTERN
 EventAssignment_t *
 EventAssignment_createWithNS (SBMLNamespaces_t* sbmlns)
@@ -1044,11 +995,6 @@ EventAssignment_createWithNS (SBMLNamespaces_t* sbmlns)
 }
 
 
-/**
- * Frees the given EventAssignment_t structure.
- *
- * @param ea the EventAssignment_t to be freed.
- */
 LIBSBML_EXTERN
 void
 EventAssignment_free (EventAssignment_t *ea)
@@ -1058,13 +1004,6 @@ EventAssignment_free (EventAssignment_t *ea)
 }
 
 
-/**
- * Creates a (deep) copy of the given EventAssignment_t structure.
- *
- * @param ea the EventAssignment_t to be copied
- * 
- * @return a (deep) copy of @p ea.
- */
 LIBSBML_EXTERN
 EventAssignment_t *
 EventAssignment_clone (const EventAssignment_t *ea)
@@ -1073,15 +1012,6 @@ EventAssignment_clone (const EventAssignment_t *ea)
 }
 
 
-/**
- * Returns a list of XMLNamespaces_t associated with this EventAssignment_t
- * structure.
- *
- * @param ea the EventAssignment_t structure
- * 
- * @return pointer to the XMLNamespaces_t structure associated with 
- * this SBML object
- */
 LIBSBML_EXTERN
 const XMLNamespaces_t *
 EventAssignment_getNamespaces(EventAssignment_t *ea)
@@ -1090,14 +1020,6 @@ EventAssignment_getNamespaces(EventAssignment_t *ea)
 }
 
 
-/**
- * Gets the value of the "variable" attribute of this EventAssignment_t
- * structure.
- *
- * @param ea the EventAssignment_t structure to query.
- *
- * @return the identifier stored in the "variable" attribute of @p ea.
- */
 LIBSBML_EXTERN
 const char *
 EventAssignment_getVariable (const EventAssignment_t *ea)
@@ -1106,14 +1028,6 @@ EventAssignment_getVariable (const EventAssignment_t *ea)
 }
 
 
-/**
- * Gets the mathematical formula stored in the given EventAssignment_t
- * structure.
- *
- * @param ea the EventAssignment_t structure to query.
- *
- * @return the ASTNode tree stored in @p ea.
- */
 LIBSBML_EXTERN
 const ASTNode_t *
 EventAssignment_getMath (const EventAssignment_t *ea)
@@ -1122,15 +1036,6 @@ EventAssignment_getMath (const EventAssignment_t *ea)
 }
 
 
-/**
- * Predicate for testing whether the attribute "variable" of the
- * given EventAssignment_t structure is set.
- *
- * @param ea the EventAssignment_t structure to query.
- * 
- * @return nonzero (for true) if the "variable" attribute of @p ea
- * is set, zero (0) otherwise.
- */
 LIBSBML_EXTERN
 int
 EventAssignment_isSetVariable (const EventAssignment_t *ea)
@@ -1139,15 +1044,6 @@ EventAssignment_isSetVariable (const EventAssignment_t *ea)
 }
 
 
-/**
- * Predicate for testing whether the attribute "variable" of the
- * given EventAssignment_t structure is set.
- *
- * @param ea the EventAssignment_t structure to query.
- * 
- * @return nonzero (for true) if the "variable" attribute of @p ea
- * is set, zero (0) otherwise.
- */
 LIBSBML_EXTERN
 int
 EventAssignment_isSetMath (const EventAssignment_t *ea)
@@ -1156,24 +1052,6 @@ EventAssignment_isSetMath (const EventAssignment_t *ea)
 }
 
 
-/**
- * Sets the attribute "variable" of the given EventAssignment_t structure
- * to a copy of the given identifier string.
- *
- * @param ea the EventAssignment_t to set.
- * @param sid the identifier of a Compartment, Species or (global)
- * Parameter defined in this model.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with an id of NULL is equivalent to
- * unsetting the "variable" attribute.
- */
 LIBSBML_EXTERN
 int
 EventAssignment_setVariable (EventAssignment_t *ea, const char *sid)
@@ -1185,22 +1063,17 @@ EventAssignment_setVariable (EventAssignment_t *ea, const char *sid)
 }
 
 
-/**
- * Sets the "math" subelement content of the given EventAssignment_t
- * structure to the given ASTNode.
- *
- * The given @p math ASTNode is copied.
- *
- * @param ea the EventAssignment_t to set.
- * @param math the ASTNode to copy into @p ea
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_OBJECT
- */
+LIBSBML_EXTERN
+int
+EventAssignment_unsetVariable (EventAssignment_t *ea)
+{
+  if (ea != NULL)  
+    return ea->unsetVariable();
+  else
+    return LIBSBML_INVALID_OBJECT;
+}
+
+
 LIBSBML_EXTERN
 int
 EventAssignment_setMath (EventAssignment_t *ea, const ASTNode_t *math)
@@ -1211,26 +1084,6 @@ EventAssignment_setMath (EventAssignment_t *ea, const ASTNode_t *math)
     return LIBSBML_INVALID_OBJECT;
 }
 
-/**
-  * Calculates and returns a UnitDefinition_t that expresses the units
-  * returned by the math expression of this EventAssignment_t.
-  *
-  * @return a UnitDefinition_t that expresses the units of the math 
-  * expression of this EventAssignment_t.
-  *
-  * Note that the functionality that facilitates unit analysis depends 
-  * on the model as a whole.  Thus, in cases where the object has not 
-  * been added to a model or the model itself is incomplete,
-  * unit analysis is not possible and this method will return @c NULL.
-  *
-  * @note The units are calculated by applying the mathematics 
-  * from the expression to the units of the &lt;ci&gt; elements used 
-  * within the expression. Where there are parameters/numbers
-  * with undeclared units the UnitDefinition_t returned by this
-  * function may not accurately represent the units of the expression.
-  *
-  * @see EventAssignment_containsUndeclaredUnits()
-  */
 LIBSBML_EXTERN
 UnitDefinition_t * 
 EventAssignment_getDerivedUnitDefinition(EventAssignment_t *ea)
@@ -1239,21 +1092,6 @@ EventAssignment_getDerivedUnitDefinition(EventAssignment_t *ea)
 }
 
 
-/**
-  * Predicate returning @c true or @c false depending on whether 
-  * the math expression of this EventAssignment_t contains
-  * parameters/numbers with undeclared units.
-  * 
-  * @return @c true if the math expression of this EventAssignment_t
-  * includes parameters/numbers 
-  * with undeclared units, @c false otherwise.
-  *
-  * @note a return value of @c true indicates that the UnitDefinition_t
-  * returned by the getDerivedUnitDefinition function may not 
-  * accurately represent the units of the expression.
-  *
-  * @see EventAssignment_getDerivedUnitDefinition()
-  */
 LIBSBML_EXTERN
 int 
 EventAssignment_containsUndeclaredUnits(EventAssignment_t *ea)
@@ -1262,10 +1100,6 @@ EventAssignment_containsUndeclaredUnits(EventAssignment_t *ea)
 }
 
 
-/**
- * @return item in this ListOfEventAssignment with the given @p id or @c NULL if no such
- * item exists.
- */
 LIBSBML_EXTERN
 EventAssignment_t *
 ListOfEventAssignments_getById (ListOf_t *lo, const char *sid)
@@ -1278,11 +1112,6 @@ ListOfEventAssignments_getById (ListOf_t *lo, const char *sid)
 }
 
 
-/**
- * Removes item in this ListOf items with the given @p id or @c NULL if no such
- * item exists.  The caller owns the returned item and is responsible for
- * deleting it.
- */
 LIBSBML_EXTERN
 EventAssignment_t *
 ListOfEventAssignments_removeById (ListOf_t *lo, const char *sid)
@@ -1293,7 +1122,6 @@ ListOfEventAssignments_removeById (ListOf_t *lo, const char *sid)
   else
     return NULL;
 }
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
