@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -49,9 +49,7 @@
 #include <sbml/Model.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -97,23 +95,17 @@ FunctionDefinition::~FunctionDefinition ()
  */
 FunctionDefinition::FunctionDefinition (const FunctionDefinition& orig) :
    SBase             ( orig         )
- , mMath             ( NULL            )
+ , mId               ( orig.mId     )
+ , mName             ( orig.mName   )
+ , mMath             ( NULL         )
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mId               = orig.mId;
-    mName             = orig.mName;
   
-    if (orig.mMath != NULL) 
-    {
-      mMath = orig.mMath->deepCopy();
-      mMath->setParentSBMLObject(this);
-    }
+  if (orig.mMath != NULL) 
+  {
+    mMath = orig.mMath->deepCopy();
+    mMath->setParentSBMLObject(this);
   }
+  
 }
 
 
@@ -122,11 +114,7 @@ FunctionDefinition::FunctionDefinition (const FunctionDefinition& orig) :
  */
 FunctionDefinition& FunctionDefinition::operator=(const FunctionDefinition& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->SBase::operator =(rhs);
     mId = rhs.mId;
@@ -148,18 +136,13 @@ FunctionDefinition& FunctionDefinition::operator=(const FunctionDefinition& rhs)
 }
 
 
-/*
- * Accepts the given SBMLVisitor.
- *
- * @return the result of calling <code>v.visit()</code>, which indicates
- * whether or not the Visitor would like to visit the Model's next
- * FunctionDefinition (if available).
- */
+/** @cond doxygenLibsbmlInternal */
 bool
 FunctionDefinition::accept (SBMLVisitor& v) const
 {
   return v.visit(*this);
 }
+/** @endcond */
 
 
 /*
@@ -250,11 +233,7 @@ FunctionDefinition::setId (const std::string& sid)
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
   }
 */
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(sid)))
+  if (!(SyntaxChecker::isValidInternalSId(sid)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -275,11 +254,7 @@ FunctionDefinition::setName (const std::string& name)
   /* if this is setting an L2 name the type is string
    * whereas if it is setting an L1 name its type is SId
    */
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (getLevel() == 1)
+  if (getLevel() == 1)
   {
     if (!(SyntaxChecker::isValidInternalSId(name)))
     {
@@ -798,7 +773,8 @@ FunctionDefinition::readL2Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("id", level, version, "<functionDefinition>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
   //
   // name: string  { use="optional" }  (L2v1 ->)
@@ -842,7 +818,8 @@ FunctionDefinition::readL3Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("id", level, version, "<functionDefinition>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
   //
   // name: string  { use="optional" }  (L2v1 ->)
@@ -1018,16 +995,10 @@ ListOfFunctionDefinitions::get (const std::string& sid) const
 {
   vector<SBase*>::const_iterator result;
 
-  if (&(sid) == NULL)
-  {
-    return NULL;
-  }
-  else
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqFD(sid) );
-    return (result == mItems.end()) ? NULL : 
-                               static_cast <FunctionDefinition*> (*result);
-  }
+  result = find_if( mItems.begin(), mItems.end(), IdEqFD(sid) );
+  return (result == mItems.end()) ? NULL : 
+                             static_cast <FunctionDefinition*> (*result);
+
 }
 
 
@@ -1046,15 +1017,12 @@ ListOfFunctionDefinitions::remove (const std::string& sid)
   SBase* item = NULL;
   vector<SBase*>::iterator result;
 
-  if (&(sid) != NULL)
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqFD(sid) );
+  result = find_if( mItems.begin(), mItems.end(), IdEqFD(sid) );
 
-    if (result != mItems.end())
-    {
-      item = *result;
-      mItems.erase(result);
-    }
+  if (result != mItems.end())
+  {
+    item = *result;
+    mItems.erase(result);
   }
 
   return static_cast <FunctionDefinition*> (item);
@@ -1113,7 +1081,6 @@ ListOfFunctionDefinitions::createObject (XMLInputStream& stream)
 
 #endif /* __cplusplus */
 /** @cond doxygenIgnored */
-
 LIBSBML_EXTERN
 FunctionDefinition_t *
 FunctionDefinition_create (unsigned int level, unsigned int version)
@@ -1327,7 +1294,6 @@ ListOfFunctionDefinitions_removeById (ListOf_t *lo, const char *sid)
   else
     return NULL;
 }
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
