@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2015 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -41,9 +46,7 @@
 #include <sbml/LocalParameter.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -64,7 +67,7 @@ LocalParameter::LocalParameter (unsigned int level, unsigned int version) :
 
 
 LocalParameter::LocalParameter (SBMLNamespaces * sbmlns) :
-   Parameter ( sbmlns )
+   Parameter ( sbmlns,  true)
 {
   if (!hasValidLevelVersionNamespaceCombination())
   {
@@ -95,10 +98,6 @@ LocalParameter::~LocalParameter ()
 LocalParameter::LocalParameter(const LocalParameter& orig) :
     Parameter      ( orig             )
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
 }
 
 
@@ -107,22 +106,14 @@ LocalParameter::LocalParameter(const LocalParameter& orig) :
  */
 LocalParameter::LocalParameter(const Parameter& orig) :
     Parameter      ( orig             )
-{
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
+{  
 }
 /*
  * Assignment operator.
  */
 LocalParameter& LocalParameter::operator=(const LocalParameter& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->Parameter::operator =(rhs);
   }
@@ -131,18 +122,13 @@ LocalParameter& LocalParameter::operator=(const LocalParameter& rhs)
 }
 
 
-/*
- * Accepts the given SBMLVisitor.
- *
- * @return the result of calling <code>v.visit()</code>, which indicates
- * whether or not the Visitor would like to visit the parent Model's or
- * KineticLaw's next LocalParameter (if available).
- */
+/** @cond doxygenLibsbmlInternal */
 bool
 LocalParameter::accept (SBMLVisitor& v) const
 {
   return v.visit(*this);
 }
+/** @endcond */
 
 
 /*
@@ -155,6 +141,54 @@ LocalParameter::clone () const
 }
 
 
+/* a local Parameter does not have a constant attribute but
+ * because it derives from parameter it inherits one
+ * need to make sure these do the right thing
+ */
+
+/** @cond doxygenLibsbmlInternal */
+/*
+ * @return true as a localParameter is always constant.
+ */
+bool
+LocalParameter::getConstant () const
+{
+  return true;
+}
+/** @endcond */
+
+
+/** @cond doxygenLibsbmlInternal */
+/*
+ * @return false as a local parameter does not have this attribute
+ */
+bool
+LocalParameter::isSetConstant () const
+{
+  return false;
+}
+/** @endcond */
+
+
+/** @cond doxygenLibsbmlInternal */
+/*
+ * Sets the constant field of this Parameter to value.
+ */
+int
+LocalParameter::setConstant (bool flag)
+{
+  return LIBSBML_UNEXPECTED_ATTRIBUTE;
+}
+/** @endcond */
+
+
+/** @cond doxygenLibsbmlInternal */
+int
+LocalParameter::unsetConstant ()
+{
+  return LIBSBML_UNEXPECTED_ATTRIBUTE;
+}
+/** @endcond */
 /*
   * Constructs and returns a UnitDefinition that expresses the units of this 
   * LocalParameter.
@@ -362,16 +396,10 @@ ListOfLocalParameters::get (const std::string& sid) const
 {
   vector<SBase*>::const_iterator result;
 
-  if (&(sid) == NULL)
-  {
-    return NULL;
-  }
-  else
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqP(sid) );
-    return (result == mItems.end()) ? NULL : 
-                             static_cast <LocalParameter*> (*result);
-  }
+  result = find_if( mItems.begin(), mItems.end(), IdEqP(sid) );
+  return (result == mItems.end()) ? NULL : 
+                           static_cast <LocalParameter*> (*result);
+  
 }
 
 
@@ -404,15 +432,12 @@ ListOfLocalParameters::remove (const std::string& sid)
   SBase* item = NULL;
   vector<SBase*>::iterator result;
 
-  if (&(sid) != NULL)
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqP(sid) );
+  result = find_if( mItems.begin(), mItems.end(), IdEqP(sid) );
 
-    if (result != mItems.end())
-    {
-      item = *result;
-      mItems.erase(result);
-    }
+  if (result != mItems.end())
+  {
+    item = *result;
+    mItems.erase(result);
   }
 
   return static_cast <LocalParameter*> (item);
@@ -472,29 +497,7 @@ ListOfLocalParameters::createObject (XMLInputStream& stream)
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
-
-
-/**
- * Creates a new LocalParameter_t structure using the given SBML @p level
- * and @p version values.
- *
- * @param level an unsigned int, the SBML Level to assign to this
- * LocalParameter
- *
- * @param version an unsigned int, the SBML Version to assign to this
- * LocalParameter
- *
- * @return a pointer to the newly created LocalParameter_t structure.
- *
- * @note Once a LocalParameter has been added to an SBMLDocument, the @p
- * level and @p version for the document @em override those used to create
- * the LocalParameter.  Despite this, the ability to supply the values at
- * creation time is an important aid to creating valid SBML.  Knowledge of
- * the intended SBML Level and Version  determine whether it is valid to
- * assign a particular value to an attribute, or whether it is valid to add
- * an object to an existing SBMLDocument.
- */
+/** @cond doxygenIgnored */
 LIBSBML_EXTERN
 LocalParameter_t *
 LocalParameter_create (unsigned int level, unsigned int version)
@@ -511,23 +514,6 @@ LocalParameter_create (unsigned int level, unsigned int version)
 }
 
 
-/**
- * Creates a new LocalParameter_t structure using the given
- * SBMLNamespaces_t structure.
- *
- * @param sbmlns SBMLNamespaces, a pointer to an SBMLNamespaces structure
- * to assign to this LocalParameter
- *
- * @return a pointer to the newly created LocalParameter_t structure.
- *
- * @note Once a LocalParameter has been added to an SBMLDocument, the
- * @p sbmlns namespaces for the document @em override those used to create
- * the LocalParameter.  Despite this, the ability to supply the values at creation time
- * is an important aid to creating valid SBML.  Knowledge of the intended SBML
- * Level and Version determine whether it is valid to assign a particular value
- * to an attribute, or whether it is valid to add an object to an existing
- * SBMLDocument.
- */
 LIBSBML_EXTERN
 LocalParameter_t *
 LocalParameter_createWithNS (SBMLNamespaces_t* sbmlns)
@@ -544,11 +530,6 @@ LocalParameter_createWithNS (SBMLNamespaces_t* sbmlns)
 }
 
 
-/**
- * Frees the given LocalParameter_t structure.
- *
- * @param p the LocalParameter_t structure to be freed.
- */
 LIBSBML_EXTERN
 void
 LocalParameter_free (LocalParameter_t *p)
@@ -558,13 +539,6 @@ LocalParameter_free (LocalParameter_t *p)
 }
 
 
-/**
- * Creates a deep copy of the given LocalParameter_t structure
- * 
- * @param p the LocalParameter_t structure to be copied
- * 
- * @return a (deep) copy of the given LocalParameter_t structure.
- */
 LIBSBML_EXTERN
 LocalParameter_t *
 LocalParameter_clone (const LocalParameter_t *p)
@@ -573,15 +547,13 @@ LocalParameter_clone (const LocalParameter_t *p)
 }
 
 
-/**
- * Returns a list of XMLNamespaces_t associated with this LocalParameter_t
- * structure.
- *
- * @param p the LocalParameter_t structure
- * 
- * @return pointer to the XMLNamespaces_t structure associated with 
- * this SBML object
- */
+LIBSBML_EXTERN
+void
+LocalParameter_initDefaults (LocalParameter_t *p)
+{
+  return;
+}
+
 LIBSBML_EXTERN
 const XMLNamespaces_t *
 LocalParameter_getNamespaces(LocalParameter_t *p)
@@ -589,13 +561,6 @@ LocalParameter_getNamespaces(LocalParameter_t *p)
   return (p != NULL) ? p->getNamespaces() : NULL;
 }
 
-/**
- * Takes a LocalParameter_t structure and returns its identifier.
- *
- * @param p the LocalParameter_t structure whose identifier is sought
- * 
- * @return the identifier of this LocalParameter_t, as a pointer to a string.
- */
 LIBSBML_EXTERN
 const char *
 LocalParameter_getId (const LocalParameter_t *p)
@@ -604,13 +569,6 @@ LocalParameter_getId (const LocalParameter_t *p)
 }
 
 
-/**
- * Takes a LocalParameter_t structure and returns its name.
- *
- * @param p the LocalParameter_t whose name is sought.
- *
- * @return the name of this LocalParameter_t, as a pointer to a string.
- */
 LIBSBML_EXTERN
 const char *
 LocalParameter_getName (const LocalParameter_t *p)
@@ -619,13 +577,6 @@ LocalParameter_getName (const LocalParameter_t *p)
 }
 
 
-/**
- * Takes a LocalParameter_t structure and returns its value.
- *
- * @param p the LocalParameter_t whose value is sought.
- *
- * @return the value assigned to this LocalParameter_t structure, as a @c double.
- */
 LIBSBML_EXTERN
 double
 LocalParameter_getValue (const LocalParameter_t *p)
@@ -634,14 +585,6 @@ LocalParameter_getValue (const LocalParameter_t *p)
 }
 
 
-/**
- * Takes a LocalParameter_t structure and returns its units.
- *
- * @param p the LocalParameter_t whose units are sought.
- *
- * @return the units assigned to this LocalParameter_t structure, as a pointer
- * to a string.  
- */
 LIBSBML_EXTERN
 const char *
 LocalParameter_getUnits (const LocalParameter_t *p)
@@ -650,15 +593,14 @@ LocalParameter_getUnits (const LocalParameter_t *p)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * LocalParameter_t structure's identifier is set.
- *
- * @param p the LocalParameter_t structure to query
- * 
- * @return @c non-zero (true) if the "id" attribute of the given
- * LocalParameter_t structure is set, zero (false) otherwise.
- */
+LIBSBML_EXTERN
+int
+LocalParameter_getConstant (const LocalParameter_t *p)
+{
+  return (p != NULL) ?  static_cast<int>( p->getConstant() ) : 0;
+}
+
+
 LIBSBML_EXTERN
 int
 LocalParameter_isSetId (const LocalParameter_t *p)
@@ -667,15 +609,6 @@ LocalParameter_isSetId (const LocalParameter_t *p)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * LocalParameter_t structure's name is set.
- *
- * @param p the LocalParameter_t structure to query
- * 
- * @return @c non-zero (true) if the "name" attribute of the given
- * LocalParameter_t structure is set, zero (false) otherwise.
- */
 LIBSBML_EXTERN
 int
 LocalParameter_isSetName (const LocalParameter_t *p)
@@ -684,19 +617,6 @@ LocalParameter_isSetName (const LocalParameter_t *p)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * LocalParameter_t structure's value is set.
- * 
- * @param p the LocalParameter_t structure to query
- * 
- * @return @c non-zero (true) if the "value" attribute of the given
- * LocalParameter_t structure is set, zero (false) otherwise.
- *
- * @note In SBML Level 1 Version 1, a LocalParameter value is required and
- * therefore <em>should always be set</em>.  In Level 1 Version 2 and
- * later, the value is optional, and as such, may or may not be set.
- */
 LIBSBML_EXTERN
 int
 LocalParameter_isSetValue (const LocalParameter_t *p)
@@ -705,15 +625,6 @@ LocalParameter_isSetValue (const LocalParameter_t *p)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * LocalParameter_t structure's units have been set.
- *
- * @param p the LocalParameter_t structure to query
- * 
- * @return @c non-zero (true) if the "units" attribute of the given
- * LocalParameter_t structure is set, zero (false) otherwise.
- */
 LIBSBML_EXTERN
 int
 LocalParameter_isSetUnits (const LocalParameter_t *p)
@@ -722,24 +633,6 @@ LocalParameter_isSetUnits (const LocalParameter_t *p)
 }
 
 
-/**
- * Assigns the identifier of a LocalParameter_t structure.
- *
- * This makes a copy of the string passed in the param @p sid.
- *
- * @param p the LocalParameter_t structure to set.
- * @param sid the string to use as the identifier.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with an id of NULL is equivalent to
- * unsetting the "id" attribute.
- */
 LIBSBML_EXTERN
 int
 LocalParameter_setId (LocalParameter_t *p, const char *sid)
@@ -751,24 +644,6 @@ LocalParameter_setId (LocalParameter_t *p, const char *sid)
 }
 
 
-/**
- * Assign the name of a LocalParameter_t structure.
- *
- * This makes a copy of the string passed in as the argument @p name.
- *
- * @param p the LocalParameter_t structure to set.
- * @param name the string to use as the name.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with the name set to NULL is equivalent to
- * unsetting the "name" attribute.
- */
 LIBSBML_EXTERN
 int
 LocalParameter_setName (LocalParameter_t *p, const char *name)
@@ -780,18 +655,6 @@ LocalParameter_setName (LocalParameter_t *p, const char *name)
 }
 
 
-/**
- * Assign the value of a LocalParameter_t structure.
- *
- * @param p the LocalParameter_t structure to set.
- * @param value the @c double value to use.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- */
 LIBSBML_EXTERN
 int
 LocalParameter_setValue (LocalParameter_t *p, double value)
@@ -803,24 +666,6 @@ LocalParameter_setValue (LocalParameter_t *p, double value)
 }
 
 
-/**
- * Assign the units of a LocalParameter_t structure.
- *
- * This makes a copy of the string passed in as the argument @p units.
- *
- * @param p the LocalParameter_t structure to set.
- * @param units the string to use as the identifier of the units to assign.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with units set to NULL is equivalent to
- * unsetting the "units" attribute.
- */
 LIBSBML_EXTERN
 int
 LocalParameter_setUnits (LocalParameter_t *p, const char *units)
@@ -832,18 +677,16 @@ LocalParameter_setUnits (LocalParameter_t *p, const char *units)
 }
 
 
-/**
- * Unsets the name of this LocalParameter_t structure.
- * 
- * @param p the LocalParameter_t structure whose name is to be unset.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_OPERATION_FAILED
- */
+LIBSBML_EXTERN
+int
+LocalParameter_setConstant (LocalParameter_t *p, int value)
+{
+  if (p != NULL)
+    return p->setConstant( static_cast<bool>(value) );
+  else
+    return LIBSBML_INVALID_OBJECT;
+}
+
 LIBSBML_EXTERN
 int
 LocalParameter_unsetName (LocalParameter_t *p)
@@ -855,22 +698,6 @@ LocalParameter_unsetName (LocalParameter_t *p)
 }
 
 
-/**
- * Unsets the value of this LocalParameter_t structure.
- *
- * In SBML Level 1 Version 1, a parameter is required to have a value and
- * therefore this attribute <em>should always be set</em>.  In Level 1
- * Version 2 and beyond, a value is optional, and as such, may or may not be
- * set.
- *
- * @param p the LocalParameter_t structure whose value is to be unset.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- */
 LIBSBML_EXTERN
 int
 LocalParameter_unsetValue (LocalParameter_t *p)
@@ -882,18 +709,6 @@ LocalParameter_unsetValue (LocalParameter_t *p)
 }
 
 
-/**
- * Unsets the units of this LocalParameter_t structure.
- * 
- * @param p the LocalParameter_t structure whose units are to be unset.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_OPERATION_FAILED
- */
 LIBSBML_EXTERN
 int
 LocalParameter_unsetUnits (LocalParameter_t *p)
@@ -905,19 +720,17 @@ LocalParameter_unsetUnits (LocalParameter_t *p)
 }
 
 
-/**
-  * Predicate returning @c true or @c false depending on whether
-  * all the required attributes for this LocalParameter object
-  * have been set.
-  *
- * @param p the LocalParameter_t structure to check.
- *
-  * @note The required attributes for a LocalParameter object are:
-  * @li id (name in L1)
-  *
-  * @return a true if all the required
-  * attributes for this object have been defined, false otherwise.
-  */
+LIBSBML_EXTERN
+int
+LocalParameter_unsetConstant (LocalParameter_t *p)
+{
+  if (p != NULL)
+    return p->unsetConstant();
+  else
+    return LIBSBML_INVALID_OBJECT;
+}
+
+
 LIBSBML_EXTERN
 int
 LocalParameter_hasRequiredAttributes(LocalParameter_t *p)
@@ -926,19 +739,6 @@ LocalParameter_hasRequiredAttributes(LocalParameter_t *p)
 }
 
 
-/**
- * Constructs and returns a UnitDefinition_t structure that expresses 
- * the units of this LocalParameter_t structure.
- *
- * @param p the LocalParameter_t structure whose units are to be returned.
- *
- * @return a UnitDefinition_t structure that expresses the units 
- * of this LocalParameter_t strucuture.
- *
- * @note This function returns the units of the LocalParameter_t expressed 
- * as a UnitDefinition_t. The units may be those explicitly declared. 
- * In the case where no units have been declared, @c NULL is returned.
- */
 LIBSBML_EXTERN
 UnitDefinition_t * 
 LocalParameter_getDerivedUnitDefinition(LocalParameter_t *p)
@@ -947,10 +747,6 @@ LocalParameter_getDerivedUnitDefinition(LocalParameter_t *p)
 }
 
 
-/**
- * @return item in this ListOfLocalParameter with the given @p id or @c NULL if no such
- * item exists.
- */
 LIBSBML_EXTERN
 LocalParameter_t *
 ListOfLocalParameters_getById (ListOf_t *lo, const char *sid)
@@ -963,11 +759,6 @@ ListOfLocalParameters_getById (ListOf_t *lo, const char *sid)
 }
 
 
-/**
- * Removes item in this ListOf items with the given @p id or @c NULL if no such
- * item exists.  The caller owns the returned item and is responsible for
- * deleting it.
- */
 LIBSBML_EXTERN
 LocalParameter_t *
 ListOfLocalParameters_removeById (ListOf_t *lo, const char *sid)
@@ -978,6 +769,5 @@ ListOfLocalParameters_removeById (ListOf_t *lo, const char *sid)
   else
     return NULL;
 }
-
 /** @endcond */
 LIBSBML_CPP_NAMESPACE_END
