@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -46,9 +46,7 @@
 #include <sbml/Parameter.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -149,25 +147,19 @@ Parameter::~Parameter ()
 /*
  * Copy constructor. Creates a copy of this Parameter.
  */
-Parameter::Parameter(const Parameter& orig) :
-    SBase      ( orig             )
+Parameter::Parameter(const Parameter& orig)
+  :  SBase      ( orig             )
+  ,  mId        (orig.mId)
+  ,  mName      (orig.mName)
+  ,  mValue     (orig.mValue)
+  ,  mUnits     (orig.mUnits)
+  ,  mConstant  (orig.mConstant)
+  ,  mIsSetValue (orig.mIsSetValue)
+  ,  mIsSetConstant (orig.mIsSetConstant)
+  ,  mExplicitlySetConstant (orig.mExplicitlySetConstant)
+  ,  mCalculatingUnits (false) // only set by units converter
+  
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mValue         = orig.mValue    ;
-    mUnits         = orig.mUnits    ;
-    mConstant      = orig.mConstant ;
-    mIsSetValue    = orig.mIsSetValue;
-    mId            = orig.mId;
-    mName          = orig.mName;
-    mIsSetConstant = orig.mIsSetConstant;
-    mExplicitlySetConstant = orig.mExplicitlySetConstant;
-    mCalculatingUnits = false; // only set by units converter
-  }
 }
 
 
@@ -176,11 +168,7 @@ Parameter::Parameter(const Parameter& orig) :
  */
 Parameter& Parameter::operator=(const Parameter& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->SBase::operator =(rhs);
     mValue      = rhs.mValue    ;
@@ -198,18 +186,13 @@ Parameter& Parameter::operator=(const Parameter& rhs)
 }
 
 
-/*
- * Accepts the given SBMLVisitor.
- *
- * @return the result of calling <code>v.visit()</code>, which indicates
- * whether or not the Visitor would like to visit the parent Model's or
- * KineticLaw's next Parameter (if available).
- */
+/** @cond doxygenLibsbmlInternal */
 bool
 Parameter::accept (SBMLVisitor& v) const
 {
   return v.visit(*this);
 }
+/** @endcond */
 
 
 /*
@@ -230,11 +213,9 @@ Parameter::clone () const
 void
 Parameter::initDefaults ()
 {
-  //// level 3 has no defaults
-  //if (getLevel() < 3)
-  //{
-    setConstant(true);
-  //}
+  setConstant(true);
+  // not explicitly set
+  mExplicitlySetConstant = false;
 }
 
 
@@ -363,11 +344,7 @@ Parameter::setId (const std::string& sid)
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
   }
 */
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(sid)))
+  if (!(SyntaxChecker::isValidInternalSId(sid)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -388,11 +365,7 @@ Parameter::setName (const std::string& name)
   /* if this is setting an L2 name the type is string
    * whereas if it is setting an L1 name its type is SId
    */
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (getLevel() == 1)
+  if (getLevel() == 1)
   {
     if (!(SyntaxChecker::isValidInternalSId(name)))
     {
@@ -430,11 +403,7 @@ Parameter::setValue (double value)
 int
 Parameter::setUnits (const std::string& units)
 {
-  if (&(units) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else  if (!(SyntaxChecker::isValidInternalUnitSId(units)))
+  if (!(SyntaxChecker::isValidInternalUnitSId(units)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -497,6 +466,31 @@ Parameter::unsetName ()
 }
 
 
+int
+Parameter::unsetConstant ()
+{
+  if ( getLevel() < 2 )
+  {
+    mConstant = false;
+    return LIBSBML_UNEXPECTED_ATTRIBUTE;
+  }
+  else if (getLevel() == 2)
+  {
+    // reset default
+    mConstant = true;
+    mExplicitlySetConstant = false;
+    mIsSetConstant = true;
+    return LIBSBML_UNEXPECTED_ATTRIBUTE;
+  }
+  else
+  {
+    mIsSetConstant = false;
+    mExplicitlySetConstant = false;
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+}
+
+
 /*
  * Unsets the value of this Parameter.
  *
@@ -809,7 +803,8 @@ Parameter::readL1Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("name", level, version, "<parameter>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
   //
   // value: double  { use="required" }  (L1v2)
@@ -834,7 +829,7 @@ Parameter::readL1Attributes (const XMLAttributes& attributes)
   }
   if (!SyntaxChecker::isValidInternalUnitSId(mUnits))
   {
-    logError(InvalidUnitIdSyntax);
+    logError(InvalidUnitIdSyntax, getLevel(), getVersion(), "The units attribute '" + mUnits + "' does not conform to the syntax.");
   }
 }
 /** @endcond */
@@ -861,7 +856,8 @@ Parameter::readL2Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("id", level, version, "<parameter>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
   //
   // value: double  { use="optional" }  (L1v2->)
@@ -878,7 +874,7 @@ Parameter::readL2Attributes (const XMLAttributes& attributes)
   }
   if (!SyntaxChecker::isValidInternalUnitSId(mUnits))
   {
-    logError(InvalidUnitIdSyntax);
+    logError(InvalidUnitIdSyntax, getLevel(), getVersion(), "The units attribute '" + mUnits + "' does not conform to the syntax.");
   }
 
   //
@@ -936,8 +932,13 @@ Parameter::readL3Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("id", level, version, "<parameter>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
+  string elplusid = "<" + getElementName() + ">";
+  if (!mId.empty()) {
+    elplusid += " with the id '" + mId + "'";
+  }
   //
   // value: double  { use="optional" }  (L1v2->)
   //
@@ -953,7 +954,9 @@ Parameter::readL3Attributes (const XMLAttributes& attributes)
   }
   if (!SyntaxChecker::isValidInternalUnitSId(mUnits))
   {
-    logError(InvalidUnitIdSyntax);
+    logError(InvalidUnitIdSyntax, level, version, "The " + elplusid + 
+      " has a substanceUnits with a value of '" + mUnits 
+      + "' which does not conform .");
   }
 
   //
@@ -968,7 +971,8 @@ Parameter::readL3Attributes (const XMLAttributes& attributes)
     if (!mIsSetConstant)
     {
       logError(AllowedAttributesOnParameter, level, version, 
-        "The required attribute 'constant' is missing.");
+        "The required attribute 'constant' is missing from the "
+             + elplusid + ".");
     }
   }
 }
@@ -1080,27 +1084,22 @@ Parameter::writeAttributes (XMLOutputStream& stream) const
 
 /* private functions used for inferring units */
 /** @cond doxygenLibsbmlInternal */
-
 void
 Parameter::setCalculatingUnits(bool calculatingUnits)
 {
   mCalculatingUnits = calculatingUnits;
 }
-
 /** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
-
 bool
 Parameter::getCalculatingUnits() const
 {
   return mCalculatingUnits;
 }
-
 /** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
-
 UnitDefinition *
 Parameter::inferUnits(Model* m, bool globalParameter)
 {
@@ -1140,12 +1139,9 @@ Parameter::inferUnits(Model* m, bool globalParameter)
   delete uff;
   return derivedUD;
 }
-
-
 /** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
-
 UnitDefinition *
 Parameter::inferUnitsFromRules(UnitFormulaFormatter *uff, Model *m)
 {
@@ -1206,12 +1202,9 @@ Parameter::inferUnitsFromRules(UnitFormulaFormatter *uff, Model *m)
 
   return derivedUD;
 }
-
-
 /** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
-
 UnitDefinition *
 Parameter::inferUnitsFromAssignments(UnitFormulaFormatter *uff, Model *m)
 {
@@ -1262,12 +1255,9 @@ Parameter::inferUnitsFromAssignments(UnitFormulaFormatter *uff, Model *m)
 
   return derivedUD;
 }
-
-
 /** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
-
 UnitDefinition *
 Parameter::inferUnitsFromReactions(UnitFormulaFormatter *uff, Model *m)
 {
@@ -1289,11 +1279,9 @@ Parameter::inferUnitsFromReactions(UnitFormulaFormatter *uff, Model *m)
 
   return derivedUD;
 }
-
 /** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
-
 UnitDefinition *
 Parameter::inferUnitsFromEvents(UnitFormulaFormatter *uff, Model *m)
 {
@@ -1312,11 +1300,9 @@ Parameter::inferUnitsFromEvents(UnitFormulaFormatter *uff, Model *m)
 
   return derivedUD;
 }
-
 /** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
-
 UnitDefinition *
 Parameter::inferUnitsFromEvent(Event * e, UnitFormulaFormatter *uff, Model *m)
 {
@@ -1398,11 +1384,9 @@ Parameter::inferUnitsFromEvent(Event * e, UnitFormulaFormatter *uff, Model *m)
 
   return derivedUD;
 }
-
 /** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
-
 UnitDefinition *
 Parameter::inferUnitsFromKineticLaw(KineticLaw* kl, 
                                     UnitFormulaFormatter *uff, Model *m)
@@ -1449,7 +1433,6 @@ Parameter::inferUnitsFromKineticLaw(KineticLaw* kl,
 
   return derivedUD;
 }
-
 /** @endcond */
 
 /*
@@ -1545,15 +1528,8 @@ ListOfParameters::get (const std::string& sid) const
 {
   vector<SBase*>::const_iterator result;
 
-  if (&(sid) == NULL)
-  {
-    return NULL;
-  }
-  else
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqP(sid) );
-    return (result == mItems.end()) ? NULL : static_cast <Parameter*> (*result);
-  }
+  result = find_if( mItems.begin(), mItems.end(), IdEqP(sid) );
+  return (result == mItems.end()) ? NULL : static_cast <Parameter*> (*result);
 }
 
 
@@ -1572,15 +1548,12 @@ ListOfParameters::remove (const std::string& sid)
   SBase* item = NULL;
   vector<SBase*>::iterator result;
 
-  if (&(sid) != NULL)
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqP(sid) );
+  result = find_if( mItems.begin(), mItems.end(), IdEqP(sid) );
 
-    if (result != mItems.end())
-    {
-      item = *result;
-      mItems.erase(result);
-    }
+  if (result != mItems.end())
+  {
+    item = *result;
+    mItems.erase(result);
   }
 
   return static_cast <Parameter*> (item);
@@ -1641,8 +1614,6 @@ ListOfParameters::createObject (XMLInputStream& stream)
 
 #endif /* __cplusplus */
 /** @cond doxygenIgnored */
-
-
 LIBSBML_EXTERN
 Parameter_t *
 Parameter_create (unsigned int level, unsigned int version)
@@ -1853,6 +1824,17 @@ Parameter_unsetName (Parameter_t *p)
 }
 
 
+LIBSBML_EXTERN
+int
+Parameter_unsetConstant (Parameter_t *c)
+{
+  if (c != NULL)
+    return c->unsetConstant();
+  else
+    return LIBSBML_INVALID_OBJECT;
+}
+
+
 LIBSBML_EXTERN
 int
 Parameter_unsetValue (Parameter_t *p)
@@ -1913,6 +1895,5 @@ ListOfParameters_removeById (ListOf_t *lo, const char *sid)
   else
     return NULL;
 }
-
 /** @endcond */
 LIBSBML_CPP_NAMESPACE_END
