@@ -49,9 +49,7 @@
 #include <sbml/util/ElementFilter.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -175,33 +173,25 @@ Reaction::~Reaction ()
 /*
  * Copy constructor. Creates a copy of this Reaction.
  */
-Reaction::Reaction (const Reaction& orig) :
-    SBase      ( orig )
+Reaction::Reaction (const Reaction& orig)
+  : SBase      ( orig )
+  , mId        ( orig.mId )
+  , mName      ( orig.mName )
   , mReactants ( orig.mReactants  )
   , mProducts  ( orig.mProducts   )
   , mModifiers ( orig.mModifiers  )
   , mKineticLaw( NULL    )
-{
-  if (&orig == NULL)
+  , mReversible( orig.mReversible )
+  , mFast      ( orig.mFast       )
+  , mIsSetFast ( orig.mIsSetFast  )
+  , mCompartment ( orig.mCompartment )
+  , mIsSetReversible ( orig.mIsSetReversible )
+  , mExplicitlySetReversible ( orig.mExplicitlySetReversible )
+  , mExplicitlySetFast       ( orig.mExplicitlySetFast )
+{  
+  if (orig.mKineticLaw != NULL)
   {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mReversible      = orig.mReversible ;
-    mFast            = orig.mFast       ;
-    mIsSetFast       = orig.mIsSetFast  ;
-    mId              = orig.mId;
-    mName            = orig.mName;
-    mCompartment     = orig.mCompartment;
-    mIsSetReversible = orig.mIsSetReversible;
-    mExplicitlySetReversible = orig.mExplicitlySetReversible;
-    mExplicitlySetFast       = orig.mExplicitlySetFast;
-
-    if (orig.mKineticLaw != NULL)
-    {
-      mKineticLaw = static_cast<KineticLaw*>( orig.mKineticLaw->clone() );
-    }
+    mKineticLaw = static_cast<KineticLaw*>( orig.mKineticLaw->clone() );
   }
   connectToChild();
 }
@@ -212,11 +202,7 @@ Reaction::Reaction (const Reaction& orig) :
  */
 Reaction& Reaction::operator=(const Reaction& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->SBase::operator =(rhs);
     mReversible = rhs.mReversible ;
@@ -249,13 +235,7 @@ Reaction& Reaction::operator=(const Reaction& rhs)
 }
 
 
-/*
- * Accepts the given SBMLVisitor.
- *
- * @return the result of calling <code>v.visit()</code>, which indicates
- * whether or not the Visitor would like to visit the Model's next
- * Reaction (if available).
- */
+/** @cond doxygenLibsbmlInternal */
 bool
 Reaction::accept (SBMLVisitor& v) const
 {
@@ -271,6 +251,7 @@ Reaction::accept (SBMLVisitor& v) const
 
   return result;
 }
+/** @endcond */
 
 
 /*
@@ -546,11 +527,7 @@ Reaction::setId (const std::string& sid)
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
   }
 */
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(sid)))
+  if (!(SyntaxChecker::isValidInternalSId(sid)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -571,11 +548,7 @@ Reaction::setName (const std::string& name)
   /* if this is setting an L2 name the type is string
    * whereas if it is setting an L1 name its type is SId
    */
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (getLevel() == 1)
+  if (getLevel() == 1)
   {
     if (!(SyntaxChecker::isValidInternalSId(name)))
     {
@@ -662,11 +635,7 @@ Reaction::setFast (bool value)
 int
 Reaction::setCompartment (const std::string& sid)
 {
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (getLevel() < 3)
+  if (getLevel() < 3)
   {
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
   }
@@ -1315,7 +1284,6 @@ Reaction::removeModifier (const std::string& species)
 
 
 /** @cond doxygenLibsbmlInternal */
-
 /*
  * Sets the parent SBMLDocument of this SBML object.
  */
@@ -1365,8 +1333,6 @@ Reaction::enablePackageInternal(const std::string& pkgURI,
 
   if (mKineticLaw) mKineticLaw->enablePackageInternal(pkgURI,pkgPrefix,flag);
 }
-
-
 /** @endcond */
 
 
@@ -1930,15 +1896,8 @@ ListOfReactions::get (const std::string& sid) const
 {
   vector<SBase*>::const_iterator result;
 
-  if (&(sid) == NULL)
-  {
-    return NULL;
-  }
-  else
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEq<Reaction>(sid) );
-    return (result == mItems.end()) ? NULL : static_cast <Reaction*> (*result);
-  }
+  result = find_if( mItems.begin(), mItems.end(), IdEq<Reaction>(sid) );
+  return (result == mItems.end()) ? NULL : static_cast <Reaction*> (*result);
 }
 
 
@@ -1957,17 +1916,15 @@ ListOfReactions::remove (const std::string& sid)
   SBase* item = NULL;
   vector<SBase*>::iterator result;
 
-  if (&(sid) != NULL)
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEq<Reaction>(sid) );
+  result = find_if( mItems.begin(), mItems.end(), IdEq<Reaction>(sid) );
 
-    if (result != mItems.end())
-    {
-      item = *result;
-      mItems.erase(result);
-    }
+  if (result != mItems.end())
+  {
+    item = *result;
+    mItems.erase(result);
   }
 
+
   return static_cast <Reaction*> (item);
 }
 
@@ -2024,8 +1981,6 @@ ListOfReactions::createObject (XMLInputStream& stream)
 
 
 /** @cond doxygenIgnored */
-
-
 LIBSBML_EXTERN
 Reaction_t *
 Reaction_create (unsigned int level, unsigned int version)
@@ -2564,6 +2519,5 @@ ListOfReactions_removeById (ListOf_t *lo, const char *sid)
   else
     return NULL;
 }
-
 /** @endcond */
 LIBSBML_CPP_NAMESPACE_END
