@@ -54,9 +54,7 @@
 #include <sbml/RateRule.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -103,28 +101,20 @@ Rule::~Rule ()
 /*
  * Copy constructor. Creates a copy of this Rule.
  */
-Rule::Rule (const Rule& orig) :
-   SBase   ( orig          )
- , mMath   ( NULL            )
+Rule::Rule (const Rule& orig) 
+ : SBase       ( orig             )
+ , mVariable   ( orig.mVariable   )
+ , mFormula    ( orig.mFormula    )
+ , mMath       ( NULL             )
+ , mUnits      ( orig.mUnits      )
+ , mType       ( orig.mType       )
+ , mL1Type     ( orig.mL1Type     )
+ , mInternalId ( orig.mInternalId )
 {
-  if (&orig == NULL)
+  if (orig.mMath != NULL) 
   {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mVariable   = orig.mVariable;
-    mFormula    = orig.mFormula ;
-    mUnits      = orig.mUnits   ;
-    mType       = orig.mType    ;
-    mL1Type     = orig.mL1Type  ;
-    mInternalId = orig.mInternalId;
-
-    if (orig.mMath != NULL) 
-    {
-      mMath = orig.mMath->deepCopy();
-      mMath->setParentSBMLObject(this);
-    }
+    mMath = orig.mMath->deepCopy();
+    mMath->setParentSBMLObject(this);
   }
 }
 
@@ -134,11 +124,7 @@ Rule::Rule (const Rule& orig) :
  */
 Rule& Rule::operator=(const Rule& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->SBase::operator =(rhs);
     mVariable = rhs.mVariable;
@@ -165,18 +151,13 @@ Rule& Rule::operator=(const Rule& rhs)
 }
 
 
-/*
- * Accepts the given SBMLVisitor.
- *
- * @return the result of calling <code>v.visit()</code>, which indicates
- * whether or not the Visitor would like to visit the Model's next Rule
- * (if available).
- */
+/** @cond doxygenLibsbmlInternal */
 bool
 Rule::accept (SBMLVisitor& v) const
 {
   return v.visit(*this);
 }
+/** @endcond */
 
 
 /*
@@ -323,38 +304,34 @@ Rule::isSetUnits () const
 int
 Rule::setFormula (const std::string& formula)
 {
-  if (&(formula) == NULL)
+  
+  
+  if (formula == "")
   {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+    mFormula.erase();
+    delete mMath;
+    mMath = NULL;
+    return LIBSBML_OPERATION_SUCCESS;
   }
-  else 
+  ASTNode * math = SBML_parseFormula(formula.c_str());
+  if (math == NULL || !(math->isWellFormedASTNode()))
   {
-    if (formula == "")
+    delete math;
+    return LIBSBML_INVALID_OBJECT;
+  }
+  else
+  {
+    delete math;
+    mFormula = formula;
+  
+    if (mMath != NULL)
     {
-      mFormula.erase();
       delete mMath;
       mMath = NULL;
-      return LIBSBML_OPERATION_SUCCESS;
-    }
-    ASTNode * math = SBML_parseFormula(formula.c_str());
-    if (math == NULL || !(math->isWellFormedASTNode()))
-    {
-      delete math;
-      return LIBSBML_INVALID_OBJECT;
-    }
-    else
-    {
-      delete math;
-      mFormula = formula;
-
-      if (mMath != NULL)
-      {
-        delete mMath;
-        mMath = NULL;
-      }
-      return LIBSBML_OPERATION_SUCCESS;
     }
+    return LIBSBML_OPERATION_SUCCESS;
   }
+  
 }
 
 
@@ -396,11 +373,7 @@ Rule::setMath (const ASTNode* math)
 int
 Rule::setVariable (const std::string& sid)
 {
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (isAlgebraic())
+  if (isAlgebraic())
   {
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
   }
@@ -424,11 +397,7 @@ int
 Rule::setUnits (const std::string& sname)
 {
   /* only in L1 ParameterRule */
-  if (&(sname) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (getLevel() > 1)
+  if (getLevel() > 1)
   {
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
   }
@@ -1478,15 +1447,8 @@ ListOfRules::get (const std::string& sid) const
 {
   vector<SBase*>::const_iterator result;
 
-  if (&(sid) == NULL)
-  {
-    return NULL;
-  }
-  else
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqRule(sid) );
-    return (result == mItems.end()) ? NULL : static_cast <Rule*> (*result);
-  }
+  result = find_if( mItems.begin(), mItems.end(), IdEqRule(sid) );
+  return (result == mItems.end()) ? NULL : static_cast <Rule*> (*result);
 }
 
 
@@ -1519,15 +1481,12 @@ ListOfRules::remove (const std::string& sid)
   SBase* item = NULL;
   vector<SBase*>::iterator result;
 
-  if (&(sid) != NULL)
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqRule(sid) );
+  result = find_if( mItems.begin(), mItems.end(), IdEqRule(sid) );
 
-    if (result != mItems.end())
-    {
-      item = *result;
-      mItems.erase(result);
-    }
+  if (result != mItems.end())
+  {
+    item = *result;
+    mItems.erase(result);
   }
 
   return static_cast <Rule*> (item);
@@ -1547,7 +1506,6 @@ ListOfRules::getElementPosition () const
 /** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
-
 bool 
 ListOfRules::isValidTypeForList(SBase * item)
 {
@@ -1559,7 +1517,6 @@ ListOfRules::isValidTypeForList(SBase * item)
     ||    (tc == SBML_COMPARTMENT_VOLUME_RULE )
     ||    (tc == SBML_PARAMETER_RULE));
 }
-
 /** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
@@ -1697,8 +1654,6 @@ ListOfRules::createObject (XMLInputStream& stream)
 
 #endif /* __cplusplus */
 /** @cond doxygenIgnored */
-
-
 LIBSBML_EXTERN
 Rule_t *
 Rule_createAlgebraic (unsigned int level, unsigned int version)
@@ -2062,6 +2017,5 @@ ListOfRules_removeById (ListOf_t *lo, const char *sid)
   else
     return NULL;
 }
-
 /** @endcond */
 LIBSBML_CPP_NAMESPACE_END
