@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -42,9 +42,7 @@
 
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -275,9 +273,9 @@ SBMLErrorLog::removeAll (const unsigned int errorId)
 
 
 bool
-SBMLErrorLog::contains (const unsigned int errorId)
+SBMLErrorLog::contains (const unsigned int errorId) const
 {
-  vector<XMLError*>::iterator iter;
+  vector<XMLError*>::const_iterator iter;
 
   // finds an item with the given errorId (the first item will be found if
   // there are two or more items with the same Id)
@@ -311,9 +309,6 @@ public:
 private:
   unsigned int severity;
 };
-
-
-
 /** @endcond */
 
 unsigned int 
@@ -392,7 +387,6 @@ SBMLErrorLog::getErrorWithSeverity(unsigned int n, unsigned int severity) const
 
 
 /** @cond doxygenIgnored */
-
 /** @endcond */
 LIBSBML_CPP_NAMESPACE_END
 
