@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -39,9 +39,7 @@
 #include <iostream>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 
@@ -174,22 +172,13 @@ SBMLNamespaces::~SBMLNamespaces()
  * Copy constructor; creates a copy of a SBMLNamespaces.
  */
 SBMLNamespaces::SBMLNamespaces(const SBMLNamespaces& orig)
+ : mLevel(orig.mLevel)
+ , mVersion(orig.mVersion)
+ , mNamespaces(NULL)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mLevel   = orig.mLevel;
-    mVersion = orig.mVersion;
- 
-    if(orig.mNamespaces != NULL)
-      this->mNamespaces = 
-            new XMLNamespaces(*const_cast<SBMLNamespaces&>(orig).mNamespaces);
-    else
-      this->mNamespaces = NULL;
-  }
+  if(orig.mNamespaces != NULL)
+    this->mNamespaces = 
+          new XMLNamespaces(*const_cast<SBMLNamespaces&>(orig).mNamespaces);
 }
 
 
@@ -203,6 +192,7 @@ SBMLNamespaces::getSupportedNamespaces()
   result->add(new SBMLNamespaces(2,2));
   result->add(new SBMLNamespaces(2,3));
   result->add(new SBMLNamespaces(2,4));
+  result->add(new SBMLNamespaces(2,5));
   result->add(new SBMLNamespaces(3,1));
   return result;
 }
@@ -225,11 +215,7 @@ SBMLNamespaces::freeSBMLNamespaces(List * supportedNS)
 SBMLNamespaces&
 SBMLNamespaces::operator=(const SBMLNamespaces& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if (&rhs != this)
+  if (&rhs != this)
   {
     mLevel   = rhs.mLevel;
     mVersion = rhs.mVersion;
@@ -795,7 +781,6 @@ SBMLNamespaces::setNamespaces(XMLNamespaces * xmlns)
 
 #endif /* __cplusplus */
 /** @cond doxygenIgnored */
-
 LIBSBML_EXTERN
 SBMLNamespaces_t *
 SBMLNamespaces_create(unsigned int level, unsigned int version)
@@ -873,7 +858,6 @@ SBMLNamespaces_getSupportedNamespaces(int *length)
   SBMLNamespaces::freeSBMLNamespaces(const_cast<List*>(supported));
   return result;
 }
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
