@@ -44,9 +44,7 @@
 #include <sbml/Species.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -161,38 +159,31 @@ Species::~Species ()
 /*
  * Copy constructor. Creates a copy of this Species.
  */
-Species::Species(const Species& orig) :
-   SBase             ( orig                    )
+Species::Species(const Species& orig)
+ : SBase                       ( orig )
+ , mId                         ( orig.mId )
+ , mName                       ( orig.mName)
+ , mSpeciesType                ( orig.mSpeciesType)
+ , mCompartment                ( orig.mCompartment)
+ , mInitialAmount              ( orig.mInitialAmount)
+ , mInitialConcentration       ( orig.mInitialConcentration)
+ , mSubstanceUnits             ( orig.mSubstanceUnits)
+ , mSpatialSizeUnits           ( orig.mSpatialSizeUnits)
+ , mHasOnlySubstanceUnits      ( orig.mHasOnlySubstanceUnits)
+ , mBoundaryCondition          ( orig.mBoundaryCondition)
+ , mCharge                     ( orig.mCharge)
+ , mConstant                   ( orig.mConstant)
+ , mIsSetInitialAmount         ( orig.mIsSetInitialAmount)
+ , mIsSetInitialConcentration  ( orig.mIsSetInitialConcentration)
+ , mIsSetCharge                ( orig.mIsSetCharge)
+ , mConversionFactor           ( orig.mConversionFactor)
+ , mIsSetBoundaryCondition     ( orig.mIsSetBoundaryCondition)
+ , mIsSetHasOnlySubstanceUnits ( orig.mIsSetHasOnlySubstanceUnits)
+ , mIsSetConstant              ( orig.mIsSetConstant)
+ , mExplicitlySetBoundaryCondition ( orig.mExplicitlySetBoundaryCondition)
+ , mExplicitlySetConstant          ( orig.mExplicitlySetConstant)
+ , mExplicitlySetHasOnlySubsUnits  ( orig.mExplicitlySetHasOnlySubsUnits)  
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mId                         = orig.mId;
-    mName                       = orig.mName;
-    mSpeciesType                = orig.mSpeciesType;
-    mCompartment                = orig.mCompartment;
-    mInitialAmount              = orig.mInitialAmount;
-    mInitialConcentration       = orig.mInitialConcentration;
-    mSubstanceUnits             = orig.mSubstanceUnits;
-    mSpatialSizeUnits           = orig.mSpatialSizeUnits;
-    mHasOnlySubstanceUnits      = orig.mHasOnlySubstanceUnits;
-    mBoundaryCondition          = orig.mBoundaryCondition;
-    mCharge                     = orig.mCharge;
-    mConstant                   = orig.mConstant;
-    mIsSetInitialAmount         = orig.mIsSetInitialAmount;
-    mIsSetInitialConcentration  = orig.mIsSetInitialConcentration;
-    mIsSetCharge                = orig.mIsSetCharge;
-    mConversionFactor           = orig.mConversionFactor;
-    mIsSetBoundaryCondition     = orig.mIsSetBoundaryCondition;
-    mIsSetHasOnlySubstanceUnits = orig.mIsSetHasOnlySubstanceUnits;
-    mIsSetConstant              = orig.mIsSetConstant;
-    mExplicitlySetBoundaryCondition = orig.mExplicitlySetBoundaryCondition;
-    mExplicitlySetConstant          = orig.mExplicitlySetConstant;
-    mExplicitlySetHasOnlySubsUnits  = orig.mExplicitlySetHasOnlySubsUnits;
-  }
 }
 
 
@@ -201,11 +192,7 @@ Species::Species(const Species& orig) :
  */
 Species& Species::operator=(const Species& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->SBase::operator =(rhs);
     this->mId = rhs.mId;
@@ -240,18 +227,13 @@ Species& Species::operator=(const Species& rhs)
 }
 
 
-/*
- * Accepts the given SBMLVisitor.
- *
- * @return the result of calling <code>v.visit()</code>, which indicates
- * whether or not the Visitor would like to visit the Model's next
- * Species (if available).
- */
+/** @cond doxygenLibsbmlInternal */
 bool
 Species::accept (SBMLVisitor& v) const
 {
   return v.visit(*this);
 }
+/** @endcond */
 
 
 /*
@@ -616,11 +598,7 @@ Species::setId (const std::string& sid)
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
   }
 */
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(sid)))
+  if (!(SyntaxChecker::isValidInternalSId(sid)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -641,11 +619,7 @@ Species::setName (const std::string& name)
   /* if this is setting an L2 name the type is string
    * whereas if it is setting an L1 name its type is SId
    */
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (getLevel() == 1)
+  if (getLevel() == 1)
   {
     if (!(SyntaxChecker::isValidInternalSId(name)))
     {
@@ -671,11 +645,7 @@ Species::setName (const std::string& name)
 int
 Species::setSpeciesType (const std::string& sid)
 {
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if ( (getLevel() < 2)
+  if ( (getLevel() < 2)
     || (getLevel() == 2 && getVersion() == 1))
   {
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
@@ -698,11 +668,7 @@ Species::setSpeciesType (const std::string& sid)
 int
 Species::setCompartment (const std::string& sid)
 {
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(sid)))
+  if (!(SyntaxChecker::isValidInternalSId(sid)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -757,11 +723,7 @@ Species::setInitialConcentration (double value)
 int
 Species::setSubstanceUnits (const std::string& sid)
 {
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else  if (!(SyntaxChecker::isValidInternalSId(sid)))
+  if (!(SyntaxChecker::isValidInternalSId(sid)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -779,11 +741,7 @@ Species::setSubstanceUnits (const std::string& sid)
 int
 Species::setSpatialSizeUnits (const std::string& sid)
 {
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else  if ( (getLevel() != 2)
+  if ( (getLevel() != 2)
     || (getLevel() == 2 && getVersion() > 2))
   {
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
@@ -890,11 +848,7 @@ Species::setConstant (bool value)
 int
 Species::setConversionFactor (const std::string& sid)
 {
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else  if (getLevel() < 3)
+  if (getLevel() < 3)
   {
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
   }
@@ -2035,15 +1989,8 @@ ListOfSpecies::get (const std::string& sid) const
 {
   vector<SBase*>::const_iterator result;
 
-  if (&(sid) == NULL)
-  {
-    return NULL;
-  }
-  else
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqS(sid) );
-    return (result == mItems.end()) ? NULL : static_cast <Species*> (*result);
-  }
+  result = find_if( mItems.begin(), mItems.end(), IdEqS(sid) );
+  return (result == mItems.end()) ? NULL : static_cast <Species*> (*result);
 }
 
 
@@ -2062,15 +2009,12 @@ ListOfSpecies::remove (const std::string& sid)
   SBase* item = NULL;
   vector<SBase*>::iterator result;
 
-  if (&(sid) != NULL)
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqS(sid) );
+  result = find_if( mItems.begin(), mItems.end(), IdEqS(sid) );
 
-    if (result != mItems.end())
-    {
-      item = *result;
-      mItems.erase(result);
-    }
+  if (result != mItems.end())
+  {
+    item = *result;
+    mItems.erase(result);
   }
 
   return static_cast <Species*> (item);
@@ -2129,8 +2073,6 @@ ListOfSpecies::createObject (XMLInputStream& stream)
 
 #endif /* __cplusplus */
 /** @cond doxygenIgnored */
-
-
 LIBSBML_EXTERN
 Species_t *
 Species_create (unsigned int level, unsigned int version)
@@ -2764,8 +2706,6 @@ ListOfSpecies_removeById (ListOf_t *lo, const char *sid)
   else
     return NULL;
 }
-
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
