@@ -8,9 +8,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2015 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -48,9 +53,7 @@
 #include <sbml/extension/SBasePlugin.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -117,29 +120,21 @@ SpeciesReference::~SpeciesReference ()
 /*
  * Copy constructor. Creates a copy of this SpeciesReference.
  */
-SpeciesReference::SpeciesReference (const SpeciesReference& orig) :
-   SimpleSpeciesReference( orig                )
- , mStoichiometryMath    ( NULL                   )
+SpeciesReference::SpeciesReference (const SpeciesReference& orig)
+ : SimpleSpeciesReference( orig                )
+ , mStoichiometry        ( orig.mStoichiometry )
+ , mDenominator          ( orig.mDenominator   )
+ , mStoichiometryMath    ( NULL                )
+ , mConstant             ( orig.mConstant)
+ , mIsSetConstant        ( orig.mIsSetConstant)
+ , mIsSetStoichiometry   ( orig.mIsSetStoichiometry)
+ , mExplicitlySetStoichiometry ( orig.mExplicitlySetStoichiometry)
+ , mExplicitlySetDenominator   ( orig.mExplicitlySetDenominator)
 {
-  if (&orig == NULL)
+  if (orig.mStoichiometryMath != NULL)
   {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mStoichiometry = orig.mStoichiometry ;
-    mDenominator = orig.mDenominator   ;
-    mConstant = orig.mConstant;
-    mIsSetConstant = orig.mIsSetConstant;
-    mIsSetStoichiometry = orig.mIsSetStoichiometry;
-    mExplicitlySetStoichiometry = orig.mExplicitlySetStoichiometry;
-    mExplicitlySetDenominator = orig.mExplicitlySetDenominator;
-
-    if (orig.mStoichiometryMath != NULL)
-    {
-      mStoichiometryMath = new StoichiometryMath(*orig.getStoichiometryMath());
+    mStoichiometryMath = new StoichiometryMath(*orig.getStoichiometryMath());
     mStoichiometryMath->connectToParent(this);
-    }
   }
 }
 
@@ -149,11 +144,7 @@ SpeciesReference::SpeciesReference (const SpeciesReference& orig) :
  */
 SpeciesReference& SpeciesReference::operator=(const SpeciesReference& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->SBase::operator =(rhs);
     this->SimpleSpeciesReference::operator = ( rhs );
@@ -181,13 +172,7 @@ SpeciesReference& SpeciesReference::operator=(const SpeciesReference& rhs)
 }
 
 
-/*
- * Accepts the given SBMLVisitor.
- *
- * @return the result of calling <code>v.visit()</code>, which indicates
- * whether or not the Visitor would like to visit the Reaction's next
- * SpeciesReference (if available).
- */
+/** @cond doxygenLibsbmlInternal */
 bool
 SpeciesReference::accept (SBMLVisitor& v) const
 {
@@ -197,6 +182,7 @@ SpeciesReference::accept (SBMLVisitor& v) const
   
   return result;
 }
+/** @endcond */
 
 
 /*
@@ -218,12 +204,12 @@ SpeciesReference::clone () const
 void
 SpeciesReference::initDefaults ()
 {
-  //// level 3 has no defaults
-  //if (getLevel() < 3)
-  //{
-    mStoichiometry = 1.0;
-    mDenominator   = 1;
-  //}
+  setStoichiometry(1.0);
+  setDenominator(1);
+
+  // mark as not explicitly set
+  mExplicitlySetStoichiometry = false;
+  mExplicitlySetDenominator   = false;
 }
 
 
@@ -495,6 +481,27 @@ SpeciesReference::unsetStoichiometry ()
 }
 
 
+/*
+ * Sets the constant field of this SpeciesReference to value.
+ */
+int
+SpeciesReference::unsetConstant ()
+{
+  if ( getLevel() < 3 )
+  {
+    mConstant = false;
+    mIsSetConstant = false;
+    return LIBSBML_UNEXPECTED_ATTRIBUTE;
+  }
+  else
+  {
+    // no default
+    mIsSetConstant = false;
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+}
+
+
 /*
  * Creates a new StoichiometryMath, adds it to this SpeciesReference
  * and returns it.
@@ -680,7 +687,7 @@ SpeciesReference::sortMath()
     mStoichiometryMath->getMath()->isRational())
   {
     mStoichiometry = mStoichiometryMath->getMath()->getNumerator();
-    mDenominator   = mStoichiometryMath->getMath()->getDenominator();
+    mDenominator   = (int)mStoichiometryMath->getMath()->getDenominator();
 
     delete mStoichiometryMath;
     mStoichiometryMath = NULL;
@@ -830,7 +837,12 @@ SpeciesReference::readOtherXML (XMLInputStream& stream)
       }
       else
       {
-        logError(MultipleAnnotations, getLevel(), getVersion());
+        string msg = "An SBML <speciesReference> element ";
+        if (isSetId()) {
+          msg += "with the id '" + getId() + "' ";
+        }
+        msg += "has multiple <annotation> children.";
+        logError(MultipleAnnotations, getLevel(), getVersion(), msg);
       }
     }
     delete mAnnotation;
@@ -1005,6 +1017,15 @@ SpeciesReference::readL3Attributes (const XMLAttributes& attributes)
   //
   mIsSetStoichiometry = attributes.readInto("stoichiometry", mStoichiometry, getErrorLog(), false, getLine(), getColumn());
 
+  string elplusid = "<" + getElementName() + ">";
+  if (!mId.empty()) {
+    elplusid += " with the id '" + mId + "'";
+  }
+  SBase* rxn = getAncestorOfType(SBML_REACTION);
+  if (rxn && rxn->isSetId()) 
+  {
+    elplusid += " from the <reaction> with the id '" + rxn->getId() + "'";
+  }
   //
   // constant: bool { use="required" } (L3v1 -> )
   //
@@ -1012,7 +1033,8 @@ SpeciesReference::readL3Attributes (const XMLAttributes& attributes)
   if (!mIsSetConstant && !isModifier())
   {
     logError(AllowedAttributesOnSpeciesReference, level, version, 
-             "The required attribute 'constant' is missing.");
+             "The required attribute 'constant' is missing from the "
+             + elplusid + ".");
   }
 
 }
@@ -1243,16 +1265,9 @@ ListOfSpeciesReferences::get (const std::string& sid) const
 {
   vector<SBase*>::const_iterator result;
 
-  if (&(sid) == NULL)
-  {
-    return NULL;
-  }
-  else
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqSSR(sid) );
-    return (result == mItems.end()) ? NULL : 
-                             static_cast <SimpleSpeciesReference*> (*result);
-  }
+  result = find_if( mItems.begin(), mItems.end(), IdEqSSR(sid) );
+  return (result == mItems.end()) ? NULL : 
+                           static_cast <SimpleSpeciesReference*> (*result);
 }
 
 
@@ -1271,15 +1286,12 @@ ListOfSpeciesReferences::remove (const std::string& sid)
   SBase* item = NULL;
   vector<SBase*>::iterator result;
 
-  if (&(sid) != NULL)
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqSSR(sid) );
+  result = find_if( mItems.begin(), mItems.end(), IdEqSSR(sid) );
 
-    if (result != mItems.end())
-    {
-      item = *result;
-      mItems.erase(result);
-    }
+  if (result != mItems.end())
+  {
+    item = *result;
+    mItems.erase(result);
   }
 
   return static_cast <SimpleSpeciesReference*> (item);
@@ -1429,8 +1441,7 @@ ListOfSpeciesReferences::createObject (XMLInputStream& stream)
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
-
+/** @cond doxygenIgnored */
 LIBSBML_EXTERN
 SpeciesReference_t *
 SpeciesReference_create (unsigned int level, unsigned int version)
@@ -1806,6 +1817,24 @@ SpeciesReference_unsetName (SpeciesReference_t *sr)
   return (sr != NULL) ? sr->unsetName() : LIBSBML_INVALID_OBJECT;
 }
 
+
+LIBSBML_EXTERN
+int
+SpeciesReference_unsetSpecies (SpeciesReference_t *sr)
+{
+  return (sr != NULL) ? sr->unsetSpecies() : LIBSBML_INVALID_OBJECT;
+}
+
+
+LIBSBML_EXTERN
+int
+SpeciesReference_unsetConstant (SpeciesReference_t *sr)
+{
+  return (sr != NULL) ? static_cast<SpeciesReference*>(sr)->unsetConstant() 
+                      : LIBSBML_INVALID_OBJECT;
+}
+
+
 LIBSBML_EXTERN
 int
 SpeciesReference_unsetStoichiometryMath (SpeciesReference_t *sr)
@@ -1865,8 +1894,6 @@ ListOfSpeciesReferences_removeById (ListOf_t *lo, const char *sid)
   else
     return NULL;
 }
-
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
