@@ -43,9 +43,7 @@
 #include <sbml/SpeciesType.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -86,18 +84,11 @@ SpeciesType::~SpeciesType ()
 /*
  * Copy constructor. Creates a copy of this SpeciesType.
  */
-SpeciesType::SpeciesType(const SpeciesType& orig) :
-   SBase             ( orig                    )
+SpeciesType::SpeciesType(const SpeciesType& orig)
+  : SBase             ( orig )
+  , mId               ( orig.mId )
+  , mName             ( orig.mName )
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mId               = orig.mId;
-    mName             = orig.mName;
-  }
 }
 
 
@@ -106,11 +97,7 @@ SpeciesType::SpeciesType(const SpeciesType& orig) :
  */
 SpeciesType& SpeciesType::operator=(const SpeciesType& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->SBase::operator =(rhs);
     mId = rhs.mId;
@@ -121,18 +108,13 @@ SpeciesType& SpeciesType::operator=(const SpeciesType& rhs)
 }
 
 
-/*
- * Accepts the given SBMLVisitor.
- *
- * @return the result of calling <code>v.visit()</code>, which indicates
- * whether or not the Visitor would like to visit the Model's next
- * SpeciesType (if available).
- */
+/** @cond doxygenLibsbmlInternal */
 bool
 SpeciesType::accept (SBMLVisitor& v) const
 {
   return v.visit(*this);
 }
+/** @endcond */
 
 
 /*
@@ -203,11 +185,7 @@ SpeciesType::setId (const std::string& sid)
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
   }
 */
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(sid)))
+  if (!(SyntaxChecker::isValidInternalSId(sid)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -228,11 +206,7 @@ SpeciesType::setName (const std::string& name)
   /* if this is setting an L2 name the type is string
    * whereas if it is setting an L1 name its type is SId
    */
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (getLevel() == 1)
+  if (getLevel() == 1)
   {
     if (!(SyntaxChecker::isValidInternalSId(name)))
     {
@@ -564,16 +538,9 @@ ListOfSpeciesTypes::get (const std::string& sid) const
 {
   vector<SBase*>::const_iterator result;
 
-  if (&(sid) == NULL)
-  {
-    return NULL;
-  }
-  else
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqST(sid) );
-    return (result == mItems.end()) ? NULL : 
-                               static_cast <SpeciesType*> (*result);
-  }
+  result = find_if( mItems.begin(), mItems.end(), IdEqST(sid) );
+  return (result == mItems.end()) ? NULL : 
+                             static_cast <SpeciesType*> (*result);
 }
 
 
@@ -592,15 +559,12 @@ ListOfSpeciesTypes::remove (const std::string& sid)
   SBase* item = NULL;
   vector<SBase*>::iterator result;
 
-  if (&(sid) != NULL)
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqST(sid) );
+  result = find_if( mItems.begin(), mItems.end(), IdEqST(sid) );
 
-    if (result != mItems.end())
-    {
-      item = *result;
-      mItems.erase(result);
-    }
+  if (result != mItems.end())
+  {
+    item = *result;
+    mItems.erase(result);
   }
 
   return static_cast <SpeciesType*> (item);
@@ -661,7 +625,6 @@ ListOfSpeciesTypes::createObject (XMLInputStream& stream)
 
 #endif /* __cplusplus */
 /** @cond doxygenIgnored */
-
 LIBSBML_EXTERN
 SpeciesType_t *
 SpeciesType_create (unsigned int level, unsigned int version)
@@ -804,8 +767,6 @@ ListOfSpeciesTypes_removeById (ListOf_t *lo, const char *sid)
   else
     return NULL;
 }
-
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
