@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -48,10 +48,10 @@
 
 #include <sbml/util/ElementFilter.h>
 
+#include <math.h>
+
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -98,19 +98,11 @@ UnitDefinition::~UnitDefinition ()
  * Copy constructor. Creates a copy of this UnitDefinition.
  */
 UnitDefinition::UnitDefinition(const UnitDefinition& orig) :
-    SBase     ( orig                    )
-  , mUnits    ( orig.mUnits             )
+    SBase     ( orig )
+  , mId       ( orig.mId )
+  , mName     ( orig.mName )
+  , mUnits    ( orig.mUnits )
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mId    = orig.mId;
-    mName  = orig.mName;
-  }
-
   connectToChild();
 }
 
@@ -120,11 +112,7 @@ UnitDefinition::UnitDefinition(const UnitDefinition& orig) :
  */
 UnitDefinition& UnitDefinition::operator=(const UnitDefinition& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->SBase::operator =(rhs);
     mId = rhs.mId;
@@ -138,13 +126,7 @@ UnitDefinition& UnitDefinition::operator=(const UnitDefinition& rhs)
 }
 
 
-/*
- * Accepts the given SBMLVisitor.
- *
- * @return the result of calling <code>v.visit()</code>, which indicates
- * whether or not the Visitor would like to visit the Model's next
- * UnitDefinition (if available).
- */
+/** @cond doxygenLibsbmlInternal */
 bool
 UnitDefinition::accept (SBMLVisitor& v) const
 {
@@ -153,7 +135,8 @@ UnitDefinition::accept (SBMLVisitor& v) const
 
   return result;
 }
-
+/** @endcond */
+\
 
 /*
  * @return a (deep) copy of this UnitDefinition.
@@ -259,11 +242,7 @@ UnitDefinition::setId (const std::string& sid)
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
   }
 */
-  if (&(sid) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(sid)))
+  if (!(SyntaxChecker::isValidInternalSId(sid)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -284,11 +263,7 @@ UnitDefinition::setName (const std::string& name)
   /* if this is setting an L2 name the type is string
    * whereas if it is setting an L1 name its type is SId
    */
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (getLevel() == 1)
+  if (getLevel() == 1)
   {
     if (!(SyntaxChecker::isValidInternalSId(name)))
     {
@@ -660,7 +635,6 @@ UnitDefinition::removeUnit (unsigned int n)
 
 
 /** @cond doxygenLibsbmlInternal */
-
 /*
  * Sets the parent SBMLDocument of this SBML object.
  */
@@ -696,7 +670,6 @@ UnitDefinition::enablePackageInternal(const std::string& pkgURI,
 
   mUnits.enablePackageInternal(pkgURI,pkgPrefix,flag);
 }
-
 /** @endcond */
 
 
@@ -898,10 +871,14 @@ UnitDefinition::reorder(UnitDefinition *ud)
   int *initialIndexArray = NULL;
   initialIndexArray = new int[units->size()];
 
+  std::vector<unsigned int> used;
+
   for (n = 0; n < numUnits; n++)
   {
-    indexArray[n] = ((Unit *)units->get(n))->getKind();
-    initialIndexArray[n] = ((Unit *)units->get(n))->getKind();
+    Unit * unit = (Unit *)(units->get(n));
+    int value = unit->getKind();
+    indexArray[n] = value;
+    initialIndexArray[n] = value;
   }
 
   qsort(indexArray, numUnits, sizeof(int), compareKinds);
@@ -913,9 +890,13 @@ UnitDefinition::reorder(UnitDefinition *ud)
     {
       if (indexArray[n] == initialIndexArray[p])
       {
-        unit = (Unit *) units->get(p);
-        units->append(unit);
-        break;
+        if (used.end() == std::find(used.begin(), used.end(), p)) 
+        {
+          unit = (Unit *) units->get(p);
+          units->append(unit);
+          used.push_back(p);
+          break;
+        }
       }
     }
   }
@@ -1195,7 +1176,6 @@ UnitDefinition::areEquivalent(const UnitDefinition * ud1, const UnitDefinition *
 }
 
 /** @cond doxygenLibsbmlInternal */
-
 bool 
 UnitDefinition::areIdenticalSIUnits(const UnitDefinition * ud1, 
                                const UnitDefinition * ud2)
@@ -1292,7 +1272,6 @@ UnitDefinition::areIdenticalSIUnits(const UnitDefinition * ud1,
 
   return identical;
 }
-
 /** @endcond */
 
 /* 
@@ -1577,7 +1556,8 @@ UnitDefinition::readL1Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("name", level, version, "<unitDefinition>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 }
 /** @endcond */
 
@@ -1603,7 +1583,8 @@ UnitDefinition::readL2Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("id", level, version, "<unitDefinition>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
   //
   // name: string  { use="optional" }  (L2v1->)
@@ -1639,7 +1620,8 @@ UnitDefinition::readL3Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("id", level, version, "<unitDefinition>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
   //
   // name: string  { use="optional" }  (L2v1->)
@@ -1802,16 +1784,9 @@ ListOfUnitDefinitions::get (const std::string& sid) const
 {
   vector<SBase*>::const_iterator result;
 
-  if (&(sid) == NULL)
-  {
-    return NULL;
-  }
-  else
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqUD(sid) );
-    return (result == mItems.end()) ? NULL : 
-                     static_cast <UnitDefinition*> (*result);
-  }
+  result = find_if( mItems.begin(), mItems.end(), IdEqUD(sid) );
+  return (result == mItems.end()) ? NULL : 
+                   static_cast <UnitDefinition*> (*result);
 }
 
 
@@ -1844,15 +1819,12 @@ ListOfUnitDefinitions::remove (const std::string& sid)
   SBase* item = NULL;
   ListItemIter result;
 
-  if (&(sid) != NULL)
-  {
-    result = find_if( mItems.begin(), mItems.end(), IdEqUD(sid) );
+  result = find_if( mItems.begin(), mItems.end(), IdEqUD(sid) );
 
-    if (result != mItems.end())
-    {
-      item = *result;
-      mItems.erase(result);
-    }
+  if (result != mItems.end())
+  {
+    item = *result;
+    mItems.erase(result);
   }
 
   return static_cast <UnitDefinition*> (item);
@@ -1911,8 +1883,6 @@ ListOfUnitDefinitions::createObject (XMLInputStream& stream)
 
 #endif /* __cplusplus */
 /** @cond doxygenIgnored */
-
-
 LIBSBML_EXTERN
 UnitDefinition_t *
 UnitDefinition_create (unsigned int level, unsigned int version)
@@ -2243,8 +2213,6 @@ ListOfUnitDefinitions_removeById (ListOf_t *lo, const char *sid)
   else
     return NULL;
 }
-
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
