@@ -38,9 +38,7 @@
 #include <cstdio>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -77,10 +75,7 @@ Date::Date(unsigned int year, unsigned int month,
 Date::Date (const std::string& date) :
   mHasBeenModified (false)
 { 
-  if (&(date) == NULL)
-    mDate = "";
-  else
-    mDate = date; 
+  mDate = date; 
 
   parseDateStringToNumbers();
   parseDateNumbersToString();
@@ -94,11 +89,6 @@ Date::~Date() {}
  */
 Date::Date(const Date& orig)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
   {
     mYear   = orig.mYear;
     mMonth  = orig.mMonth;
@@ -122,11 +112,7 @@ Date::Date(const Date& orig)
  */
 Date& Date::operator=(const Date& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     mYear   = rhs.mYear;
     mMonth  = rhs.mMonth;
@@ -392,16 +378,7 @@ Date::setDateAsString (const std::string& date)
    * the date completely
    */
  
-  if (&(date) == NULL)
-  {
-    mDate = "";
-    // revert to default numbers
-    // rewrite date string to reflect the defaults
-    parseDateStringToNumbers();
-    parseDateNumbersToString();
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (date.empty())
+  if (date.empty())
   {
     mDate = "";
     // revert to default numbers
@@ -684,7 +661,6 @@ Date::resetModifiedFlags()
 
 
 /** @cond doxygenIgnored */
-
 LIBSBML_EXTERN
 Date_t *
 Date_createFromValues(unsigned int year, unsigned int month, 
@@ -911,7 +887,6 @@ Date_representsValidDate(Date_t *date)
   if (date == NULL) return (int)false;
   return static_cast<int> (date->representsValidDate());
 }
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
