@@ -3,6 +3,11 @@
  * @brief   ModelCreator I/O
  * @author  Sarah Keating
  * 
+ * Copyright (C) 2013-2015 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
@@ -33,9 +38,7 @@
 #include <cstdio>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -129,11 +132,6 @@ ModelCreator::~ModelCreator()
  */
 ModelCreator::ModelCreator(const ModelCreator& orig)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
   {
     mFamilyName   = orig.mFamilyName;
     mGivenName    = orig.mGivenName;
@@ -156,11 +154,7 @@ ModelCreator::ModelCreator(const ModelCreator& orig)
  */
 ModelCreator& ModelCreator::operator=(const ModelCreator& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     mFamilyName   = rhs.mFamilyName;
     mGivenName    = rhs.mGivenName;
@@ -230,11 +224,6 @@ ModelCreator::isSetOrganisation()
 int 
 ModelCreator::setFamilyName(const std::string& name)
 {
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else
   {
     mFamilyName = name;
     mHasBeenModified = true;
@@ -249,11 +238,6 @@ ModelCreator::setFamilyName(const std::string& name)
 int 
 ModelCreator::setGivenName(const std::string& name)
 {
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else
   {
     mGivenName = name;
     mHasBeenModified = true;
@@ -268,11 +252,6 @@ ModelCreator::setGivenName(const std::string& name)
 int 
 ModelCreator::setEmail(const std::string& email)
 {
-  if (&(email) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else
   {
     mEmail = email;
     mHasBeenModified = true;
@@ -284,11 +263,6 @@ ModelCreator::setEmail(const std::string& email)
 int 
 ModelCreator::setOrganization(const std::string& organization)
 {
-  if (&(organization) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else
   {
     mOrganization = organization;
     mHasBeenModified = true;
@@ -427,7 +401,6 @@ ModelCreator::resetModifiedFlags()
 
 
 /** @cond doxygenIgnored */
-
 LIBSBML_EXTERN
 ModelCreator_t *
 ModelCreator_create()
@@ -645,7 +618,6 @@ ModelCreator_hasRequiredAttributes(ModelCreator_t *mc)
   if (mc == NULL) return (int)false;
   return static_cast<int> (mc->hasRequiredAttributes());
 }
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
