@@ -7,7 +7,7 @@
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
-* Copyright (C) 2013-2014 jointly by the following organizations:
+* Copyright (C) 2013-2015 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *     3. University of Heidelberg, Heidelberg, Germany
@@ -112,7 +112,7 @@ SBMLIdConverter::getDefaultProperties() const
 bool 
 SBMLIdConverter::matchesProperties(const ConversionProperties &props) const
 {
-  if (&props == NULL || !props.hasOption("renameSIds"))
+  if (!props.hasOption("renameSIds"))
     return false;
   return true;
 }
@@ -185,8 +185,6 @@ SBMLIdConverter::convert()
 }
 
 /** @cond doxygenIgnored */
-
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
