@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -86,11 +86,7 @@ SBMLLevelVersionConverter::~SBMLLevelVersionConverter ()
 SBMLLevelVersionConverter& 
 SBMLLevelVersionConverter::operator=(const SBMLLevelVersionConverter& rhs)
 {  
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->SBMLConverter::operator =(rhs);
   }
@@ -134,7 +130,7 @@ SBMLLevelVersionConverter::getDefaultProperties() const
 bool 
 SBMLLevelVersionConverter::matchesProperties(const ConversionProperties &props) const
 {
-  if (&props == NULL || !props.hasOption("setLevelAndVersion"))
+  if (!props.hasOption("setLevelAndVersion"))
     return false;
   return true;
 }
@@ -351,7 +347,7 @@ SBMLLevelVersionConverter::convert()
       {
         /* now we want to mDocument->check whether the resulting model is valid
          */
-        mDocument->validateSBML();
+        validateConvertedDocument();
         unsigned int errors = 
            mDocument->getErrorLog()->getNumFailsWithSeverity(LIBSBML_SEV_ERROR);
         if (errors > 0)
@@ -950,7 +946,6 @@ SBMLLevelVersionConverter::performConversion(bool strict, bool strictUnits,
   return conversion;
 
 }
-
 /** @endcond */
 
 
@@ -1082,8 +1077,24 @@ SBMLLevelVersionConverter::hasStrictSBO()
 
 
 /** @cond doxygenIgnored */
+unsigned int
+SBMLLevelVersionConverter::validateConvertedDocument()
+{
+  // force a read
+  std::string sbml = writeSBMLToStdString(mDocument);
+  SBMLDocument *tempdoc = readSBMLFromString(sbml.c_str());
+  unsigned int nerrors = tempdoc->getErrorLog()->getNumErrors();
+  for (unsigned int i = 0; i < nerrors; i++)
+  {
+    const SBMLError * error = tempdoc->getErrorLog()->getError(i);
+    mDocument->getErrorLog()->add(*(error));
+  }
+  delete tempdoc;
 
+  nerrors += mDocument->checkConsistency();
 
+  return nerrors;
+}
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
