@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -100,8 +100,9 @@ class LIBSBML_EXTERN  SBMLLevelVersionConverter : public SBMLConverter
 public:
 
   /** @cond doxygenLibsbmlInternal */
-
-  /* register with the ConversionRegistry */
+  /**
+   * Register with the ConversionRegistry.
+   */
   static void init();
 
   /** @endcond */
@@ -133,9 +134,6 @@ public:
    *
    * @param rhs The object whose values are used as the basis of the
    * assignment.
-   *
-   * @throws SBMLConstructorException
-   * Thrown if the argument @p rhs is @c NULL.
    */
   SBMLLevelVersionConverter& operator=(const SBMLLevelVersionConverter& rhs);
 
@@ -178,9 +176,7 @@ public:
    * with the configuration options set by
    * SBMLConverter::setProperties(@if java ConversionProperties@endif).
    *
-   * @return  integer value indicating the success/failure of the operation.
-   * @if clike The value is drawn from the enumeration
-   * #OperationReturnValues_t. @endif@~ The possible values are:
+   * @copydetails doc_returns_success_code
    * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
    * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    * @li @sbmlconstant{LIBSBML_CONV_INVALID_TARGET_NAMESPACE, OperationReturnValues_t}
@@ -239,7 +235,6 @@ public:
 
 private:
   /** @cond doxygenLibsbmlInternal */
-
   bool conversion_errors(unsigned int errors, bool strictUnits = true);
 
   /*
@@ -257,6 +252,8 @@ private:
    */
   bool performConversion(bool strict, bool strictUnits, bool duplicateAnn);
 
+  unsigned int validateConvertedDocument();
+
   /** @endcond */
 };
 
