@@ -110,7 +110,7 @@ SBMLRuleConverter::getDefaultProperties() const
 bool 
   SBMLRuleConverter::matchesProperties(const ConversionProperties &props) const
 {
-  if (&props == NULL || !props.hasOption("sortRules"))
+  if (!props.hasOption("sortRules"))
     return false;
   return true;
 }
@@ -396,8 +396,6 @@ SBMLRuleConverter::convert()
 }
 
 /** @cond doxygenIgnored */
-
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
