@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -83,11 +83,7 @@ SBMLStripPackageConverter::~SBMLStripPackageConverter ()
 SBMLStripPackageConverter& 
 SBMLStripPackageConverter::operator=(const SBMLStripPackageConverter& rhs)
 {  
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     this->SBMLConverter::operator =(rhs);
   }
@@ -129,13 +125,12 @@ SBMLStripPackageConverter::getDefaultProperties() const
 bool 
 SBMLStripPackageConverter::matchesProperties(const ConversionProperties &props) const
 {
-  if (&props == NULL || !props.hasOption("stripPackage"))
+  if (!props.hasOption("stripPackage"))
     return false;
   return true;
 }
 
 /** @cond doxygenLibsbmlInternal */
-
 bool 
 SBMLStripPackageConverter::stripPackage(const std::string& packageToStrip)
 {
@@ -242,8 +237,6 @@ SBMLStripPackageConverter::isStripAllUnrecognizedPackages() const
 }
 
 /** @cond doxygenIgnored */
-
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
