@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -56,6 +56,23 @@ static const packageErrorTableEntry defaultErrorTable[] =
   }
 };
 
+
+static const packageErrorTableEntryV2 defaultErrorTableV2[] =
+{
+  // 10304
+  { 0, 
+    "",
+    0, 
+    LIBSBML_SEV_ERROR,
+    LIBSBML_SEV_ERROR,
+    "",
+    { "",
+      ""
+    }
+  }
+};
+
+
 SBMLExtension::SBMLExtension ()
  : mIsEnabled(true)
 #ifndef LIBSBML_USE_LEGACY_MATH
@@ -69,14 +86,17 @@ SBMLExtension::SBMLExtension ()
  * Copy constructor.
  */
 SBMLExtension::SBMLExtension(const SBMLExtension& orig)
- : mIsEnabled(orig.mIsEnabled)
- , mSupportedPackageURI(orig.mSupportedPackageURI)
-#ifndef LIBSBML_USE_LEGACY_MATH
- , mASTBasePlugin(NULL)
-#endif
 {
 #ifndef LIBSBML_USE_LEGACY_MATH
-  if (orig.mASTBasePlugin != NULL) {
+    mASTBasePlugin = NULL;
+#endif
+
+  mIsEnabled = orig.mIsEnabled;
+  mSupportedPackageURI = orig.mSupportedPackageURI;
+
+#ifndef LIBSBML_USE_LEGACY_MATH
+  if (orig.mASTBasePlugin != NULL) 
+  {
     mASTBasePlugin = orig.mASTBasePlugin->clone();
   }
 #endif
@@ -93,7 +113,8 @@ SBMLExtension::~SBMLExtension ()
   for (size_t i=0; i < mSBasePluginCreators.size(); i++)
     delete mSBasePluginCreators[i];
 #ifndef LIBSBML_USE_LEGACY_MATH
-  delete mASTBasePlugin;
+  if (mASTBasePlugin != NULL)
+    delete mASTBasePlugin;
 #endif
 }
 
@@ -104,22 +125,25 @@ SBMLExtension::~SBMLExtension ()
 SBMLExtension& 
 SBMLExtension::operator=(const SBMLExtension& orig)
 {  
-  mIsEnabled = orig.mIsEnabled; 
-  mSupportedPackageURI = orig.mSupportedPackageURI; 
+  if (&orig != this)
+  {
+    mIsEnabled = orig.mIsEnabled; 
+    mSupportedPackageURI = orig.mSupportedPackageURI; 
+
+  #ifndef LIBSBML_USE_LEGACY_MATH
+    mASTBasePlugin = NULL;
+    if (orig.mASTBasePlugin != NULL) {
+      mASTBasePlugin = orig.mASTBasePlugin->clone();
+    }
+  #endif /* LIBSBML_USE_LEGACY_MATH */
+
+    for (size_t i=0; i < mSBasePluginCreators.size(); i++)
+      delete mSBasePluginCreators[i];
+
+    for (size_t i=0; i < orig.mSBasePluginCreators.size(); i++)
+      mSBasePluginCreators.push_back(orig.mSBasePluginCreators[i]->clone());
 
-#ifndef LIBSBML_USE_LEGACY_MATH
-  mASTBasePlugin = NULL;
-  if (orig.mASTBasePlugin != NULL) {
-    mASTBasePlugin = orig.mASTBasePlugin->clone();
   }
-#endif /* LIBSBML_USE_LEGACY_MATH */
-
-  for (size_t i=0; i < mSBasePluginCreators.size(); i++)
-    delete mSBasePluginCreators[i];
-
-  for (size_t i=0; i < orig.mSBasePluginCreators.size(); i++)
-    mSBasePluginCreators.push_back(orig.mSBasePluginCreators[i]->clone());
-
   return *this;
 }
 
@@ -182,7 +206,6 @@ SBMLExtension::addSBasePluginCreator(const SBasePluginCreatorBase* sbaseExt)
 
 #ifndef LIBSBML_USE_LEGACY_MATH
 /** @cond doxygenLibsbmlInternal */
-
 int 
 SBMLExtension::setASTBasePlugin(const ASTBasePlugin* astPlugin)
 {
@@ -200,40 +223,33 @@ SBMLExtension::setASTBasePlugin(const ASTBasePlugin* astPlugin)
 
   return LIBSBML_OPERATION_SUCCESS;
 }
-
 /** @endcond */
 
 
 /** @cond doxygenLibsbmlInternal */
-
 bool
 SBMLExtension::isSetASTBasePlugin() const
 {
   return (mASTBasePlugin != NULL);
 }
-
 /** @endcond */
 
 
 /** @cond doxygenLibsbmlInternal */
-
 ASTBasePlugin*
 SBMLExtension::getASTBasePlugin()
 {
   return mASTBasePlugin;
 }
-
 /** @endcond */
 
 
 /** @cond doxygenLibsbmlInternal */
-
 const ASTBasePlugin*
 SBMLExtension::getASTBasePlugin() const
 {
   return const_cast<SBMLExtension*>(this)->getASTBasePlugin();
 }
-
 /** @endcond */
 
 #endif /* LIBSBML_USE_LEGACY_MATH */
@@ -242,7 +258,6 @@ SBMLExtension::getASTBasePlugin() const
 SBasePluginCreatorBase*
 SBMLExtension::getSBasePluginCreator(const SBaseExtensionPoint& extPoint)
 {
-  if (&extPoint == NULL) return NULL;
   std::vector<SBasePluginCreatorBase*>::iterator it = mSBasePluginCreators.begin();
   while(it != mSBasePluginCreators.end())
   {
@@ -313,7 +328,6 @@ SBMLExtension::getNumOfSupportedPackageURI() const
 bool
 SBMLExtension::isSupported(const std::string& uri) const
 {
-  if(&uri == NULL) return false;
   return ( mSupportedPackageURI.end() 
             != 
            find(mSupportedPackageURI.begin(),mSupportedPackageURI.end(), uri) );
@@ -396,6 +410,17 @@ SBMLExtension::getErrorTable(unsigned int index) const
 }
 /** @endcond */
 
+
+/** @cond doxygenLibsbmlInternal */
+
+packageErrorTableEntryV2 
+SBMLExtension::getErrorTableV2(unsigned int index) const
+{
+  return defaultErrorTableV2[0];
+}
+
+/** @endcond */
+
 /** @cond doxygenLibsbmlInternal */
 unsigned int 
 SBMLExtension::getErrorTableIndex(unsigned int errorId) const
@@ -404,6 +429,16 @@ SBMLExtension::getErrorTableIndex(unsigned int errorId) const
 }
 /** @endcond */
 
+/** @cond doxygenLibsbmlInternal */
+bool
+SBMLExtension::hasMultipleVersions() const
+{
+  return false;
+}
+/** @endcond */
+
+
+
 /** @cond doxygenLibsbmlInternal */
 unsigned int
 SBMLExtension::getErrorIdOffset() const
@@ -416,13 +451,31 @@ SBMLExtension::getErrorIdOffset() const
 unsigned int 
 SBMLExtension::getSeverity(unsigned int index, unsigned int pkgVersion) const
 {
-  packageErrorTableEntry pkgErr = getErrorTable(index);
-  switch (pkgVersion)
+  // I know this is messy but I need to think through multiple versions of 
+  // packages
+  if (hasMultipleVersions() == false)
   {
-    case 1:
-    default:
-      return pkgErr.l3v1_severity;
-      break;
+    packageErrorTableEntry pkgErr = getErrorTable(index);
+    switch (pkgVersion)
+    {
+      case 1:
+      default:
+        return pkgErr.l3v1v1_severity;
+        break;
+    }
+  }
+  else
+  {
+    packageErrorTableEntryV2 pkgErr = getErrorTableV2(index);
+    switch (pkgVersion)
+    {
+      case 1:
+        return pkgErr.l3v1v1_severity;
+      case 2:
+      default:
+        return pkgErr.l3v1v2_severity;
+        break;
+    }
   }
 }
 /** @endcond */
@@ -431,8 +484,17 @@ SBMLExtension::getSeverity(unsigned int index, unsigned int pkgVersion) const
 unsigned int 
 SBMLExtension::getCategory(unsigned int index) const
 {
-  packageErrorTableEntry pkgErr = getErrorTable(index);
-  return pkgErr.category;
+  // I know this is messy but I need to think through multiple versions of 
+  // packages
+  if (hasMultipleVersions() == false)
+  {
+    packageErrorTableEntry pkgErr = getErrorTable(index);
+    return pkgErr.category;
+  }
+  {
+    packageErrorTableEntryV2 pkgErr = getErrorTableV2(index);
+    return pkgErr.category;
+  }
 }
 /** @endcond */
 
@@ -442,35 +504,56 @@ SBMLExtension::getMessage(unsigned int index,
                           unsigned int pkgVersion, 
                           const std::string& details) const
 {
-  packageErrorTableEntry pkgErr = getErrorTable(index);
-      
   ostringstream newMsg;
   std::string ref;
-  std::string message;
 
-  newMsg << pkgErr.message;
-
-  switch (pkgVersion)
+  // I know this is messy but I need to think through multiple versions of 
+  // packages
+  if (hasMultipleVersions() == false)
   {
-    case 1:
-    default:
-      ref = pkgErr.reference.ref_l3v1;
-      break;
+    packageErrorTableEntry pkgErr = getErrorTable(index);
+
+    newMsg << pkgErr.message << endl;
+
+    switch (pkgVersion)
+    {
+      case 1:
+      default:
+        ref = pkgErr.reference.ref_l3v1v1;
+        break;
+    }
+  }
+  else
+  {
+    packageErrorTableEntryV2 pkgErr = getErrorTableV2(index);
+      
+    newMsg << pkgErr.message << endl;
+
+    switch (pkgVersion)
+    {
+      case 1:
+        ref = pkgErr.reference.ref_l3v1v1;
+      case 2:
+      default:
+        ref = pkgErr.reference.ref_l3v1v2;
+        break;
+    }
   }
 
   if (!ref.empty())
   {
-    newMsg << "\nReference: " << ref << endl;
+    newMsg << "Reference: " << ref << endl;
   }
 
   if (!details.empty())
   {
     newMsg << " " << details;
-  }      
-  newMsg << endl;
-  message =  newMsg.str();
-
-  return message;
+    if (details[details.size()-1] != '\n') {
+      newMsg << endl;
+    }
+  }
+  
+  return newMsg.str();
 }
 /** @endcond */
 
@@ -478,15 +561,24 @@ SBMLExtension::getMessage(unsigned int index,
 std::string 
 SBMLExtension::getShortMessage(unsigned int index) const
 {
-  packageErrorTableEntry pkgErr = getErrorTable(index);
-  return pkgErr.shortMessage;
+  // I know this is messy but I need to think through multiple versions of 
+  // packages
+  if (hasMultipleVersions() == false)
+  {
+    packageErrorTableEntry pkgErr = getErrorTable(index);
+    return pkgErr.shortMessage;
+  }
+  else
+  {
+    packageErrorTableEntryV2 pkgErr = getErrorTableV2(index);
+    return pkgErr.shortMessage;
+  }
 }
 /** @endcond */
 
 #endif /* __cplusplus */
 
 /** @cond doxygenIgnored */
-
 LIBSBML_EXTERN
 SBMLExtension_t*
 SBMLExtension_clone(SBMLExtension_t* ext)
@@ -645,7 +737,6 @@ SBMLExtension_isEnabled(SBMLExtension_t* ext)
   if (ext == NULL) return LIBSBML_INVALID_OBJECT;
   return ext->isEnabled();
 }
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
