@@ -69,8 +69,6 @@ SBMLExtensionRegistry::deleteRegistry()
 }
 
 /** @cond doxygenLibsbmlInternal */
-
-
 /*
  *
  */
@@ -99,12 +97,9 @@ SBMLExtensionRegistry::SBMLExtensionRegistry()
 
 
 SBMLExtensionRegistry::SBMLExtensionRegistry(const SBMLExtensionRegistry& orig)
+ : mSBMLExtensionMap(orig.mSBMLExtensionMap)
+ , mSBasePluginMap(orig.mSBasePluginMap)
 {
-  if (&orig != NULL)
-  {
-    mSBMLExtensionMap =   orig.mSBMLExtensionMap;
-    mSBasePluginMap   =   orig.mSBasePluginMap;
-  }
 }
 
 SBMLExtensionRegistry& SBMLExtensionRegistry::operator= (const SBMLExtensionRegistry&rhs)
@@ -218,8 +213,6 @@ SBMLExtensionRegistry::getExtension(const std::string& uri)
 const SBMLExtension*
 SBMLExtensionRegistry::getExtensionInternal(const std::string& uri)
 {
-  if(&uri == NULL) return NULL;
-  
   SBMLExtensionMapIter it = mSBMLExtensionMap.find(uri);
 
 #if 0
@@ -242,18 +235,15 @@ SBMLExtensionRegistry::getSBasePluginCreators(const SBaseExtensionPoint& extPoin
 {
   std::list<const SBasePluginCreatorBase*> sbaseExtList;
 
-  if (&extPoint != NULL)
-  {
-    SBasePluginMapIter it = mSBasePluginMap.find(extPoint);
-    if (it != mSBasePluginMap.end())
-    {    
-      do 
-      {
-        sbaseExtList.push_back((*it).second);
-        ++it;
-      } while ( it != mSBasePluginMap.upper_bound(extPoint));
-    }
-  }  
+  SBasePluginMapIter it = mSBasePluginMap.find(extPoint);
+  if (it != mSBasePluginMap.end())
+  {    
+    do 
+    {
+      sbaseExtList.push_back((*it).second);
+      ++it;
+    } while ( it != mSBasePluginMap.upper_bound(extPoint));
+  }
 
   return sbaseExtList;
 }
@@ -269,8 +259,6 @@ SBMLExtensionRegistry::getSBasePluginCreators(const std::string& uri)
 {
   std::list<const SBasePluginCreatorBase*> sbasePCList;
 
-  if (&uri != NULL)
-  {
   SBasePluginMapIter it = mSBasePluginMap.begin();
   if (it != mSBasePluginMap.end())
   {    
@@ -296,7 +284,7 @@ SBMLExtensionRegistry::getSBasePluginCreators(const std::string& uri)
       std::cout << "[DEBUG] SBMLExtensionRegistry::getPluginCreators() " 
                 << uri << " is NOT found." << std::endl;
 #endif
-  }
+
 
   return sbasePCList;  
 }
@@ -310,7 +298,6 @@ SBMLExtensionRegistry::getSBasePluginCreators(const std::string& uri)
 const SBasePluginCreatorBase* 
 SBMLExtensionRegistry::getSBasePluginCreator(const SBaseExtensionPoint& extPoint, const std::string &uri)
 {
-  if(&extPoint == NULL || &uri == NULL) return NULL;
   SBasePluginMapIter it = mSBasePluginMap.find(extPoint);
   if (it != mSBasePluginMap.end())
   {
@@ -344,7 +331,6 @@ unsigned int
 SBMLExtensionRegistry::getNumExtension(const SBaseExtensionPoint& extPoint)
 {
   unsigned int numOfExtension = 0;
-  if (&extPoint == NULL) return 0;
   SBasePluginMapIter it = mSBasePluginMap.find(extPoint);
   if (it != mSBasePluginMap.end())
   {    
@@ -592,8 +578,6 @@ SBMLExtensionRegistry::enablePackages(const std::vector<std::string>& packages)
 
 #endif /* __cplusplus */
 /** @cond doxygenIgnored */
-
-
 LIBSBML_EXTERN
 int 
 SBMLExtensionRegistry_addExtension(const SBMLExtension_t* extension)
@@ -735,7 +719,6 @@ SBMLExtensionRegistry_getRegisteredPackageName(int index)
 {
   return safe_strdup(SBMLExtensionRegistry::getRegisteredPackageName(index).c_str());
 }
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
