@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -280,7 +280,6 @@ SBasePlugin::stripPackage(const std::string& pkgPrefix, bool flag)
 {
   return true;
 }
-
 /** @endcond */
 
 
@@ -525,7 +524,6 @@ SBasePlugin::parseAnnotation(SBase *parentObject, XMLNode *annotation)
 {
 
 }
-
 /** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
@@ -575,8 +573,6 @@ void
 SBasePlugin::readAttributes (const XMLAttributes& attributes,
                              const ExpectedAttributes& expectedAttributes)
 {
-  if (&attributes == NULL || &expectedAttributes == NULL ) return;
-
   const unsigned int sbmlLevel   = getLevel  ();
   const unsigned int sbmlVersion = getVersion();
   const unsigned int pkgVersion  = getPackageVersion();
@@ -657,6 +653,14 @@ SBasePlugin::writeXMLNS (XMLOutputStream& stream) const
 /** @endcond */
 
 
+/** @cond doxygenLibsbmlInternal */
+bool 
+SBasePlugin::isValidTypeForList(SBase* item) const
+{ 
+  return false; 
+}
+/** @endcond */
+
 /** @cond doxygenLibsbmlInternal */
 /*
  * @return the SBMLErrorLog used to log errors while reading and
@@ -680,7 +684,6 @@ SBasePlugin::logUnknownElement(const std::string &element,
  			               const unsigned int sbmlVersion,
 			               const unsigned int pkgVersion )
 {
-  if(&element == NULL) return;
   
   std::ostringstream msg;
 
@@ -713,7 +716,6 @@ SBasePlugin::logUnknownAttribute(const std::string &attribute,
                                  const unsigned int pkgVersion,
                                  const std::string& element)
 {
-  if (&attribute == NULL || &element == NULL) return;
   
   std::ostringstream msg;
 
@@ -735,6 +737,19 @@ SBasePlugin::logUnknownAttribute(const std::string &attribute,
 }
 /** @endcond */
 
+/** @cond doxygenLibsbmlInternal */
+bool 
+SBasePlugin::accept (SBMLVisitor& v) const
+{
+  return false;
+}
+/** @endcond */
+
+SBasePlugin* 
+SBasePlugin::clone () const
+{
+  return new SBasePlugin(*this);
+}
 
 /** @cond doxygenLibsbmlInternal */
 /*
@@ -742,14 +757,12 @@ SBasePlugin::logUnknownAttribute(const std::string &attribute,
  */
 void 
 SBasePlugin::logEmptyString(const std::string &attribute, 
-                                    const unsigned int sbmlLevel,
-                                    const unsigned int sbmlVersion,
-			            const unsigned int pkgVersion,
-			            const std::string& element)
+                            const unsigned int sbmlLevel,
+                            const unsigned int sbmlVersion,
+			                      const unsigned int pkgVersion,
+			                      const std::string& element)
 {
 
-  if (&attribute == NULL || &element == NULL) return;
-  
   std::ostringstream msg;
 
   msg << "Attribute '" << attribute << "' on an "
@@ -769,9 +782,20 @@ SBasePlugin::logEmptyString(const std::string &attribute,
 /** @endcond */
 
 
+/** @cond doxygenLibsbmlInternal */
+
+const SBMLExtension*
+SBasePlugin::getSBMLExtension() const
+{
+  return mSBMLExt;
+}
+/** @endcond */
+
+
+
+
 #endif /* __cplusplus */
 /** @cond doxygenIgnored */
-
 LIBSBML_EXTERN
 const char* 
 SBasePlugin_getURI(SBasePlugin_t* plugin)
@@ -961,7 +985,6 @@ SBasePlugin_getPackageVersion(SBasePlugin_t* plugin)
   if (plugin == NULL) return SBML_INT_MAX;
   return plugin->getPackageVersion();
 }
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
