@@ -665,8 +665,7 @@ public:
 
   virtual bool isValidTypeForList(SBase* item) const;
 
-    /** @cond doxygenLibsbmlInternal */
-
+  /** @cond doxygenLibsbmlInternal */
   /**
    * Accepts the given SBMLVisitor.
    *
@@ -675,9 +674,13 @@ public:
    * sibling object (if available).
    */
   virtual bool accept (SBMLVisitor& v) const;
-
   /** @endcond */
 
+  /** @cond doxygenLibsbmlInternal */
+  
+  const SBMLExtension* getSBMLExtension() const;
+
+  /** @endcond */
 
 protected:
   /** @cond doxygenLibsbmlInternal */
