@@ -45,9 +45,7 @@
 #include <sbml/math/MathML.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -87,7 +85,6 @@ LIBSBML_EXTERN
 ASTNode*
 readMathML (XMLInputStream& stream, const std::string& reqd_prefix)
 {
-  if (&stream == NULL) return NULL;
 
   stream.skipText();
 
@@ -113,7 +110,7 @@ LIBSBML_EXTERN
 void
 writeMathML (const ASTNode* node, XMLOutputStream& stream, SBMLNamespaces *sbmlns)
 {
-  if (node == NULL || &stream == NULL) return;
+  if (node == NULL ) return;
   stream.setSBMLNamespaces(sbmlns);
   node->write(stream);
 }
@@ -285,7 +282,6 @@ writeMathMLToStdString (const ASTNode* node)
 
   return os.str();
 }
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
