@@ -131,7 +131,7 @@ bool
 CompFlatteningConverter::matchesProperties
                         (const ConversionProperties &props) const
 {
-  if (&props == NULL || !props.hasOption("flatten comp"))
+  if (!props.hasOption("flatten comp"))
     return false;
   return true;
 }
@@ -1420,8 +1420,6 @@ CompFlatteningConverter::haveUnflattenableUnrequiredPackages()
 
 
 /** @cond doxygenIgnored */
-
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
