@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -49,19 +49,12 @@ SBMLUri::SBMLUri (const std::string& uri)
  * Copy constructor.
  */
 SBMLUri::SBMLUri(const SBMLUri& orig)
+ : mScheme (orig.mScheme)
+ , mHost   (orig.mHost)
+ , mPath   (orig.mPath)
+ , mQuery  (orig.mQuery)
+ , mUri    (orig.mUri)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mScheme = orig.mScheme;
-    mHost = orig.mHost;
-    mPath = orig.mPath;
-    mQuery = orig.mQuery;
-    mUri = orig.mUri;
-  }
 }
 
 
@@ -80,11 +73,7 @@ SBMLUri::~SBMLUri ()
 SBMLUri&
 SBMLUri::operator=(const SBMLUri& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment operator");
-  }
-  else if(&rhs!=this)
+  if(&rhs!=this)
   {
     mScheme = rhs.mScheme;
     mHost = rhs.mHost;
@@ -314,8 +303,6 @@ SBMLUri::getQuery() const
 }
 
 /** @cond doxygenIgnored */
-
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
