@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -35,9 +35,7 @@
 #include <sbml/packages/comp/common/CompExtensionTypes.h>
 #include <sbml/SBMLTypes.h>
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -324,7 +322,7 @@ public:
 
   virtual bool visit (const SBase &x)
   {
-    if (&x == NULL || x.getPackageName() != "comp")
+    if (x.getPackageName() != "comp")
     {
       return SBMLVisitor::visit(x);      
     }
@@ -465,7 +463,6 @@ CompValidator::addConstraint (VConstraint* c)
 //void
 //CompValidator::logFailure (const SBMLError& msg)
 //{
-//  if (&msg == NULL) return;
 //  mFailures.push_back(msg);
 //}
 
@@ -478,8 +475,6 @@ CompValidator::addConstraint (VConstraint* c)
 unsigned int
 CompValidator::validate (const SBMLDocument& d)
 {
-  if (&d == NULL) return 0;
-
   Model* m = const_cast<SBMLDocument&>(d).getModel();
 
   if (m != NULL)
@@ -607,8 +602,6 @@ CompValidator::validate (const SBMLDocument& d)
 unsigned int
 CompValidator::validate (const std::string& filename)
 {
-  if (&filename == NULL) return 0;
-
   SBMLReader    reader;
   SBMLDocument* d = reader.readSBML(filename);
 
