@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  * 
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -37,6 +37,7 @@
 #include <sbml/packages/fbc/sbml/Association.h>
 #include <sbml/packages/fbc/extension/FbcExtension.h>
 #include <sbml/math/FormulaParser.h>
+#include <sbml/util/util.h>
 
 using namespace std;
 
@@ -119,7 +120,7 @@ Association::Association(const XMLNode& node, FbcPkgNamespaces* fbcns)
       
       if(childName=="gene" || childName=="or" || childName == "and")
       {
-        mAssociations.push_back(Association(*child, new FbcPkgNamespaces(*fbcns)));
+        mAssociations.push_back(new Association(*child, new FbcPkgNamespaces(*fbcns)));
       }
       ++n;
     }
@@ -135,7 +136,12 @@ Association::Association(const Association& source) : SBase(source)
 {
   this->mType=source.mType;
   this->mReference=source.mReference;
-  this->mAssociations=source.mAssociations;
+
+  std::vector<Association*>::const_iterator it;
+  for (it = source.mAssociations.begin(); it != source.mAssociations.end(); ++it)
+  {
+    mAssociations.push_back((*it)->clone());
+  }
 }
 
 /*
@@ -148,7 +154,19 @@ Association& Association::operator=(const Association& source)
     this->SBase::operator=(source);
     this->mType=source.mType;
     this->mReference=source.mReference;
-    this->mAssociations=source.mAssociations;
+
+    std::vector<Association*>::iterator it;
+    for (it = mAssociations.begin(); it != mAssociations.end(); ++it)
+    {
+      delete (*it);
+    }
+    mAssociations.clear();
+
+    std::vector<Association*>::const_iterator cit;
+    for (cit = source.mAssociations.begin(); cit != source.mAssociations.end(); ++cit)
+    {
+      mAssociations.push_back((*cit)->clone());
+    }
   }
   
   return *this;
@@ -160,6 +178,12 @@ Association& Association::operator=(const Association& source)
  */ 
 Association::~Association ()
 {
+  std::vector<Association*>::iterator it;
+  for (it = mAssociations.begin(); it != mAssociations.end(); ++it)
+  {
+    delete (*it);
+  }
+  mAssociations.clear();
 }
 
 AssociationTypeCode_t 
@@ -221,16 +245,6 @@ Association::unsetReference ()
 
 }
 
-void replaceAllSubStrings(std::string& str, const std::string& from, const std::string& to) {
-  if(from.empty())
-    return;
-  size_t start_pos = 0;
-  while((start_pos = str.find(from, start_pos)) != std::string::npos) {
-    str.replace(start_pos, from.length(), to);
-    start_pos += to.length(); // In case 'to' contains 'from', like replacing 'x' with 'yx'
-  }
-}
-
 Association* toAssociation(const ASTNode* node);
 
 void addChildren(Association* association, const ASTNode* node, const ASTNode *current)
@@ -349,11 +363,11 @@ Association::toInfix() const
   {
     stringstream str;
     str << "(";
-    str << mAssociations[0].toInfix();
+    str << mAssociations[0]->toInfix();
     for (size_t pos = 1; pos < mAssociations.size(); ++pos)
     {
       str << " or ";
-      str << mAssociations[pos].toInfix();
+      str << mAssociations[pos]->toInfix();
     }
     str << ")";
     return str.str();
@@ -363,11 +377,11 @@ Association::toInfix() const
   {
     stringstream str;
     str << "(";
-    str << mAssociations[0].toInfix();
+    str << mAssociations[0]->toInfix();
     for (size_t pos = 1; pos < mAssociations.size(); ++pos)
     {
       str << " and ";
-      str << mAssociations[pos].toInfix();
+      str << mAssociations[pos]->toInfix();
     }
     str << ")";
     return str.str();
@@ -382,9 +396,9 @@ Association::addGene(const std::string& id)
 {
   if (mType == OR_ASSOCIATION || mType == AND_ASSOCIATION)
   {
-    Association geneAssociation;
-    geneAssociation.setType(GENE_ASSOCIATION);
-    geneAssociation.setReference(id);
+    Association *geneAssociation = new Association();
+    geneAssociation->setType(GENE_ASSOCIATION);
+    geneAssociation->setReference(id);
     mAssociations.push_back(geneAssociation);
     return LIBSBML_OPERATION_SUCCESS;
   }
@@ -402,7 +416,7 @@ Association::addAssociation(Association &association)
 {
   if (mType == OR_ASSOCIATION || mType == AND_ASSOCIATION)
   {
-    mAssociations.push_back(association);
+    mAssociations.push_back(association.clone());
     return LIBSBML_OPERATION_SUCCESS;
   }
   return LIBSBML_OPERATION_FAILED;
@@ -491,10 +505,10 @@ XMLNode Association::toXML() const
   if(this->mNotes) node.addChild(*this->mNotes);
   if(this->mAnnotation) node.addChild(*this->mAnnotation);
 
-  std::vector<Association>::const_iterator it;
+  std::vector<Association*>::const_iterator it;
   for (it = mAssociations.begin(); it != mAssociations.end(); ++it)
   {
-    node.addChild((*it).toXML());
+    node.addChild((*it)->toXML());
   }
   return node;
 }
@@ -504,16 +518,37 @@ XMLNode Association::toXML() const
 SBase*
 Association::createObject (XMLInputStream& stream)
 {
-  return NULL;
+  SBase* object = NULL;
+
+
+  if (mType == GENE_ASSOCIATION) return NULL;
+
+  const string& name = stream.peek().getName();
+  if (name == "gene" || name == "or" || name == "and")
+  {
+    Association* association = new Association(getLevel(), getVersion());
+    if (name == "gene")
+      association->setType(GENE_ASSOCIATION);
+    else if (name == "and")
+      association->setType(AND_ASSOCIATION);
+    else if (name == "or")
+      association->setType(OR_ASSOCIATION);
+
+    mAssociations.push_back(association);
+    object = association;
+  }
+  return object;
 }
 /** @endcond */
 
+
 /** @cond doxygenLibsbmlInternal */
 void
 Association::addExpectedAttributes(ExpectedAttributes& attributes)
 {
   SBase::addExpectedAttributes(attributes);
 
+  if (mType == GENE_ASSOCIATION)
   attributes.add("reference");
 }
 /** @endcond */
@@ -528,6 +563,8 @@ Association::readAttributes (const XMLAttributes& attributes,
   const unsigned int sbmlLevel   = getLevel  ();
   const unsigned int sbmlVersion = getVersion();
 
+  if (mType != GENE_ASSOCIATION) return;
+
   bool assigned = attributes.readInto("reference", mReference, getErrorLog(), true, getLine(), getColumn());
   if (assigned && mReference.empty())
   {
@@ -546,6 +583,7 @@ Association::writeAttributes (XMLOutputStream& stream) const
 {
   SBase::writeAttributes(stream);
 
+  if (mType == GENE_ASSOCIATION)
   stream.writeAttribute("reference",   getPrefix(), mReference);
 
   //
@@ -562,10 +600,10 @@ Association::writeElements (XMLOutputStream& stream) const
   SBase::writeElements(stream);
 
   
-  std::vector<Association>::const_iterator it;
+  std::vector<Association*>::const_iterator it;
   for (it = mAssociations.begin(); it!= mAssociations.end(); ++it)
   {
-    (*it).write(stream);
+    (*it)->write(stream);
   }
   
   //
@@ -595,14 +633,13 @@ Association::clone() const
 }
 
 
-/*
- * Accepts the given SBMLVisitor.
- */
+/** @cond doxygenLibsbmlInternal */
 bool
 Association::accept (SBMLVisitor& v) const
 {
   return false;
 }
+/** @endcond */
 
 #endif /* __cplusplus */
 LIBSBML_CPP_NAMESPACE_END
