@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  * 
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -47,9 +47,10 @@ class LIBSBML_EXTERN CobraToFbcConverter : public SBMLConverter
 public:
 
   /** @cond doxygenLibsbmlInternal */
-  
-  /* register with the ConversionRegistry */
-  static void init();  
+  /**
+   * Register with the ConversionRegistry.
+   */
+  static void init();
 
   /** @endcond */
 
@@ -115,6 +116,11 @@ public:
    */
   virtual ConversionProperties getDefaultProperties() const;
 
+  /** 
+   * Returns a flag whether the level and version of the source document
+   * should be checked for compatibility before converting to SBML Level 3
+   */ 
+  bool checkCompatibility() const;
 
 };
 
