@@ -450,15 +450,8 @@ int Layout::setName (const std::string& name)
   /* if this is setting an L2 name the type is string
    * whereas if it is setting an L1 name its type is SId
    */
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else
-  {
-    mName = name;
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  mName = name;
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 /*
@@ -1701,6 +1694,7 @@ Layout::clone() const
 }
 
 
+/** @cond doxygenLibsbmlInternal */
 bool
 Layout::accept (SBMLVisitor& v) const
 {
@@ -1718,6 +1712,7 @@ Layout::accept (SBMLVisitor& v) const
   
   return true;
 }
+/** @endcond */
 
 
 /** @cond doxygenLibsbmlInternal */
@@ -2571,7 +2566,6 @@ XMLNode ListOfTextGlyphs::toXML() const
 
 #endif /* __cplusplus */
 /** @cond doxygenIgnored */
-
 LIBSBML_EXTERN
 Layout_t *
 Layout_create (void)
@@ -3021,7 +3015,6 @@ Layout_unsetId (Layout_t *l)
   if (l == NULL) return;
   l->unsetId();
 }
-
 /** @endcond */
 LIBSBML_CPP_NAMESPACE_END
 
