@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -73,17 +73,10 @@ CompartmentReference::CompartmentReference (MultiPkgNamespaces* multins)
  */
 CompartmentReference::CompartmentReference (const CompartmentReference& orig)
   : SBase(orig)
+  , mId  ( orig.mId)
+  , mName  ( orig.mName)
+  , mCompartment  ( orig.mCompartment)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mId  = orig.mId;
-    mName  = orig.mName;
-    mCompartment  = orig.mCompartment;
-  }
 }
 
 
@@ -93,11 +86,7 @@ CompartmentReference::CompartmentReference (const CompartmentReference& orig)
 CompartmentReference&
 CompartmentReference::operator=(const CompartmentReference& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment");
-  }
-  else if (&rhs != this)
+  if (&rhs != this)
   {
     SBase::operator=(rhs);
     mId  = rhs.mId;
@@ -202,15 +191,8 @@ CompartmentReference::setId(const std::string& id)
 int
 CompartmentReference::setName(const std::string& name)
 {
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else
-  {
-    mName = name;
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  mName = name;
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -220,11 +202,7 @@ CompartmentReference::setName(const std::string& name)
 int
 CompartmentReference::setCompartment(const std::string& compartment)
 {
-  if (&(compartment) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(compartment)))
+  if (!(SyntaxChecker::isValidInternalSId(compartment)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -444,8 +422,10 @@ CompartmentReference::readAttributes (const XMLAttributes& attributes,
    * happened immediately prior to this read
   */
 
-  if (getErrorLog() != NULL &&
-      static_cast<ListOfCompartmentReferences*>(getParentSBMLObject())->size() < 2)
+  ListOfCompartmentReferences * parentListOfCompartmentReferences =
+      static_cast<ListOfCompartmentReferences*>(getParentSBMLObject());
+
+  if (getErrorLog() != NULL && parentListOfCompartmentReferences->size() < 2)
   {
     numErrs = getErrorLog()->getNumErrors();
     for (int n = numErrs-1; n >= 0; n--)
@@ -455,16 +435,20 @@ CompartmentReference::readAttributes (const XMLAttributes& attributes,
         const std::string details =
               getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiLofCpaRefs_AllowedAtts,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                  parentListOfCompartmentReferences->getLine(),
+                  parentListOfCompartmentReferences->getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
                    getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiLofCpaRefs_AllowedAtts,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                  parentListOfCompartmentReferences->getLine(),
+                  parentListOfCompartmentReferences->getColumn());
       }
     }
   }
@@ -482,7 +466,7 @@ CompartmentReference::readAttributes (const XMLAttributes& attributes,
         const std::string details =
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
+        getErrorLog()->logPackageError("multi", MultiCpaRef_AllowedMultiAtts,
                        getPackageVersion(), sbmlLevel, sbmlVersion, details);
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
@@ -490,7 +474,7 @@ CompartmentReference::readAttributes (const XMLAttributes& attributes,
         const std::string details =
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
+        getErrorLog()->logPackageError("multi", MultiCpaRef_AllowedCoreAtts,
                        getPackageVersion(), sbmlLevel, sbmlVersion, details);
       }
     }
@@ -511,9 +495,12 @@ CompartmentReference::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mId, getLevel(), getVersion(), "<CompartmentReference>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mId) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mId) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax);
+        std::string details = "The syntax of the attribute id='" + mId + "' does not conform.";
+        getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                   getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                   getLine(), getColumn());
     }
   }
 
@@ -545,16 +532,19 @@ CompartmentReference::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mCompartment, getLevel(), getVersion(), "<CompartmentReference>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mCompartment) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mCompartment) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute compartment='" + mCompartment + "' does not conform.");
+      std::string details = "The syntax of the attribute compartment='" + mCompartment + "' does not conform.";
+      getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                 getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                 getLine(), getColumn());
+
     }
   }
   else
   {
-    std::string message = "Multi attribute 'compartment' is missing.";
-    getErrorLog()->logPackageError("multi", MultiUnknownError,
+    std::string message = "The attribute 'compartment' is missing in the <compartmentReference> element.";
+    getErrorLog()->logPackageError("multi", MultiCpaRef_AllowedMultiAtts,
                    getPackageVersion(), sbmlLevel, sbmlVersion, message);
   }
 
@@ -737,15 +727,16 @@ ListOfCompartmentReferences::getItemTypeCode () const
 SBase*
 ListOfCompartmentReferences::createObject(XMLInputStream& stream)
 {
-  const std::string& name   = stream.peek().getName();
   SBase* object = NULL;
+  const std::string& name = stream.peek().getName();
 
   if (name == "compartmentReference")
-  {
-    MULTI_CREATE_NS(multins, getSBMLNamespaces());
-    object = new CompartmentReference(multins);
-    appendAndOwn(object);
-  }
+    {
+      MULTI_CREATE_NS(multins, getSBMLNamespaces());
+      object = new CompartmentReference(multins);
+      appendAndOwn(object);
+      delete multins;
+    }
 
   return object;
 }
@@ -768,7 +759,8 @@ ListOfCompartmentReferences::writeXMLNS(XMLOutputStream& stream) const
 
   if (prefix.empty())
   {
-    if (getNamespaces()->hasURI(MultiExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(MultiExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(MultiExtension::getXmlnsL3V1V1(),prefix);
     }
@@ -781,7 +773,7 @@ ListOfCompartmentReferences::writeXMLNS(XMLOutputStream& stream) const
   /** @endcond doxygenLibsbmlInternal */
 
 
-/**
+/*
  * 
  */
 LIBSBML_EXTERN
@@ -793,7 +785,7 @@ CompartmentReference_create(unsigned int level, unsigned int version,
 }
 
 
-/**
+/*
  * 
  */
 LIBSBML_EXTERN
@@ -805,8 +797,8 @@ CompartmentReference_free(CompartmentReference_t * cr)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 CompartmentReference_t *
@@ -823,8 +815,8 @@ CompartmentReference_clone(CompartmentReference_t * cr)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 char *
@@ -837,8 +829,8 @@ CompartmentReference_getId(CompartmentReference_t * cr)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 char *
@@ -851,8 +843,8 @@ CompartmentReference_getName(CompartmentReference_t * cr)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 char *
@@ -865,8 +857,8 @@ CompartmentReference_getCompartment(CompartmentReference_t * cr)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -876,8 +868,8 @@ CompartmentReference_isSetId(CompartmentReference_t * cr)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -887,8 +879,8 @@ CompartmentReference_isSetName(CompartmentReference_t * cr)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -898,8 +890,8 @@ CompartmentReference_isSetCompartment(CompartmentReference_t * cr)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -909,8 +901,8 @@ CompartmentReference_setId(CompartmentReference_t * cr, const char * id)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -920,8 +912,8 @@ CompartmentReference_setName(CompartmentReference_t * cr, const char * name)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -931,8 +923,8 @@ CompartmentReference_setCompartment(CompartmentReference_t * cr, const char * co
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -942,8 +934,8 @@ CompartmentReference_unsetId(CompartmentReference_t * cr)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -953,8 +945,8 @@ CompartmentReference_unsetName(CompartmentReference_t * cr)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -964,8 +956,8 @@ CompartmentReference_unsetCompartment(CompartmentReference_t * cr)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -975,8 +967,8 @@ CompartmentReference_hasRequiredAttributes(CompartmentReference_t * cr)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 CompartmentReference_t *
@@ -989,8 +981,8 @@ ListOfCompartmentReferences_getById(ListOf_t * lo, const char * sid)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 CompartmentReference_t *
