@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -69,15 +69,8 @@ DenotedSpeciesTypeComponentIndex::DenotedSpeciesTypeComponentIndex (MultiPkgName
  */
 DenotedSpeciesTypeComponentIndex::DenotedSpeciesTypeComponentIndex (const DenotedSpeciesTypeComponentIndex& orig)
   : SBase(orig)
+  , mSpeciesTypeComponentIndex  ( orig.mSpeciesTypeComponentIndex)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mSpeciesTypeComponentIndex  = orig.mSpeciesTypeComponentIndex;
-  }
 }
 
 
@@ -87,11 +80,7 @@ DenotedSpeciesTypeComponentIndex::DenotedSpeciesTypeComponentIndex (const Denote
 DenotedSpeciesTypeComponentIndex&
 DenotedSpeciesTypeComponentIndex::operator=(const DenotedSpeciesTypeComponentIndex& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment");
-  }
-  else if (&rhs != this)
+  if (&rhs != this)
   {
     SBase::operator=(rhs);
     mSpeciesTypeComponentIndex  = rhs.mSpeciesTypeComponentIndex;
@@ -144,11 +133,7 @@ DenotedSpeciesTypeComponentIndex::isSetSpeciesTypeComponentIndex() const
 int
 DenotedSpeciesTypeComponentIndex::setSpeciesTypeComponentIndex(const std::string& speciesTypeComponentIndex)
 {
-  if (&(speciesTypeComponentIndex) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(speciesTypeComponentIndex)))
+  if (!(SyntaxChecker::isValidInternalSId(speciesTypeComponentIndex)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -328,8 +313,10 @@ DenotedSpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attribute
    * happened immediately prior to this read
   */
 
-  if (getErrorLog() != NULL &&
-      static_cast<ListOfDenotedSpeciesTypeComponentIndexes*>(getParentSBMLObject())->size() < 2)
+  ListOfDenotedSpeciesTypeComponentIndexes * parentListOf =
+      static_cast<ListOfDenotedSpeciesTypeComponentIndexes*>(getParentSBMLObject());
+
+  if (getErrorLog() != NULL && parentListOf->size() < 2)
   {
     numErrs = getErrorLog()->getNumErrors();
     for (int n = numErrs-1; n >= 0; n--)
@@ -339,16 +326,18 @@ DenotedSpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attribute
         const std::string details =
               getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiLofDenSptCpoInds_AllowedAtts,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                  parentListOf->getLine(), parentListOf->getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
                    getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiLofDenSptCpoInds_AllowedAtts,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                  parentListOf->getLine(), parentListOf->getColumn());
       }
     }
   }
@@ -366,16 +355,18 @@ DenotedSpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attribute
         const std::string details =
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiDenSptCpoInd_AllowedMultiAtts,
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                       getLine(), getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiDenSptCpoInd_AllowedCoreAtts,
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                       getLine(), getColumn());
       }
     }
   }
@@ -395,18 +386,21 @@ DenotedSpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attribute
     {
       logEmptyString(mSpeciesTypeComponentIndex, getLevel(), getVersion(), "<DenotedSpeciesTypeComponentIndex>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mSpeciesTypeComponentIndex) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mSpeciesTypeComponentIndex) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute speciesTypeComponentIndex='" 
-        + mSpeciesTypeComponentIndex + "' does not conform.");
+      std::string details = "The syntax of the attribute speciesTypeComponentIndex='" + mSpeciesTypeComponentIndex + "' does not conform.";
+      getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                 getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                 getLine(), getColumn());
+
     }
   }
   else
   {
     std::string message = "Multi attribute 'speciesTypeComponentIndex' is missing.";
-    getErrorLog()->logPackageError("multi", MultiUnknownError,
-                   getPackageVersion(), sbmlLevel, sbmlVersion, message);
+    getErrorLog()->logPackageError("multi", MultiDenSptCpoInd_SpTypeCpoIndAtt_Ref,
+                   getPackageVersion(), sbmlLevel, sbmlVersion, message,
+                   getLine(), getColumn());
   }
 
 }
@@ -590,6 +584,7 @@ ListOfDenotedSpeciesTypeComponentIndexes::createObject(XMLInputStream& stream)
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     object = new DenotedSpeciesTypeComponentIndex(multins);
     appendAndOwn(object);
+    delete multins;
   }
 
   return object;
@@ -613,7 +608,8 @@ ListOfDenotedSpeciesTypeComponentIndexes::writeXMLNS(XMLOutputStream& stream) co
 
   if (prefix.empty())
   {
-    if (getNamespaces()->hasURI(MultiExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(MultiExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(MultiExtension::getXmlnsL3V1V1(),prefix);
     }
@@ -626,7 +622,7 @@ ListOfDenotedSpeciesTypeComponentIndexes::writeXMLNS(XMLOutputStream& stream) co
   /** @endcond doxygenLibsbmlInternal */
 
 
-/**
+/*
  * 
  */
 LIBSBML_EXTERN
@@ -638,7 +634,7 @@ DenotedSpeciesTypeComponentIndex_create(unsigned int level, unsigned int version
 }
 
 
-/**
+/*
  * 
  */
 LIBSBML_EXTERN
@@ -650,8 +646,8 @@ DenotedSpeciesTypeComponentIndex_free(DenotedSpeciesTypeComponentIndex_t * dstci
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 DenotedSpeciesTypeComponentIndex_t *
@@ -668,8 +664,8 @@ DenotedSpeciesTypeComponentIndex_clone(DenotedSpeciesTypeComponentIndex_t * dstc
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 char *
@@ -682,8 +678,8 @@ DenotedSpeciesTypeComponentIndex_getSpeciesTypeComponentIndex(DenotedSpeciesType
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -693,8 +689,8 @@ DenotedSpeciesTypeComponentIndex_isSetSpeciesTypeComponentIndex(DenotedSpeciesTy
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -704,8 +700,8 @@ DenotedSpeciesTypeComponentIndex_setSpeciesTypeComponentIndex(DenotedSpeciesType
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -715,8 +711,8 @@ DenotedSpeciesTypeComponentIndex_unsetSpeciesTypeComponentIndex(DenotedSpeciesTy
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -726,8 +722,8 @@ DenotedSpeciesTypeComponentIndex_hasRequiredAttributes(DenotedSpeciesTypeCompone
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 DenotedSpeciesTypeComponentIndex_t *
@@ -740,8 +736,8 @@ ListOfDenotedSpeciesTypeComponentIndexes_getById(ListOf_t * lo, const char * sid
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 DenotedSpeciesTypeComponentIndex_t *
