@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -75,18 +75,11 @@ InSpeciesTypeBond::InSpeciesTypeBond (MultiPkgNamespaces* multins)
  */
 InSpeciesTypeBond::InSpeciesTypeBond (const InSpeciesTypeBond& orig)
   : SBase(orig)
+  , mId  ( orig.mId)
+  , mName  ( orig.mName)
+  , mBindingSite1  ( orig.mBindingSite1)
+  , mBindingSite2  ( orig.mBindingSite2)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mId  = orig.mId;
-    mName  = orig.mName;
-    mBindingSite1  = orig.mBindingSite1;
-    mBindingSite2  = orig.mBindingSite2;
-  }
 }
 
 
@@ -96,11 +89,7 @@ InSpeciesTypeBond::InSpeciesTypeBond (const InSpeciesTypeBond& orig)
 InSpeciesTypeBond&
 InSpeciesTypeBond::operator=(const InSpeciesTypeBond& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment");
-  }
-  else if (&rhs != this)
+  if (&rhs != this)
   {
     SBase::operator=(rhs);
     mId  = rhs.mId;
@@ -226,15 +215,8 @@ InSpeciesTypeBond::setId(const std::string& id)
 int
 InSpeciesTypeBond::setName(const std::string& name)
 {
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else
-  {
-    mName = name;
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  mName = name;
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -244,11 +226,7 @@ InSpeciesTypeBond::setName(const std::string& name)
 int
 InSpeciesTypeBond::setBindingSite1(const std::string& bindingSite1)
 {
-  if (&(bindingSite1) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(bindingSite1)))
+  if (!(SyntaxChecker::isValidInternalSId(bindingSite1)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -266,11 +244,7 @@ InSpeciesTypeBond::setBindingSite1(const std::string& bindingSite1)
 int
 InSpeciesTypeBond::setBindingSite2(const std::string& bindingSite2)
 {
-  if (&(bindingSite2) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(bindingSite2)))
+  if (!(SyntaxChecker::isValidInternalSId(bindingSite2)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -518,8 +492,11 @@ InSpeciesTypeBond::readAttributes (const XMLAttributes& attributes,
    * happened immediately prior to this read
   */
 
+  ListOfInSpeciesTypeBonds * parentListOf =
+      static_cast<ListOfInSpeciesTypeBonds*>(getParentSBMLObject());
+
   if (getErrorLog() != NULL &&
-      static_cast<ListOfInSpeciesTypeBonds*>(getParentSBMLObject())->size() < 2)
+      parentListOf->size() < 2)
   {
     numErrs = getErrorLog()->getNumErrors();
     for (int n = numErrs-1; n >= 0; n--)
@@ -529,16 +506,18 @@ InSpeciesTypeBond::readAttributes (const XMLAttributes& attributes,
         const std::string details =
               getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiLofInSptBnds_AllowedAtts,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                  parentListOf->getLine(), parentListOf->getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
                    getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiLofInSptBnds_AllowedAtts,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                  parentListOf->getLine(), parentListOf->getColumn());
       }
     }
   }
@@ -556,16 +535,18 @@ InSpeciesTypeBond::readAttributes (const XMLAttributes& attributes,
         const std::string details =
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiInSptBnd_AllowedMultiAtts,
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                       getLine(), getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiInSptBnd_AllowedCoreAtts,
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                       getLine(), getColumn());
       }
     }
   }
@@ -585,9 +566,12 @@ InSpeciesTypeBond::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mId, getLevel(), getVersion(), "<InSpeciesTypeBond>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mId) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mId) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax);
+        std::string details = "The syntax of the attribute id='" + mId + "' does not conform.";
+        getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                   getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                   getLine(), getColumn());
     }
   }
 
@@ -619,18 +603,20 @@ InSpeciesTypeBond::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mBindingSite1, getLevel(), getVersion(), "<InSpeciesTypeBond>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mBindingSite1) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mBindingSite1) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute bindingSite1='" + mBindingSite1 + 
-        "' does not conform.");
+      std::string details = "The syntax of the attribute bindingSite1='" + mBindingSite1 + "' does not conform.";
+      getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                 getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                 getLine(), getColumn());
     }
   }
   else
   {
     std::string message = "Multi attribute 'bindingSite1' is missing.";
-    getErrorLog()->logPackageError("multi", MultiUnknownError,
-                   getPackageVersion(), sbmlLevel, sbmlVersion, message);
+    getErrorLog()->logPackageError("multi", MultiInSptBnd_AllowedMultiAtts,
+                   getPackageVersion(), sbmlLevel, sbmlVersion, message,
+                   getLine(), getColumn());
   }
 
   //
@@ -646,17 +632,19 @@ InSpeciesTypeBond::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mBindingSite2, getLevel(), getVersion(), "<InSpeciesTypeBond>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mBindingSite2) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mBindingSite2) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
         "The syntax of the attribute bindingSite2='" + mBindingSite2 + "' does not conform.");
     }
   }
   else
   {
-    std::string message = "Multi attribute 'bindingSite2' is missing.";
-    getErrorLog()->logPackageError("multi", MultiUnknownError,
-                   getPackageVersion(), sbmlLevel, sbmlVersion, message);
+    std::string details = "The syntax of the attribute bindingSite2='" + mBindingSite2 + "' does not conform.";
+    getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+               getPackageVersion(), sbmlLevel, sbmlVersion, details,
+               getLine(), getColumn());
+
   }
 
 }
@@ -849,6 +837,7 @@ ListOfInSpeciesTypeBonds::createObject(XMLInputStream& stream)
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     object = new InSpeciesTypeBond(multins);
     appendAndOwn(object);
+    delete multins;
   }
 
   return object;
@@ -872,7 +861,8 @@ ListOfInSpeciesTypeBonds::writeXMLNS(XMLOutputStream& stream) const
 
   if (prefix.empty())
   {
-    if (getNamespaces()->hasURI(MultiExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(MultiExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(MultiExtension::getXmlnsL3V1V1(),prefix);
     }
@@ -885,7 +875,7 @@ ListOfInSpeciesTypeBonds::writeXMLNS(XMLOutputStream& stream) const
   /** @endcond doxygenLibsbmlInternal */
 
 
-/**
+/*
  * 
  */
 LIBSBML_EXTERN
@@ -897,7 +887,7 @@ InSpeciesTypeBond_create(unsigned int level, unsigned int version,
 }
 
 
-/**
+/*
  * 
  */
 LIBSBML_EXTERN
@@ -909,8 +899,8 @@ InSpeciesTypeBond_free(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 InSpeciesTypeBond_t *
@@ -927,8 +917,8 @@ InSpeciesTypeBond_clone(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 char *
@@ -941,8 +931,8 @@ InSpeciesTypeBond_getId(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 char *
@@ -955,8 +945,8 @@ InSpeciesTypeBond_getName(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 char *
@@ -969,8 +959,8 @@ InSpeciesTypeBond_getBindingSite1(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 char *
@@ -983,8 +973,8 @@ InSpeciesTypeBond_getBindingSite2(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -994,8 +984,8 @@ InSpeciesTypeBond_isSetId(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1005,8 +995,8 @@ InSpeciesTypeBond_isSetName(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1016,8 +1006,8 @@ InSpeciesTypeBond_isSetBindingSite1(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1027,8 +1017,8 @@ InSpeciesTypeBond_isSetBindingSite2(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1038,8 +1028,8 @@ InSpeciesTypeBond_setId(InSpeciesTypeBond_t * istb, const char * id)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1049,8 +1039,8 @@ InSpeciesTypeBond_setName(InSpeciesTypeBond_t * istb, const char * name)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1060,8 +1050,8 @@ InSpeciesTypeBond_setBindingSite1(InSpeciesTypeBond_t * istb, const char * bindi
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1071,8 +1061,8 @@ InSpeciesTypeBond_setBindingSite2(InSpeciesTypeBond_t * istb, const char * bindi
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1082,8 +1072,8 @@ InSpeciesTypeBond_unsetId(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1093,8 +1083,8 @@ InSpeciesTypeBond_unsetName(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1104,8 +1094,8 @@ InSpeciesTypeBond_unsetBindingSite1(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1115,8 +1105,8 @@ InSpeciesTypeBond_unsetBindingSite2(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1126,8 +1116,8 @@ InSpeciesTypeBond_hasRequiredAttributes(InSpeciesTypeBond_t * istb)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 InSpeciesTypeBond_t *
@@ -1140,8 +1130,8 @@ ListOfInSpeciesTypeBonds_getById(ListOf_t * lo, const char * sid)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 InSpeciesTypeBond_t *
