@@ -87,23 +87,13 @@ SpeciesFeature::SpeciesFeature (MultiPkgNamespaces* multins)
  */
 SpeciesFeature::SpeciesFeature (const SpeciesFeature& orig)
   : SBase(orig)
+  , mId  ( orig.mId)
+  , mSpeciesFeatureType  ( orig.mSpeciesFeatureType)
+  , mOccur  ( orig.mOccur)
+  , mIsSetOccur  ( orig.mIsSetOccur)
+  , mComponent  ( orig.mComponent)
+  , mSpeciesFeatureValues  ( orig.mSpeciesFeatureValues)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mId  = orig.mId;
-    mSpeciesFeatureType  = orig.mSpeciesFeatureType;
-    mOccur  = orig.mOccur;
-    mIsSetOccur  = orig.mIsSetOccur;
-    mComponent  = orig.mComponent;
-    mSpeciesFeatureValues  = orig.mSpeciesFeatureValues;
-
-    // connect to child objects
-    connectToChild();
-  }
 }
 
 
@@ -113,11 +103,7 @@ SpeciesFeature::SpeciesFeature (const SpeciesFeature& orig)
 SpeciesFeature&
 SpeciesFeature::operator=(const SpeciesFeature& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment");
-  }
-  else if (&rhs != this)
+  if (&rhs != this)
   {
     SBase::operator=(rhs);
     mId  = rhs.mId;
@@ -248,11 +234,7 @@ SpeciesFeature::setId(const std::string& id)
 int
 SpeciesFeature::setSpeciesFeatureType(const std::string& speciesFeatureType)
 {
-  if (&(speciesFeatureType) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(speciesFeatureType)))
+  if (!(SyntaxChecker::isValidInternalSId(speciesFeatureType)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -282,11 +264,7 @@ SpeciesFeature::setOccur(unsigned int occur)
 int
 SpeciesFeature::setComponent(const std::string& component)
 {
-  if (&(component) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(component)))
+  if (!(SyntaxChecker::isValidInternalSId(component)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -648,7 +626,11 @@ SpeciesFeature::accept (SBMLVisitor& v) const
 {
   v.visit(*this);
 
-/* VISIT CHILDREN */
+  // SpeciesFeatureValue
+  for(unsigned int i = 0; i < getNumSpeciesFeatureValues(); i++)
+  {
+    getSpeciesFeatureValue(i)->accept(v);
+  }
 
   v.leave(*this);
 
@@ -772,8 +754,10 @@ SpeciesFeature::readAttributes (const XMLAttributes& attributes,
    * happened immediately prior to this read
   */
 
-  if (getErrorLog() != NULL &&
-      static_cast<ListOfSpeciesFeatures*>(getParentSBMLObject())->size() < 2)
+  ListOfSpeciesFeatures * parentListOf =
+      static_cast<ListOfSpeciesFeatures*>(getParentSBMLObject());
+
+  if (getErrorLog() != NULL && parentListOf->size() < 2)
   {
     numErrs = getErrorLog()->getNumErrors();
     for (int n = numErrs-1; n >= 0; n--)
@@ -783,16 +767,18 @@ SpeciesFeature::readAttributes (const XMLAttributes& attributes,
         const std::string details =
               getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiLofSpeFtrs_AllowedMultiAtts,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                  parentListOf->getLine(), parentListOf->getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
                    getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiLofSpeFtrs_AllowedCoreAtts,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                  parentListOf->getLine(), parentListOf->getColumn());
       }
     }
   }
@@ -810,16 +796,18 @@ SpeciesFeature::readAttributes (const XMLAttributes& attributes,
         const std::string details =
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiSpeFtr_AllowedMultiAtts,
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                       getLine(), getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiSpeFtr_AllowedCoreAtts,
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                       getLine(), getColumn());
       }
     }
   }
@@ -841,8 +829,10 @@ SpeciesFeature::readAttributes (const XMLAttributes& attributes,
     }
     else if (SyntaxChecker::isValidSBMLSId(mId) == false && getErrorLog() != NULL)
     {
-      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute id='" + mId + "' does not conform.");
+        std::string details = "The syntax of the attribute id='" + mId + "' does not conform.";
+        getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                   getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                   getLine(), getColumn());
     }
   }
 
@@ -861,9 +851,10 @@ SpeciesFeature::readAttributes (const XMLAttributes& attributes,
     }
     else if (SyntaxChecker::isValidSBMLSId(mSpeciesFeatureType) == false && getErrorLog() != NULL)
     {
-      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute speciesFeatureType='" + mSpeciesFeatureType 
-        + "' does not conform.");
+        std::string details = "The syntax of the attribute speciesFeatureType='" + mSpeciesFeatureType + "' does not conform.";
+        getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                   getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                   getLine(), getColumn());
     }
   }
   else
@@ -914,8 +905,10 @@ SpeciesFeature::readAttributes (const XMLAttributes& attributes,
     }
     else if (SyntaxChecker::isValidSBMLSId(mComponent) == false && getErrorLog() != NULL)
     {
-      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute component='" + mComponent + "' does not conform.");
+        std::string details = "The syntax of the attribute component='" + mComponent + "' does not conform.";
+        getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                   getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                   getLine(), getColumn());
     }
   }
 
@@ -1295,8 +1288,9 @@ ListOfSpeciesFeatures::readAttributes (const XMLAttributes& attributes,
        mRelation = Relation_fromString( relation.c_str() );
        if (SpeciesFeature_isValidRelation(mRelation) == 0)
        {
-          getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), getLevel(), getVersion());
+          getErrorLog()->logPackageError("multi", MultiLofSpeFtrs_RelationAtt_Ref,
+                       getPackageVersion(), getLevel(), getVersion(), "",
+                       getLine(), getColumn());
        }
     }
   }
