@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -73,17 +73,10 @@ SpeciesFeatureChange::SpeciesFeatureChange (MultiPkgNamespaces* multins)
  */
 SpeciesFeatureChange::SpeciesFeatureChange (const SpeciesFeatureChange& orig)
   : SBase(orig)
+  , mId  ( orig.mId)
+  , mReactantSpeciesFeature  ( orig.mReactantSpeciesFeature)
+  , mProductSpeciesFeature  ( orig.mProductSpeciesFeature)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mId  = orig.mId;
-    mReactantSpeciesFeature  = orig.mReactantSpeciesFeature;
-    mProductSpeciesFeature  = orig.mProductSpeciesFeature;
-  }
 }
 
 
@@ -93,11 +86,7 @@ SpeciesFeatureChange::SpeciesFeatureChange (const SpeciesFeatureChange& orig)
 SpeciesFeatureChange&
 SpeciesFeatureChange::operator=(const SpeciesFeatureChange& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment");
-  }
-  else if (&rhs != this)
+  if (&rhs != this)
   {
     SBase::operator=(rhs);
     mId  = rhs.mId;
@@ -202,11 +191,7 @@ SpeciesFeatureChange::setId(const std::string& id)
 int
 SpeciesFeatureChange::setReactantSpeciesFeature(const std::string& reactantSpeciesFeature)
 {
-  if (&(reactantSpeciesFeature) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(reactantSpeciesFeature)))
+  if (!(SyntaxChecker::isValidInternalSId(reactantSpeciesFeature)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -224,11 +209,7 @@ SpeciesFeatureChange::setReactantSpeciesFeature(const std::string& reactantSpeci
 int
 SpeciesFeatureChange::setProductSpeciesFeature(const std::string& productSpeciesFeature)
 {
-  if (&(productSpeciesFeature) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(productSpeciesFeature)))
+  if (!(SyntaxChecker::isValidInternalSId(productSpeciesFeature)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -456,8 +437,10 @@ SpeciesFeatureChange::readAttributes (const XMLAttributes& attributes,
    * happened immediately prior to this read
   */
 
-  if (getErrorLog() != NULL &&
-      static_cast<ListOfSpeciesFeatureChanges*>(getParentSBMLObject())->size() < 2)
+  ListOfSpeciesFeatureChanges * parentListOf =
+      static_cast<ListOfSpeciesFeatureChanges*>(getParentSBMLObject());
+
+  if (getErrorLog() != NULL && parentListOf->size() < 2)
   {
     numErrs = getErrorLog()->getNumErrors();
     for (int n = numErrs-1; n >= 0; n--)
@@ -467,16 +450,18 @@ SpeciesFeatureChange::readAttributes (const XMLAttributes& attributes,
         const std::string details =
               getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiLofSpeFtrChgs_AllowedAtts,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                  parentListOf->getLine(), parentListOf->getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
                    getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiLofSpeFtrChgs_AllowedAtts,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                  parentListOf->getLine(), parentListOf->getColumn());
       }
     }
   }
@@ -494,16 +479,18 @@ SpeciesFeatureChange::readAttributes (const XMLAttributes& attributes,
         const std::string details =
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiSpeFtrChg_AllowedMultiAtts,
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                       getLine(), getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiSpeFtrChg_AllowedCoreAtts,
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                       getLine(), getColumn());
       }
     }
   }
@@ -523,9 +510,12 @@ SpeciesFeatureChange::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mId, getLevel(), getVersion(), "<SpeciesFeatureChange>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mId) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mId) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax);
+      std::string details = "The syntax of the attribute id='" + mId + "' does not conform.";
+      getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                 getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                 getLine(), getColumn());
     }
   }
 
@@ -542,11 +532,12 @@ SpeciesFeatureChange::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mReactantSpeciesFeature, getLevel(), getVersion(), "<SpeciesFeatureChange>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mReactantSpeciesFeature) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mReactantSpeciesFeature) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute reactantSpeciesFeature='" 
-        + mReactantSpeciesFeature + "' does not conform.");
+        std::string details = "The syntax of the attribute reactantSpeciesFeature='" + mReactantSpeciesFeature + "' does not conform.";
+        getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                   getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                   getLine(), getColumn());
     }
   }
   else
@@ -569,11 +560,12 @@ SpeciesFeatureChange::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mProductSpeciesFeature, getLevel(), getVersion(), "<SpeciesFeatureChange>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mProductSpeciesFeature) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mProductSpeciesFeature) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute productSpeciesFeature='" 
-        + mProductSpeciesFeature + "' does not conform.");
+        std::string details = "The syntax of the attribute productSpeciesFeature='" + mProductSpeciesFeature + "' does not conform.";
+        getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                   getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                   getLine(), getColumn());
     }
   }
   else
@@ -770,6 +762,7 @@ ListOfSpeciesFeatureChanges::createObject(XMLInputStream& stream)
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     object = new SpeciesFeatureChange(multins);
     appendAndOwn(object);
+    delete multins;
   }
 
   return object;
@@ -793,7 +786,8 @@ ListOfSpeciesFeatureChanges::writeXMLNS(XMLOutputStream& stream) const
 
   if (prefix.empty())
   {
-    if (getNamespaces()->hasURI(MultiExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(MultiExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(MultiExtension::getXmlnsL3V1V1(),prefix);
     }
