@@ -86,23 +86,15 @@ SpeciesTypeComponentIndex::SpeciesTypeComponentIndex (MultiPkgNamespaces* multin
  */
 SpeciesTypeComponentIndex::SpeciesTypeComponentIndex (const SpeciesTypeComponentIndex& orig)
   : SBase(orig)
+  , mId  ( orig.mId)
+  , mComponent  ( orig.mComponent)
+  , mOccur  ( orig.mOccur)
+  , mIsSetOccur  ( orig.mIsSetOccur)
+  , mIdentifyingParent  ( orig.mIdentifyingParent)
+  , mDenotedSpeciesTypeComponentIndexes  ( orig.mDenotedSpeciesTypeComponentIndexes)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mId  = orig.mId;
-    mComponent  = orig.mComponent;
-    mOccur  = orig.mOccur;
-    mIsSetOccur  = orig.mIsSetOccur;
-    mIdentifyingParent  = orig.mIdentifyingParent;
-    mDenotedSpeciesTypeComponentIndexes  = orig.mDenotedSpeciesTypeComponentIndexes;
-
-    // connect to child objects
-    connectToChild();
-  }
+  // connect to child objects
+  connectToChild();
 }
 
 
@@ -112,11 +104,7 @@ SpeciesTypeComponentIndex::SpeciesTypeComponentIndex (const SpeciesTypeComponent
 SpeciesTypeComponentIndex&
 SpeciesTypeComponentIndex::operator=(const SpeciesTypeComponentIndex& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment");
-  }
-  else if (&rhs != this)
+  if (&rhs != this)
   {
     SBase::operator=(rhs);
     mId  = rhs.mId;
@@ -247,11 +235,7 @@ SpeciesTypeComponentIndex::setId(const std::string& id)
 int
 SpeciesTypeComponentIndex::setComponent(const std::string& component)
 {
-  if (&(component) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(component)))
+  if (!(SyntaxChecker::isValidInternalSId(component)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -281,11 +265,7 @@ SpeciesTypeComponentIndex::setOccur(unsigned int occur)
 int
 SpeciesTypeComponentIndex::setIdentifyingParent(const std::string& identifyingParent)
 {
-  if (&(identifyingParent) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(identifyingParent)))
+  if (!(SyntaxChecker::isValidInternalSId(identifyingParent)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -650,9 +630,11 @@ SpeciesTypeComponentIndex::accept (SBMLVisitor& v) const
 {
   v.visit(*this);
 
-/* VISIT CHILDREN */
-
-  v.leave(*this);
+  // DenotedSpeciesTypeComponentIndex
+  for(unsigned int i = 0; i < getNumDenotedSpeciesTypeComponentIndexes(); i++)
+  {
+    getDenotedSpeciesTypeComponentIndex(i)->accept(v);
+  }
 
   return true;
 }
@@ -774,8 +756,11 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
    * happened immediately prior to this read
   */
 
+  ListOfSpeciesTypeComponentIndexes * parentListOf =
+      static_cast<ListOfSpeciesTypeComponentIndexes*>(getParentSBMLObject());
+
   if (getErrorLog() != NULL &&
-      static_cast<ListOfSpeciesTypeComponentIndexes*>(getParentSBMLObject())->size() < 2)
+      parentListOf->size() < 2)
   {
     numErrs = getErrorLog()->getNumErrors();
     for (int n = numErrs-1; n >= 0; n--)
@@ -785,16 +770,18 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
         const std::string details =
               getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiLofSptCpoInds_AllowedAtts,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                  parentListOf->getLine(), parentListOf->getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
                    getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiLofSptCpoInds_AllowedAtts,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                  parentListOf->getLine(), parentListOf->getColumn());
       }
     }
   }
@@ -812,16 +799,18 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
         const std::string details =
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiSptCpoInd_AllowedMultiAtts,
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                       getLine(), getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiSptCpoInd_AllowedCoreAtts,
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                       getLine(), getColumn());
       }
     }
   }
@@ -843,15 +832,18 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
     }
     else if (SyntaxChecker::isValidSBMLSId(mId) == false && getErrorLog() != NULL)
     {
-      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute id='" + mId + "' does not conform.");
+        std::string details = "The syntax of the attribute id='" + mId + "' does not conform.";
+        getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                   getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                   getLine(), getColumn());
     }
   }
   else
   {
     std::string message = "Multi attribute 'id' is missing.";
     getErrorLog()->logPackageError("multi", MultiUnknownError,
-                   getPackageVersion(), sbmlLevel, sbmlVersion, message);
+                   getPackageVersion(), sbmlLevel, sbmlVersion, message,
+                   getLine(), getColumn());
   }
 
   //
@@ -869,15 +861,18 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
     }
     else if (SyntaxChecker::isValidSBMLSId(mComponent) == false && getErrorLog() != NULL)
     {
-      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute component='" + mComponent + "' does not conform.");
+        std::string details = "The syntax of the attribute component='" + mComponent + "' does not conform.";
+        getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                   getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                   getLine(), getColumn());
     }
   }
   else
   {
     std::string message = "Multi attribute 'component' is missing.";
     getErrorLog()->logPackageError("multi", MultiUnknownError,
-                   getPackageVersion(), sbmlLevel, sbmlVersion, message);
+                   getPackageVersion(), sbmlLevel, sbmlVersion, message,
+                   getLine(), getColumn());
   }
 
   //
@@ -893,15 +888,18 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
       if (getErrorLog()->getNumErrors() == numErrs + 1 &&
               getErrorLog()->contains(XMLAttributeTypeMismatch))
       {
+        std::string message = getErrorLog()->getError(numErrs)->getMessage();
         getErrorLog()->remove(XMLAttributeTypeMismatch);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                     getPackageVersion(), sbmlLevel, sbmlVersion);
+        getErrorLog()->logPackageError("multi", MultiSptCpoInd_OccAtt_Ref,
+                     getPackageVersion(), sbmlLevel, sbmlVersion, message,
+                     getLine(), getColumn());
       }
       else
       {
         std::string message = "Multi attribute 'occur' is missing.";
         getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, message);
+                       getPackageVersion(), sbmlLevel, sbmlVersion, message,
+                       getLine(), getColumn());
       }
     }
   }
@@ -921,9 +919,10 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
     }
     else if (SyntaxChecker::isValidSBMLSId(mIdentifyingParent) == false && getErrorLog() != NULL)
     {
-      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute identifyingParent='" + mIdentifyingParent 
-        + "' does not conform.");
+        std::string details = "The syntax of the attribute identifyingParent='" + mIdentifyingParent + "' does not conform.";
+        getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                   getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                   getLine(), getColumn());
     }
   }
 
