@@ -79,20 +79,13 @@ SpeciesTypeInstance::SpeciesTypeInstance (MultiPkgNamespaces* multins)
  */
 SpeciesTypeInstance::SpeciesTypeInstance (const SpeciesTypeInstance& orig)
   : SBase(orig)
+  , mId  ( orig.mId)
+  , mName  ( orig.mName)
+  , mSpeciesType  ( orig.mSpeciesType)
+  , mCompartmentReference  ( orig.mCompartmentReference)
+  , mOccur  ( orig.mOccur)
+  , mIsSetOccur  ( orig.mIsSetOccur)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mId  = orig.mId;
-    mName  = orig.mName;
-    mSpeciesType  = orig.mSpeciesType;
-    mCompartmentReference  = orig.mCompartmentReference;
-    mOccur  = orig.mOccur;
-    mIsSetOccur  = orig.mIsSetOccur;
-  }
 }
 
 
@@ -102,11 +95,7 @@ SpeciesTypeInstance::SpeciesTypeInstance (const SpeciesTypeInstance& orig)
 SpeciesTypeInstance&
 SpeciesTypeInstance::operator=(const SpeciesTypeInstance& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment");
-  }
-  else if (&rhs != this)
+  if (&rhs != this)
   {
     SBase::operator=(rhs);
     mId  = rhs.mId;
@@ -254,15 +243,8 @@ SpeciesTypeInstance::setId(const std::string& id)
 int
 SpeciesTypeInstance::setName(const std::string& name)
 {
-  if (&(name) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else
-  {
-    mName = name;
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  mName = name;
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -272,11 +254,7 @@ SpeciesTypeInstance::setName(const std::string& name)
 int
 SpeciesTypeInstance::setSpeciesType(const std::string& speciesType)
 {
-  if (&(speciesType) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(speciesType)))
+  if (!(SyntaxChecker::isValidInternalSId(speciesType)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -294,11 +272,7 @@ SpeciesTypeInstance::setSpeciesType(const std::string& speciesType)
 int
 SpeciesTypeInstance::setCompartmentReference(const std::string& compartmentReference)
 {
-  if (&(compartmentReference) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(compartmentReference)))
+  if (!(SyntaxChecker::isValidInternalSId(compartmentReference)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -569,10 +543,10 @@ SpeciesTypeInstance::addExpectedAttributes(ExpectedAttributes& attributes)
  * Read values from the given XMLAttributes set into their specific fields.
  */
 void
-SpeciesTypeInstance::readAttributes (const XMLAttributes& attributes,
-                             const ExpectedAttributes& expectedAttributes)
+SpeciesTypeInstance::readAttributes(const XMLAttributes& attributes,
+    const ExpectedAttributes& expectedAttributes)
 {
-  const unsigned int sbmlLevel   = getLevel  ();
+  const unsigned int sbmlLevel = getLevel();
   const unsigned int sbmlVersion = getVersion();
 
   unsigned int numErrs;
@@ -580,59 +554,71 @@ SpeciesTypeInstance::readAttributes (const XMLAttributes& attributes,
   /* look to see whether an unknown attribute error was logged
    * during the read of the listOfSpeciesTypeInstances - which will have
    * happened immediately prior to this read
-  */
+   */
 
-  if (getErrorLog() != NULL &&
-      static_cast<ListOfSpeciesTypeInstances*>(getParentSBMLObject())->size() < 2)
-  {
-    numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs-1; n >= 0; n--)
+  ListOfSpeciesTypeInstances * parentListOf =
+      static_cast<ListOfSpeciesTypeInstances*>(getParentSBMLObject());
+
+  if (getErrorLog() != NULL && parentListOf->size() < 2)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
-      {
-        const std::string details =
-              getErrorLog()->getError(n)->getMessage();
-        getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
-      }
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
-      {
-        const std::string details =
-                   getErrorLog()->getError(n)->getMessage();
-        getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
-      }
+      numErrs = getErrorLog()->getNumErrors();
+      for (int n = numErrs - 1; n >= 0; n--)
+        {
+          if (getErrorLog()->getError(n)->getErrorId()
+              == UnknownPackageAttribute)
+            {
+              const std::string details =
+                  getErrorLog()->getError(n)->getMessage();
+              getErrorLog()->remove(UnknownPackageAttribute);
+              getErrorLog()->logPackageError("multi",
+                  MultiLofSptInss_AllowedAtts, getPackageVersion(), sbmlLevel,
+                  sbmlVersion, details, parentListOf->getLine(),
+                  parentListOf->getColumn());
+            }
+          else if (getErrorLog()->getError(n)->getErrorId()
+              == UnknownCoreAttribute)
+            {
+              const std::string details =
+                  getErrorLog()->getError(n)->getMessage();
+              getErrorLog()->remove(UnknownCoreAttribute);
+              getErrorLog()->logPackageError("multi",
+                  MultiLofSptInss_AllowedAtts, getPackageVersion(), sbmlLevel,
+                  sbmlVersion, details, parentListOf->getLine(),
+                  parentListOf->getColumn());
+            }
+        }
     }
-  }
 
   SBase::readAttributes(attributes, expectedAttributes);
 
   // look to see whether an unknown attribute error was logged
   if (getErrorLog() != NULL)
-  {
-    numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs-1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
-      {
-        const std::string details =
-                          getErrorLog()->getError(n)->getMessage();
-        getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
-      }
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
-      {
-        const std::string details =
-                          getErrorLog()->getError(n)->getMessage();
-        getErrorLog()->remove(UnknownCoreAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
-      }
+      numErrs = getErrorLog()->getNumErrors();
+      for (int n = numErrs - 1; n >= 0; n--)
+        {
+          if (getErrorLog()->getError(n)->getErrorId()
+              == UnknownPackageAttribute)
+            {
+              const std::string details =
+                  getErrorLog()->getError(n)->getMessage();
+              getErrorLog()->remove(UnknownPackageAttribute);
+              getErrorLog()->logPackageError("multi",
+                  MultiSptIns_AllowedMultiAtts, getPackageVersion(), sbmlLevel,
+                  sbmlVersion, details, getLine(), getColumn());
+            }
+          else if (getErrorLog()->getError(n)->getErrorId()
+              == UnknownCoreAttribute)
+            {
+              const std::string details =
+                  getErrorLog()->getError(n)->getMessage();
+              getErrorLog()->remove(UnknownCoreAttribute);
+              getErrorLog()->logPackageError("multi",
+                  MultiSptIns_AllowedCoreAtts, getPackageVersion(), sbmlLevel,
+                  sbmlVersion, details, getLine(), getColumn());
+            }
+        }
     }
-  }
 
   bool assigned = false;
 
@@ -641,26 +627,31 @@ SpeciesTypeInstance::readAttributes (const XMLAttributes& attributes,
   //
   assigned = attributes.readInto("id", mId);
 
-   if (assigned == true)
-  {
-    // check string is not empty and correct syntax
+  if (assigned == true)
+    {
+      // check string is not empty and correct syntax
 
-    if (mId.empty() == true)
-    {
-      logEmptyString(mId, getLevel(), getVersion(), "<SpeciesTypeInstance>");
+      if (mId.empty() == true)
+        {
+          logEmptyString(mId, getLevel(), getVersion(),
+              "<SpeciesTypeInstance>");
+        }
+      else if (SyntaxChecker::isValidSBMLSId(mId)
+          == false&& getErrorLog() != NULL)
+        {
+          std::string details = "The syntax of the attribute id='" + mId + "' does not conform.";
+          getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                     getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                     getLine(), getColumn());
+        }
     }
-    else if (SyntaxChecker::isValidSBMLSId(mId) == false && getErrorLog() != NULL)
-    {
-      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute id='" + mId + "' does not conform.");
-    }
-  }
   else
-  {
-    std::string message = "Multi attribute 'id' is missing.";
-    getErrorLog()->logPackageError("multi", MultiUnknownError,
-                   getPackageVersion(), sbmlLevel, sbmlVersion, message);
-  }
+    {
+      std::string message = "Multi attribute 'id' is missing.";
+      getErrorLog()->logPackageError("multi", MultiUnknownError,
+          getPackageVersion(), sbmlLevel, sbmlVersion, message,
+          getLine(), getColumn());
+    }
 
   //
   // name string   ( use = "optional" )
@@ -668,14 +659,15 @@ SpeciesTypeInstance::readAttributes (const XMLAttributes& attributes,
   assigned = attributes.readInto("name", mName);
 
   if (assigned == true)
-  {
-    // check string is not empty
-
-    if (mName.empty() == true)
     {
-      logEmptyString(mName, getLevel(), getVersion(), "<SpeciesTypeInstance>");
+      // check string is not empty
+
+      if (mName.empty() == true)
+        {
+          logEmptyString(mName, getLevel(), getVersion(),
+              "<SpeciesTypeInstance>");
+        }
     }
-  }
 
   //
   // speciesType SIdRef   ( use = "required" )
@@ -683,25 +675,30 @@ SpeciesTypeInstance::readAttributes (const XMLAttributes& attributes,
   assigned = attributes.readInto("speciesType", mSpeciesType);
 
   if (assigned == true)
-  {
-    // check string is not empty and correct syntax
+    {
+      // check string is not empty and correct syntax
 
-    if (mSpeciesType.empty() == true)
-    {
-      logEmptyString(mSpeciesType, getLevel(), getVersion(), "<SpeciesTypeInstance>");
+      if (mSpeciesType.empty() == true)
+        {
+          logEmptyString(mSpeciesType, getLevel(), getVersion(),
+              "<SpeciesTypeInstance>");
+        }
+      else if (SyntaxChecker::isValidSBMLSId(mSpeciesType)
+          == false&& getErrorLog() != NULL)
+        {
+          std::string details = "The syntax of the attribute speciesType='" + mSpeciesType + "' does not conform.";
+          getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                     getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                     getLine(), getColumn());
+        }
     }
-    else if (SyntaxChecker::isValidSBMLSId(mSpeciesType) == false && getErrorLog() != NULL)
-    {
-      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute speciesType='" + mSpeciesType + "' does not conform.");
-    }
-  }
   else
-  {
-    std::string message = "Multi attribute 'speciesType' is missing.";
-    getErrorLog()->logPackageError("multi", MultiUnknownError,
-                   getPackageVersion(), sbmlLevel, sbmlVersion, message);
-  }
+    {
+      std::string message = "Multi attribute 'speciesType' is missing.";
+      getErrorLog()->logPackageError("multi", MultiUnknownError,
+          getPackageVersion(), sbmlLevel, sbmlVersion, message,
+          getLine(), getColumn());
+    }
 
   //
   // compartmentReference SIdRef   ( use = "optional" )
@@ -709,20 +706,24 @@ SpeciesTypeInstance::readAttributes (const XMLAttributes& attributes,
   assigned = attributes.readInto("compartmentReference", mCompartmentReference);
 
   if (assigned == true)
-  {
-    // check string is not empty and correct syntax
+    {
+      // check string is not empty and correct syntax
 
-    if (mCompartmentReference.empty() == true)
-    {
-      logEmptyString(mCompartmentReference, getLevel(), getVersion(), "<SpeciesTypeInstance>");
+      if (mCompartmentReference.empty() == true)
+        {
+          logEmptyString(mCompartmentReference, getLevel(), getVersion(),
+              "<SpeciesTypeInstance>");
+        }
+      else if (SyntaxChecker::isValidSBMLSId(mCompartmentReference)
+          == false&& getErrorLog() != NULL)
+        {
+          std::string details = "The syntax of the attribute compartmentReference='" + mCompartmentReference + "' does not conform.";
+          getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                     getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                     getLine(), getColumn());
+
+        }
     }
-    else if (SyntaxChecker::isValidSBMLSId(mCompartmentReference) == false && getErrorLog() != NULL)
-    {
-      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute compartmentReference='" + 
-        mCompartmentReference + "' does not conform.");
-    }
-  }
 
   //
   // occur unsigned int   ( use = "required" )
@@ -731,25 +732,28 @@ SpeciesTypeInstance::readAttributes (const XMLAttributes& attributes,
   mIsSetOccur = attributes.readInto("occur", mOccur);
 
   if (mIsSetOccur == false)
-  {
-    if (getErrorLog() != NULL)
     {
-      if (getErrorLog()->getNumErrors() == numErrs + 1 &&
-              getErrorLog()->contains(XMLAttributeTypeMismatch))
-      {
-        getErrorLog()->remove(XMLAttributeTypeMismatch);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                     getPackageVersion(), sbmlLevel, sbmlVersion);
-      }
-      else
-      {
-        std::string message = "Multi attribute 'occur' is missing.";
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, message);
-      }
+      if (getErrorLog() != NULL)
+        {
+          if (getErrorLog()->getNumErrors() == numErrs + 1
+              && getErrorLog()->contains(numErrs))
+            {
+              std::string message = getErrorLog()->getError(
+                  XMLAttributeTypeMismatch)->getMessage();
+              getErrorLog()->remove(XMLAttributeTypeMismatch);
+              getErrorLog()->logPackageError("multi", MultiSptIns_OccAtt_Ref,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, message,
+                  getLine(), getColumn());
+            }
+          else
+            {
+              std::string message = "Multi attribute 'occur' is missing.";
+              getErrorLog()->logPackageError("multi", MultiUnknownError,
+                  getPackageVersion(), sbmlLevel, sbmlVersion, message,
+                  getLine(), getColumn());
+            }
+        }
     }
-  }
-
 }
 
 
