@@ -2,6 +2,7 @@
  * @file:   MultiValidator.cpp
  * @brief:  Implementation of the MultiValidator class
  * @author: SBMLTeam
+ * @author: Fengkai Zhang
  *
  * <!--------------------------------------------------------------------------
  * This file is part of libSBML.  Please visit http://sbml.org for more
@@ -149,6 +150,7 @@ struct MultiValidatorConstraints
   ConstraintSet<SpeciesFeature>      mSpeciesFeature;
   ConstraintSet<SpeciesTypeComponentMapInProduct>      mSpeciesTypeComponentMapInProduct;
   ConstraintSet<MultiSpeciesType>      mMultiSpeciesType;
+  ConstraintSet<Compartment>           mCompartment;
   map<VConstraint*,bool> ptrMap;
 
   ~MultiValidatorConstraints ();
@@ -275,6 +277,11 @@ MultiValidatorConstraints::add (VConstraint* c)
     mMultiSpeciesType.add( static_cast< TConstraint<MultiSpeciesType>* >(c) );
     return;
   }
+  if (dynamic_cast< TConstraint<Compartment>* >(c) != NULL)
+  {
+    mCompartment.add( static_cast< TConstraint<Compartment>* >(c) );
+    return;
+  }
 
 }
 
@@ -301,8 +308,16 @@ public:
 
   MultiValidatingVisitor (MultiValidator& v, const Model& m) : v(v), m(m) { }
 
+
   using SBMLVisitor::visit;
 
+  // model
+  virtual void visit (const Model &x)
+  {
+    v.mMultiConstraints->mModel.applyTo(m, x);
+    v.mMultiConstraints->mModel.empty();
+  }
+
   bool visit (const PossibleSpeciesFeatureValue &x)
   {
     v.mMultiConstraints->mPossibleSpeciesFeatureValue.applyTo(m, x);
@@ -381,9 +396,14 @@ public:
     return !v.mMultiConstraints->mMultiSpeciesType.empty();
   }
 
+  bool visit (const Compartment &x)
+  {
+    v.mMultiConstraints->mCompartment.applyTo(m, x);
+    return !v.mMultiConstraints->mCompartment.empty();
+  }
   virtual bool visit(const SBase &x)
   {
-    if (&x == NULL || x.getPackageName() != "multi")
+    if (x.getPackageName() != "multi")
     {
       return SBMLVisitor::visit(x);
     }
@@ -496,6 +516,13 @@ MultiValidator::addConstraint (VConstraint* c)
   mMultiConstraints->add(c);
 }
 
+#define ACCEPT_MULTI(x,vv)\
+{\
+   const SBasePlugin *plugin = static_cast <const SBasePlugin *>((x)->getPlugin(MultiExtension::getPackageName()));\
+   if (plugin != NULL) plugin->accept(vv);\
+}
+
+
 
 /*
  * Validates the given SBMLDocument.  Failures logged during
@@ -506,21 +533,57 @@ MultiValidator::addConstraint (VConstraint* c)
 unsigned int
 MultiValidator::validate (const SBMLDocument& d)
 {
-  if (&d == NULL) return 0;
 
   const Model* m = d.getModel();
 
+  // model
   if (m != NULL)
   {
     MultiValidatingVisitor vv(*this, *m);
 
-    const MultiModelPlugin* plugin = 
-      static_cast <const MultiModelPlugin *> (m->getPlugin("multi"));
-      
-    if (plugin != NULL)
+    // Model
+    ACCEPT_MULTI(m, vv);
+
+    // Compartment
+    for (int i = 0; i < m->getNumCompartments(); i++)
     {
-      plugin->accept(vv);
+      ACCEPT_MULTI(m->getCompartment(i),vv);
     }
+
+    //  Species
+    for (int i = 0; i < m->getNumSpecies(); i++)
+    {
+      ACCEPT_MULTI(m->getSpecies(i),vv);
+    }
+
+    // ListOfReactions
+    ACCEPT_MULTI(m->getListOfReactions(), vv);
+
+    // Reaction
+    for (int i = 0; i < m->getNumReactions(); i++)
+    {
+      const Reaction * r = m->getReaction(i);
+
+      for (int j = 0; j < r->getNumReactants(); j++)
+      {
+        ACCEPT_MULTI(r->getReactant(j),vv);
+      }
+      for (int j = 0; j < r->getNumProducts(); j++)
+      {
+        ACCEPT_MULTI(r->getProduct(j),vv);
+      }
+      for (int j = 0; j < r->getNumModifiers(); j++)
+      {
+        ACCEPT_MULTI(r->getModifier(j),vv);
+      }
+
+      const KineticLaw * kineticLaw = r->getKineticLaw();
+      if (kineticLaw) {
+          const ASTNode * math = kineticLaw->getMath();
+          // TODO for validation of ci elements
+      }
+    }
+
   }
 
   /* ADD ANY OTHER OBJECTS THAT HAVE PLUGINS */
@@ -538,7 +601,6 @@ MultiValidator::validate (const SBMLDocument& d)
 unsigned int
 MultiValidator::validate (const std::string& filename)
 {
-  if (&filename == NULL) return 0;
 
   SBMLReader    reader;
   SBMLDocument& d = *reader.readSBML(filename);
