@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -36,9 +36,7 @@
 #include <sbml/SBMLReader.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -312,7 +310,7 @@ public:
 
   virtual bool visit (const SBase &x)
   {
-    if(&x == NULL || x.getPackageName() != "qual")
+    if(x.getPackageName() != "qual")
     {
       return SBMLVisitor::visit(x);
     }
@@ -416,8 +414,6 @@ QualValidator::addConstraint (VConstraint* c)
 unsigned int
 QualValidator::validate (const SBMLDocument& d)
 {
-  if (&d == NULL) return 0;
-
   const Model* m = d.getModel();
 
   if (m != NULL)
@@ -446,8 +442,6 @@ QualValidator::validate (const SBMLDocument& d)
 unsigned int
 QualValidator::validate (const std::string& filename)
 {
-  if (&filename == NULL) return 0;
-
   SBMLReader    reader;
   SBMLDocument* d = reader.readSBML(filename);
 
