@@ -95,26 +95,18 @@ ParametricObject::ParametricObject (SpatialPkgNamespaces* spatialns)
  */
 ParametricObject::ParametricObject (const ParametricObject& orig)
   : SBase(orig)
+  , mId  ( orig.mId)
+  , mPolygonType  ( orig.mPolygonType)
+  , mDomainType  ( orig.mDomainType)
+  , mPointIndex  ( NULL)
+  , mPointIndexLength  ( orig.mPointIndexLength)
+  , mIsSetPointIndexLength  ( orig.mIsSetPointIndexLength)
+  , mCompression  ( orig.mCompression)
+  , mDataType  ( orig.mDataType)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mId  = orig.mId;
-    mPolygonType  = orig.mPolygonType;
-    mDomainType  = orig.mDomainType;
-    mPointIndex  = NULL;
-    setPointIndex(orig.mPointIndex, orig.mPointIndexLength);
-    mPointIndexLength  = orig.mPointIndexLength;
-    mIsSetPointIndexLength  = orig.mIsSetPointIndexLength;
-    mCompression  = orig.mCompression;
-    mDataType  = orig.mDataType;
-
-    // connect to child objects
-    connectToChild();
-  }
+  setPointIndex(orig.mPointIndex, orig.mPointIndexLength);
+  // connect to child objects
+  connectToChild();
 }
 
 
@@ -124,11 +116,7 @@ ParametricObject::ParametricObject (const ParametricObject& orig)
 ParametricObject&
 ParametricObject::operator=(const ParametricObject& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment");
-  }
-  else if (&rhs != this)
+  if (&rhs != this)
   {
     SBase::operator=(rhs);
     mId  = rhs.mId;
@@ -356,11 +344,7 @@ ParametricObject::setPolygonType(const std::string& polygonType)
 int
 ParametricObject::setDomainType(const std::string& domainType)
 {
-  if (&(domainType) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(domainType)))
+  if (!(SyntaxChecker::isValidInternalSId(domainType)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
