@@ -49,9 +49,7 @@
 #include <sbml/SBMLReader.h>
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -706,7 +704,6 @@ Validator::getFailures () const
 void
 Validator::logFailure (const SBMLError& msg)
 {
-  if (&msg == NULL) return;
   mFailures.push_back(msg);
 }
 
@@ -751,8 +748,6 @@ private:
 unsigned int
 Validator::validate (const SBMLDocument& d)
 {
-  if (&d == NULL) return 0;
-
   Model* m = const_cast<SBMLDocument&>(d).getModel();
 
   if (m != NULL)
@@ -812,8 +807,6 @@ Validator::validate (const SBMLDocument& d)
 unsigned int
 Validator::validate (const std::string& filename)
 {
-  if (&filename == NULL) return 0;
-
   SBMLReader    reader;
   SBMLDocument* d = reader.readSBML(filename);
 
@@ -832,7 +825,6 @@ Validator::validate (const std::string& filename)
 
 
 /** @cond doxygenIgnored */
-
 /** @endcond */
 LIBSBML_CPP_NAMESPACE_END
 
