@@ -49,9 +49,7 @@
 #include "PieceBooleanMathCheck.h"
 
 /** @cond doxygenIgnored */
-
 using namespace std;
-
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -96,11 +94,6 @@ PieceBooleanMathCheck::getPreamble ()
 void
 PieceBooleanMathCheck::checkMath (const Model& m, const ASTNode& node, const SBase & sb)
 {
-  /* should not be here but why not catch it rather than crash*/
-  if (&(node) == NULL)
-  {
-    return;
-  }
 
   ASTNodeType_t type = node.getType();
 
@@ -190,5 +183,4 @@ PieceBooleanMathCheck::getMessage (const ASTNode& node, const SBase& object)
 }
 
 LIBSBML_CPP_NAMESPACE_END
-
 /** @endcond */
