@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -217,8 +217,6 @@ XMLOutputStream::XMLOutputStream (  std::ostream&       stream
  , mNextAmpersandIsRef( false )
  , mSBMLns (NULL)
 {
-  if (&stream == NULL)
-    throw XMLConstructorException();
 
   unsetStringStream();
   mStream.imbue( locale::classic() );
@@ -233,7 +231,6 @@ XMLOutputStream::XMLOutputStream (  std::ostream&       stream
 void
 XMLOutputStream::endElement (const std::string& name, const std::string& prefix)
 {
-  if(&name == NULL) return;
 
   if (mInStart)
   {
@@ -267,7 +264,6 @@ XMLOutputStream::endElement (const std::string& name, const std::string& prefix)
 void
 XMLOutputStream::endElement (const XMLTriple& triple)
 {
-  if(&triple == NULL) return;
 
   if (mInStart)
   {
@@ -310,7 +306,6 @@ XMLOutputStream::setAutoIndent (bool indent)
 void
 XMLOutputStream::startElement (const std::string& name, const std::string& prefix)
 {
-  if (&name == NULL) return; 
 
   if (mInStart)
   {
@@ -341,7 +336,6 @@ XMLOutputStream::startElement (const std::string& name, const std::string& prefi
 void
 XMLOutputStream::startElement (const XMLTriple& triple)
 {
-  if (&triple == NULL) return;
 
   if (mInStart)
   {
@@ -371,7 +365,6 @@ XMLOutputStream::startElement (const XMLTriple& triple)
 void
 XMLOutputStream::startEndElement (const std::string& name, const std::string& prefix)
 {
-  if (&name == NULL) return; 
 
   if (mInStart)
   {
@@ -406,7 +399,6 @@ XMLOutputStream::startEndElement (const std::string& name, const std::string& pr
 void
 XMLOutputStream::startEndElement (const XMLTriple& triple)
 {
-  if (&triple == NULL) return;
 
   if (mInStart)
   {
@@ -440,7 +432,7 @@ XMLOutputStream::startEndElement (const XMLTriple& triple)
 void
 XMLOutputStream::writeAttribute (const std::string& name, const std::string& value)
 {
-  if ( &name == NULL || &value == NULL || value.empty() ) return; 
+  if ( value.empty() ) return; 
 
   mStream << ' ';
 
@@ -531,7 +523,6 @@ XMLOutputStream::writeAttribute (const XMLTriple& triple, const char* value)
 void
 XMLOutputStream::writeAttribute (const std::string& name, const bool& value)
 {
-  if (&name == NULL || &value == NULL) return; 
 
   mStream << ' ';
 
@@ -561,7 +552,6 @@ XMLOutputStream::writeAttribute (const std::string& name, const std::string& pre
 void
 XMLOutputStream::writeAttribute (const XMLTriple& triple, const bool& value)
 {
-  if (&triple == NULL || &value == NULL) return; 
 
   mStream << ' ';
 
@@ -576,7 +566,6 @@ XMLOutputStream::writeAttribute (const XMLTriple& triple, const bool& value)
 void
 XMLOutputStream::writeAttribute (const std::string& name, const double& value)
 {
-  if (&name == NULL || &value == NULL) return; 
 
   mStream << ' ';
 
@@ -617,7 +606,6 @@ XMLOutputStream::writeAttribute (const XMLTriple& triple, const double& value)
 void
 XMLOutputStream::writeAttribute (const std::string& name, const long& value)
 {
-  if (&name == NULL || &value == NULL) return; 
 
   mStream << ' ';
 
@@ -659,7 +647,6 @@ XMLOutputStream::writeAttribute (const XMLTriple& triple, const long& value)
 void
 XMLOutputStream::writeAttribute (const std::string& name, const int& value)
 {
-  if (&name == NULL || &value == NULL) return; 
 
   mStream << ' ';
 
@@ -688,7 +675,6 @@ XMLOutputStream::writeAttribute (const std::string& name, const std::string& pre
 void
 XMLOutputStream::writeAttribute (const XMLTriple& triple, const int& value)
 {
-  if (&triple == NULL || &value == NULL) return; 
 
   mStream << ' ';
 
@@ -703,7 +689,6 @@ XMLOutputStream::writeAttribute (const XMLTriple& triple, const int& value)
 void
 XMLOutputStream::writeAttribute (const std::string& name, const unsigned int& value)
 {
-  if (&name == NULL || &value == NULL) return; 
 
   mStream << ' ';
 
@@ -733,7 +718,6 @@ void
 XMLOutputStream::writeAttribute (  const XMLTriple&     triple
                                  , const unsigned int&  value )
 {
-  if (&triple == NULL || &value == NULL) return; 
 
   mStream << ' ';
 
@@ -1092,17 +1076,46 @@ XMLOutputStringStream::XMLOutputStringStream (  std::ostringstream& stream
   setStringStream();
 }
 
+XMLOwningOutputStringStream::XMLOwningOutputStringStream (  const std::string&  encoding
+                               , bool                writeXMLDecl
+                               , const std::string&  programName
+                               , const std::string&  programVersion)
+  : XMLOutputStringStream(*(new std::ostringstream), encoding, writeXMLDecl, programName, programVersion)
+{
+  
+}
+
+XMLOwningOutputStringStream::~XMLOwningOutputStringStream()
+{
+  delete &mStream;
+}
+
 
 XMLOutputFileStream::XMLOutputFileStream (  std::ofstream& stream
                    , const std::string&  encoding
                    , bool                writeXMLDecl
                    , const std::string&  programName
-                   , const std::string&  programVersion):
-  XMLOutputStream(stream, encoding, writeXMLDecl, 
+                   , const std::string&  programVersion)
+  : XMLOutputStream(stream, encoding, writeXMLDecl, 
                     programName, programVersion)
 {
 }
 
+XMLOwningOutputFileStream::XMLOwningOutputFileStream (  
+                               const std::string&  filename
+                             , const std::string&  encoding
+                             , bool                writeXMLDecl
+                             , const std::string&  programName
+                             , const std::string&  programVersion)
+  : XMLOutputFileStream( *(new std::ofstream(filename.c_str(), std::ios::out)), 
+                         encoding, writeXMLDecl, programName, programVersion)
+{
+}
+
+XMLOwningOutputFileStream::~XMLOwningOutputFileStream()
+{
+  delete &mStream;
+}
 
 #endif /* __cplusplus */
 
@@ -1133,9 +1146,7 @@ XMLOutputStream_createAsString (const char * encoding, int writeXMLDecl)
 {
   if (encoding == NULL) return NULL;
 
-  std::ostringstream *out = new std::ostringstream();
-
-  return new(nothrow) XMLOutputStringStream(*out, encoding, writeXMLDecl);
+  return new(nothrow) XMLOwningOutputStringStream(encoding, writeXMLDecl);
 }
 
 
@@ -1146,34 +1157,38 @@ XMLOutputStream_createAsStringWithProgramInfo (const char * encoding,
 {
   if (encoding == NULL) return NULL;
 
-  std::ostringstream *out = new std::ostringstream();
-
-  return new(nothrow) XMLOutputStringStream(*out, encoding, writeXMLDecl,
+  return new(nothrow) XMLOwningOutputStringStream(encoding, writeXMLDecl,
                              programName, programVersion);
 }
 
 
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createFile (const char * filename, const char * encoding, int writeXMLDecl)
+XMLOutputStream_createFile (const char * filename, const char * encoding, 
+                            int writeXMLDecl)
 {
   if (filename == NULL || encoding == NULL) return NULL;
 
-  std::ofstream *fout = new std::ofstream(filename, std::ios::out);
-  return new(nothrow) XMLOutputFileStream(*fout, encoding, writeXMLDecl);
+  XMLOutputStream_t * out = new(nothrow) 
+                           XMLOwningOutputFileStream(filename, encoding, writeXMLDecl);
+
+  return out;
 }
 
 
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createFileWithProgramInfo (const char * filename, const char * encoding, 
+XMLOutputStream_createFileWithProgramInfo (const char * filename, 
+                                           const char * encoding, 
         int writeXMLDecl, const char * programName, const char * programVersion)
 {
   if (filename == NULL || encoding == NULL) return NULL;
 
-  std::ofstream *fout = new std::ofstream(filename, std::ios::out);
-  return new(nothrow) XMLOutputFileStream(*fout, encoding, writeXMLDecl,
-                          programName, programVersion);
+  XMLOutputStream_t * out = new(nothrow) 
+                           XMLOwningOutputFileStream(filename, encoding, writeXMLDecl,
+                           programName, programVersion);
+  
+  return out;
 }
 
 
@@ -1455,5 +1470,4 @@ XMLOutputStream_getString(XMLOutputStream_t* stream)
 
 
 LIBSBML_CPP_NAMESPACE_END
-
 /** @endcond */
